##### creating masterdb from scratch #####
DROP DATABASE IF EXISTS masterdb;
CREATE DATABASE masterdb;
USE masterdb;
GRANT ALL ON masterdb.* TO 'runner'@'localhost';

##### num_file = 1 + number of raw data file splits #####
CREATE TABLE split_runs
 ( 
	run SMALLINT,
	num_file TINYINT,
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../allright.txt' INTO TABLE split_runs;

##### basic run info i got by hand #####
CREATE TABLE basic
 ( 
	run SMALLINT,
	period TINYINT,
	nomangle TINYINT,
	cell VARCHAR(8),
	ebeam DOUBLE(9,4),
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../beamenergy/basic.list' INTO TABLE basic;

##### central spectrometer setting for right arm that i got from start/end run summaries #####
CREATE TABLE rspec
 ( 
	run SMALLINT,
	pmom DOUBLE,
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../specmom/rspec.list' INTO TABLE rspec;

##### beam polarization info i got basically from Eugene Moller website #####
CREATE TABLE beampol
 ( 
	run SMALLINT,
	moller_a DOUBLE(6,4),
	compton DOUBLE(6,4),
	moller_c DOUBLE(6,4),
	moller_pol_sign_out SMALLINT,
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../beampol/beampol.list' INTO TABLE beampol;

##### information from the paper run and halog shift summaries #####
CREATE TABLE byhand
 ( 
	run SMALLINT,
	flag SMALLINT,
	runtype VARCHAR(10),
	target1 VARCHAR(20),
	target2 VARCHAR(20),
	taraux1 VARCHAR(10),
	taraux2 VARCHAR(10),
	raster VARCHAR(2),
	comments VARCHAR(170),
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../runtype/final_runtypes_raster_n2.txt' INTO TABLE byhand;

##### sieve slit and target collimator info, by hand from Vince #####
CREATE TABLE byhand_aux
 (
	run SMALLINT,
	runtype VARCHAR(10),
	sieve_slit VARCHAR(20),
	target_collimators VARCHAR(20),
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../runtype/runtype_aux.txt' INTO TABLE byhand_aux;

# translating to MySQL NULL value
UPDATE byhand SET target2 = NULL WHERE target2 = "-";
UPDATE byhand SET taraux1 = NULL WHERE taraux1 = "-";
UPDATE byhand SET taraux2 = NULL WHERE taraux2 = "-";
UPDATE byhand SET raster = NULL WHERE raster = "?";

##### bhwp setting gotten from paper/halog summaries #####
CREATE TABLE beam_half_waveplate
 ( 
	run SMALLINT,
	bhwp VARCHAR(4),
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../bhwp/bhwp.list' INTO TABLE beam_half_waveplate;
# translating to MySQL NULL value
UPDATE beam_half_waveplate SET bhwp = NULL WHERE bhwp = "NULL";

##### info from start run summary from halog #####
CREATE TABLE wwwbeg 
 ( 
	`krun` SMALLINT,
	`Log entry time hr` VARCHAR(2),
	`Log entry time min` VARCHAR(2),
	`Log entry time sec` VARCHAR(2),
	`Log entry time mon` VARCHAR(2),
	`Log entry time day` VARCHAR(2),
	`Log entry time yr` VARCHAR(4),
	`Entry number` VARCHAR(90),
	`keyword` VARCHAR(5),
	`User name` VARCHAR(5),
	`kRun_type` VARCHAR(10),
	`kbeam_energy` VARCHAR(7),
	`kbeam_halfwaveplate` VARCHAR(3),
	`kbeam_raster` VARCHAR(3),
	`kcomment_text` VARCHAR(131),
	`kdaq_mode` VARCHAR(12),
	`kkin_name` VARCHAR(1),
	`kleftarm_p` VARCHAR(6),
	`kleftarm_theta` VARCHAR(6),
	`krightarm_p` VARCHAR(7),
	`krightarm_theta` VARCHAR(6),
	`ktarget_halfwaveplate` VARCHAR(3),
	`ktarget_name` VARCHAR(8),
	`ktarget_polarization` VARCHAR(5),
	`ktarget_type` VARCHAR(21),
	`ps1` VARCHAR(4),
	`ps2` VARCHAR(4),
	`ps3` VARCHAR(4),
	`ps4` VARCHAR(4),
	`ps5` VARCHAR(5),
	`ps6` VARCHAR(5),
	`ps7` VARCHAR(5),
	`ps8` VARCHAR(5),
	`EVENTS[0]` VARCHAR(1),
	`EVENTS[+]` VARCHAR(1),
	`EVENTS[-]` VARCHAR(1),
	`TIME  [0]` VARCHAR(1),
	`TIME  [+]` VARCHAR(1),
	`TIME  [-]` VARCHAR(1),
	`LIVE  [0]` VARCHAR(1),
	`LIVE  [+]` VARCHAR(1),
	`LIVE  [-]` VARCHAR(1),
	`T1[0] rate prescale` VARCHAR(1),
	`T1[0] rate real` VARCHAR(1),
	`T2[0] rate prescale` VARCHAR(1),
	`T2[0] rate real` VARCHAR(1),
	`T8[0] rate prescale` VARCHAR(1),
	`T8[0] rate real` VARCHAR(1),
	`T1[+] rate prescale` VARCHAR(1),
	`T1[+] rate real` VARCHAR(1),
	`T2[+] rate prescale` VARCHAR(1),
	`T2[+] rate real` VARCHAR(1),
	`T8[+] rate prescale` VARCHAR(1),
	`T8[+] rate real` VARCHAR(1),
	`T1[-] rate prescale` VARCHAR(1),
	`T1[-] rate real` VARCHAR(1),
	`T2[-] rate prescale` VARCHAR(1),
	`T2[-] rate real` VARCHAR(1),
	`T8[-] rate prescale` VARCHAR(1),
	`T8[-] rate real` VARCHAR(1),
	`T1[0] totals prescale` VARCHAR(1),
	`T1[0] totals real` VARCHAR(1),
	`T2[0] totals prescale` VARCHAR(1),
	`T2[0] totals real` VARCHAR(1),
	`T8[0] totals prescale` VARCHAR(1),
	`T8[0] totals real` VARCHAR(1),
	`T1[+] totals prescale` VARCHAR(1),
	`T1[+] totals real` VARCHAR(1),
	`T2[+] totals prescale` VARCHAR(1),
	`T2[+] totals real` VARCHAR(1),
	`T8[+] totals prescale` VARCHAR(1),
	`T8[+] totals real` VARCHAR(1),
	`T1[-] totals prescale` VARCHAR(1),
	`T1[-] totals real` VARCHAR(1),
	`T2[-] totals prescale` VARCHAR(1),
	`T2[-] totals real` VARCHAR(1),
	`T8[-] totals prescale` VARCHAR(1),
	`T8[-] totals real` VARCHAR(1),
	`BCM x1` VARCHAR(1),
	`BCM x3` VARCHAR(1),
	`BCM x10` VARCHAR(1),
	`BCM u1` VARCHAR(1),
	`BCM u3` VARCHAR(1),
	`BCM u10` VARCHAR(1),
	`BCM d1` VARCHAR(1),
	`BCM d3` VARCHAR(1),
	`BCM d10` VARCHAR(1),
	`BCM u1 [0]` VARCHAR(1),
	`BCM u3 [0]` VARCHAR(1),
	`BCM u10[0]` VARCHAR(1),
	`BCM u1 [+]` VARCHAR(1),
	`BCM u3 [+]` VARCHAR(1),
	`BCM u10[+]` VARCHAR(1),
	`BCM u1 [-]` VARCHAR(1),
	`BCM u3 [-]` VARCHAR(1),
	`BCM u10[-]` VARCHAR(1),
	`BCM d1 [0]` VARCHAR(1),
	`BCM d3 [0]` VARCHAR(1),
	`BCM d10[0]` VARCHAR(1),
	`BCM d1 [+]` VARCHAR(1),
	`BCM d3 [+]` VARCHAR(1),
	`BCM d10[+]` VARCHAR(1),
	`BCM d1 [-]` VARCHAR(1),
	`BCM d3 [-]` VARCHAR(1),
	`BCM d10[-]` VARCHAR(1),
	`Run Number` VARCHAR(4),
	`run mon` VARCHAR(2),
	`run day` VARCHAR(2),
	`run hr` VARCHAR(2),
	`run min` VARCHAR(2),
	`run sec` VARCHAR(2),
	`run yr` VARCHAR(4),
	`Left Arm D1 momentum` VARCHAR(1),
	`Left Arm angle` VARCHAR(1),
	`Right Arm D1 momentum` VARCHAR(8),
	`Right Arm angle` VARCHAR(7),
	`HALLA:p` VARCHAR(7),
	`HALLA:dpp` VARCHAR(12),
	`Tiefenbach Hall A energy` VARCHAR(7),
	`Left Arm mispointing (HPT)` VARCHAR(1),
	`Right Arm mispointing (HPT)` VARCHAR(1),
	`Left Arm Top VDC Current` VARCHAR(1),
	`Left Arm Bottom VDC Current` VARCHAR(1),
	`Right Arm Top VDC Current` VARCHAR(1),
	`Right Arm Bottom VDC Current` VARCHAR(1),
	`Right septum set current` VARCHAR(7),
	`Right septum current readback` VARCHAR(6),
	`Left Arm Q1 power supply current` VARCHAR(1),
	`Left Arm Q1 momentum` VARCHAR(1),
	`Left Arm Q1 gauss meter` VARCHAR(1),
	`Left Arm Q1 power supply polarity` VARCHAR(1),
	`Left Arm Q2 power supply current` VARCHAR(1),
	`Left Arm Q2 momentum` VARCHAR(1),
	`Left Arm Q2 gauss meter` VARCHAR(1),
	`Left Arm Q2 power supply polarity` VARCHAR(1),
	`Left Arm D1 power supply current` VARCHAR(1),
	`Left Arm D1 NMR` VARCHAR(1),
	`Left Arm Q3 power supply current` VARCHAR(1),
	`Left Arm Q3 momentum` VARCHAR(1),
	`Left Arm Q3 gauss meter` VARCHAR(1),
	`Left Arm Q3 power supply polarity` VARCHAR(1),
	`Right Arm Q1 power supply current` VARCHAR(1),
	`Right Arm Q1 momentum` VARCHAR(10),
	`Right Arm Q1 gauss meter` VARCHAR(10),
	`Right Arm Q1 power supply polarity` VARCHAR(1),
	`Right Arm Q2 power supply current` VARCHAR(12),
	`Right Arm Q2 momentum` VARCHAR(12),
	`Right Arm Q2 gauss meter` VARCHAR(10),
	`Right Arm Q2 power supply polarity` VARCHAR(7),
	`Right Arm D1 power supply current` VARCHAR(10),
	`Right Arm D1 NMR` VARCHAR(8),
	`Right Arm Q3 power supply current` VARCHAR(12),
	`Right Arm Q3 momentum` VARCHAR(12),
	`Right Arm Q3 gauss meter` VARCHAR(10),
	`Right Arm Q3 power supply polarity` VARCHAR(8),
	`Average current of the two cavities` VARCHAR(9),
	`Current on Unser monitor` VARCHAR(9),
	`Current on Upstream bcm` VARCHAR(9),
	`Current on Downstream bcm` VARCHAR(9),
	`Upstream Cavity Coefficient` VARCHAR(4),
	`Downstream Cavity Coefficient` VARCHAR(4),
	`Current on IBC0L02 (source)` VARCHAR(10),
	`Hall C Current` VARCHAR(1),
	`MBSY1c Hall A Beam energy` VARCHAR(7),
	`MBSY1c magnet current (amp)` VARCHAR(9),
	`MBSY1c Bdl` VARCHAR(11),
	`MBSY3c Hall C Beam energy` VARCHAR(7),
	`Tiefenbach Hall C energy` VARCHAR(7),
	`Delta(E)/E width (MV_AI_DXWID)` VARCHAR(9),
	`IPM1C12.XPOS` VARCHAR(12),
	`IPM1H04A.XPOS` VARCHAR(12),
	`IPM1H04A.YPOS` VARCHAR(12),
	`IPM1H04B.XPOS` VARCHAR(12),
	`IPM1H04B.YPOS` VARCHAR(12),
	`Left Arm Collimator` VARCHAR(1),
	`Left LVDT HPM` VARCHAR(1),
	`Left LVDT VPM` VARCHAR(1),
	`HacL_HPE1313A:0_Ch58` VARCHAR(1),
	`HacL_HPE1313A:0_Ch55` VARCHAR(1),
	`HacL_HPE1313A:0_Ch54` VARCHAR(1),
	`HacL_alignROLL` VARCHAR(1),
	`HacL_alignPITCH` VARCHAR(1),
	`HacL_alignHPT` VARCHAR(1),
	`Right Arm Collimator` VARCHAR(12),
	`Right LVDT HPM` VARCHAR(7),
	`Right LVDT VPM` VARCHAR(5),
	`HacR_HPE1313A:0_Ch58` VARCHAR(9),
	`HacR_HPE1313A:0_Ch55` VARCHAR(7),
	`HacR_HPE1313A:0_Ch54` VARCHAR(9),
	`HacR_alignROLL` VARCHAR(9),
	`HacR_alignPITCH` VARCHAR(12),
	`HacR_alignHPT` VARCHAR(2),
	`Wien angle` VARCHAR(8),
	`Helicity Mode ON/OFF Random/Toggle` VARCHAR(3),
	`Wien BDL` VARCHAR(7),
	`Wien field` VARCHAR(6),
	`Laser attenuation Hall A` VARCHAR(3),
	`Laser power Hall A` VARCHAR(2),
	`Half-wave plate (off=out)` VARCHAR(3),
	`rotating waveplate` VARCHAR(4),
	`Beam Half-wave plate (off=out)` VARCHAR(3),
	`G0 Helicity Settle Set` VARCHAR(8),
	`G0 Helicity Delay Set` VARCHAR(8),
	`G0 Helicity Pattern Set` VARCHAR(7),
	`G0 Helicity Settle Read` VARCHAR(8),
	`G0 Helicity Delay Read` VARCHAR(8),
	`G0 Helicity Pattern` VARCHAR(7),
	`Target OTR x-position` VARCHAR(10),
	`Target OTR y-position` VARCHAR(10),
	`Target OTR x-width` VARCHAR(9),
	`Target OTR y-width` VARCHAR(9),
	`Target OTR data valid flag` VARCHAR(3),
	`Target OTR In/Out` VARCHAR(15),
	`Arc OTR x-position` VARCHAR(9),
	`Arc OTR y-position` VARCHAR(12),
	`Arc OTR x-width` VARCHAR(9),
	`Arc OTR y-width` VARCHAR(9),
	`Arc OTR data valid flag` VARCHAR(2),
	`Arc OTR In/Out` VARCHAR(13),
	`Polarized 3He Target RTD #1` VARCHAR(1),
	`Polarized 3He Target RTD #2` VARCHAR(1),
	`Polarized 3He Target RTD #3` VARCHAR(1),
	`Polarized 3He Target RTD #4` VARCHAR(1),
	`Polarized 3He Target RTD #5` VARCHAR(1),
	`Polarized 3He Target RTD #6` VARCHAR(1),
	`Polarized 3He Target RTD #7` VARCHAR(1),
	`Polarized 3He Ref. Cell RTD #8` VARCHAR(1),
	`Polarized 3He Ref. Cell RTD #9` VARCHAR(1),
	`Polarized 3He Ref. Cell RTD #10` VARCHAR(1),
	`Polarized 3He Target Ref. Cell Gas Pres.` VARCHAR(1),
	`Polarized 3He Target Ref. Cell Sys.Vac.` VARCHAR(1),
	`Polarized 3He Target Cooling Jet` VARCHAR(1),
	`Polarized 3He Target OVEN RTD` VARCHAR(1),
	`Polarized 3He Target OVEN SP1 SET` VARCHAR(1),
	`Polarized 3He Target OVEN SP1` VARCHAR(1),
	`Polarized 3He Target OVEN AL1 SET` VARCHAR(1),
	`Polarized 3He Target OVEN AL1` VARCHAR(1),
	`Polarized 3He Target OVEN AL1 STATUS` VARCHAR(1),
	`Polarized 3He Target Half-Wave Plate DIST` VARCHAR(1),
	`Polarized 3He Target Half-Wave Plate STAT` VARCHAR(1),
	`Polarized 3He Target Position (PA)` VARCHAR(1),
	`Polarized 3He Target Position (POS)` VARCHAR(1),
	`Polarized 3He Target Position (DA)` VARCHAR(1),
	`Polarized 3He Target Position (SS9)` VARCHAR(1),
	`Polarized 3He Target Position (SA10)` VARCHAR(1),
	`Polarized 3He Target Position (SA9)` VARCHAR(1),
	`Polarized 3He Laser#1 State` VARCHAR(1),
	`Polarized 3He Laser#1 Current` VARCHAR(1),
	`Polarized 3He Laser#1 Temperature` VARCHAR(1),
	`Polarized 3He Laser#2 State` VARCHAR(1),
	`Polarized 3He Laser#2 Current` VARCHAR(1),
	`Polarized 3He Laser#2 Temperature` VARCHAR(1),
	`Polarized 3He Laser#3 State` VARCHAR(1),
	`Polarized 3He Laser#3 Current` VARCHAR(1),
	`Polarized 3He Laser#3 Temperature` VARCHAR(1),
	`Polarized 3He Laser#4 State` VARCHAR(1),
	`Polarized 3He Laser#4 Current` VARCHAR(1),
	`Polarized 3He Laser#4 Temperature` VARCHAR(1),
	`Polarized 3He Laser#5 State` VARCHAR(1),
	`Polarized 3He Laser#5 Current` VARCHAR(1),
	`Polarized 3He Laser#5 Temperature` VARCHAR(1),
	`Polarized 3He Laser#6 State` VARCHAR(1),
	`Polarized 3He Laser#6 Current` VARCHAR(1),
	`Polarized 3He Laser#6 Temperature` VARCHAR(1),
	`Polarized 3He Laser#7 State` VARCHAR(1),
	`Polarized 3He Laser#7 Current` VARCHAR(1),
	`Polarized 3He Laser#7 Temperature` VARCHAR(1),
	`Polarized 3He Coil Current Longitudinal` VARCHAR(6),
	`Polarized 3He Coil Current Transverse` VARCHAR(6),
	`Transverse gradient coils (A) setup current` VARCHAR(8),
	`Transverse gradient coils (A) readback current` VARCHAR(11),
	`Longitudinal upstream gradient coil (B) setup current` VARCHAR(7),
	`Longitudinal upstream gradient coil (B) readback current` VARCHAR(11),
	`Longitudinal downstream gradient coil (C) setup current` VARCHAR(7),
	`Longitudinal downstream gradient coil (C) readback current` VARCHAR(12),
	`Small vertical gradient coils (D) setup current` VARCHAR(8),
	`Small vertical gradient coils (D) readback current` VARCHAR(12),
	`Left Arm D1 momentum 2` VARCHAR(1),
	`Right Arm D1 momentum 2` VARCHAR(1),
	`Tiefenbach Hall A energy 2` VARCHAR(1),
	`Log book entry time is secs from midnnight April 20` VARCHAR(8),
	`Run stop time is secs from midnnight April 20` VARCHAR(8),
	`kCOMMENTS` VARCHAR(1),
	`Number of run summary files for this run` VARCHAR(1),
	`Right Arm Top VDC voltage` VARCHAR(11),
	`Right Arm Bottom VDC voltage` VARCHAR(11),
	`Arc1 dp/p` VARCHAR(11),
	`Arc2 dp/p` VARCHAR(11),
	`Right Arm Angle Floor Angle` VARCHAR(4),
	`Right Arm Angle Vernier` VARCHAR(5),
	`IPM1C12.YPOS` VARCHAR(12),
	`Survey X offset bpmA` VARCHAR(5),
	`Survey Y offset bpmA` VARCHAR(4),
	`Survey X offset bpmB` VARCHAR(4),
	`Survey Y offset bpmB` VARCHAR(2),
	INDEX (krun)
 );
LOAD DATA LOCAL INFILE '../html/right_beg_raw.html' INTO TABLE wwwbeg;

##### info from end run summary from halog #####
CREATE TABLE wwwend 
 ( 
	`krun` SMALLINT,
	`Log entry time hr` VARCHAR(2),
	`Log entry time min` VARCHAR(2),
	`Log entry time sec` VARCHAR(2),
	`Log entry time mon` VARCHAR(2),
	`Log entry time day` VARCHAR(2),
	`Log entry time yr` VARCHAR(4),
	`Entry number` VARCHAR(90),
	`keyword` VARCHAR(3),
	`User name` VARCHAR(5),
	`kRun_type` VARCHAR(10),
	`kbeam_energy` VARCHAR(7),
	`kbeam_halfwaveplate` VARCHAR(3),
	`kbeam_raster` VARCHAR(3),
	`kcomment_text` VARCHAR(131),
	`kdaq_mode` VARCHAR(12),
	`kkin_name` VARCHAR(4),
	`kleftarm_p` VARCHAR(6),
	`kleftarm_theta` VARCHAR(6),
	`krightarm_p` VARCHAR(7),
	`krightarm_theta` VARCHAR(6),
	`ktarget_halfwaveplate` VARCHAR(3),
	`ktarget_name` VARCHAR(8),
	`ktarget_polarization` VARCHAR(5),
	`ktarget_type` VARCHAR(69),
	`ps1` VARCHAR(4),
	`ps2` VARCHAR(4),
	`ps3` VARCHAR(4),
	`ps4` VARCHAR(4),
	`ps5` VARCHAR(5),
	`ps6` VARCHAR(5),
	`ps7` VARCHAR(5),
	`ps8` VARCHAR(5),
	`EVENTS[0]` VARCHAR(8),
	`EVENTS[+]` VARCHAR(8),
	`EVENTS[-]` VARCHAR(8),
	`TIME  [0]` VARCHAR(8),
	`TIME  [+]` VARCHAR(8),
	`TIME  [-]` VARCHAR(8),
	`LIVE  [0]` VARCHAR(6),
	`LIVE  [+]` VARCHAR(8),
	`LIVE  [-]` VARCHAR(7),
	`T1[0] rate prescale` VARCHAR(8),
	`T1[0] rate real` VARCHAR(8),
	`T2[0] rate prescale` VARCHAR(6),
	`T2[0] rate real` VARCHAR(7),
	`T8[0] rate prescale` VARCHAR(6),
	`T8[0] rate real` VARCHAR(6),
	`T1[+] rate prescale` VARCHAR(8),
	`T1[+] rate real` VARCHAR(8),
	`T2[+] rate prescale` VARCHAR(6),
	`T2[+] rate real` VARCHAR(7),
	`T8[+] rate prescale` VARCHAR(6),
	`T8[+] rate real` VARCHAR(6),
	`T1[-] rate prescale` VARCHAR(8),
	`T1[-] rate real` VARCHAR(8),
	`T2[-] rate prescale` VARCHAR(6),
	`T2[-] rate real` VARCHAR(7),
	`T8[-] rate prescale` VARCHAR(6),
	`T8[-] rate real` VARCHAR(6),
	`T1[0] totals prescale` VARCHAR(9),
	`T1[0] totals real` VARCHAR(11),
	`T2[0] totals prescale` VARCHAR(7),
	`T2[0] totals real` VARCHAR(9),
	`T8[0] totals prescale` VARCHAR(6),
	`T8[0] totals real` VARCHAR(11),
	`T1[+] totals prescale` VARCHAR(9),
	`T1[+] totals real` VARCHAR(11),
	`T2[+] totals prescale` VARCHAR(6),
	`T2[+] totals real` VARCHAR(9),
	`T8[+] totals prescale` VARCHAR(6),
	`T8[+] totals real` VARCHAR(10),
	`T1[-] totals prescale` VARCHAR(9),
	`T1[-] totals real` VARCHAR(11),
	`T2[-] totals prescale` VARCHAR(6),
	`T2[-] totals real` VARCHAR(9),
	`T8[-] totals prescale` VARCHAR(6),
	`T8[-] totals real` VARCHAR(10),
	`BCM x1` VARCHAR(6),
	`BCM x3` VARCHAR(6),
	`BCM x10` VARCHAR(6),
	`BCM u1` VARCHAR(10),
	`BCM u3` VARCHAR(10),
	`BCM u10` VARCHAR(10),
	`BCM d1` VARCHAR(10),
	`BCM d3` VARCHAR(10),
	`BCM d10` VARCHAR(10),
	`BCM u1 [0]` VARCHAR(15),
	`BCM u3 [0]` VARCHAR(15),
	`BCM u10[0]` VARCHAR(15),
	`BCM u1 [+]` VARCHAR(15),
	`BCM u3 [+]` VARCHAR(15),
	`BCM u10[+]` VARCHAR(15),
	`BCM u1 [-]` VARCHAR(15),
	`BCM u3 [-]` VARCHAR(15),
	`BCM u10[-]` VARCHAR(15),
	`BCM d1 [0]` VARCHAR(15),
	`BCM d3 [0]` VARCHAR(15),
	`BCM d10[0]` VARCHAR(15),
	`BCM d1 [+]` VARCHAR(15),
	`BCM d3 [+]` VARCHAR(15),
	`BCM d10[+]` VARCHAR(15),
	`BCM d1 [-]` VARCHAR(15),
	`BCM d3 [-]` VARCHAR(15),
	`BCM d10[-]` VARCHAR(15),
	`Run Number` VARCHAR(4),
	`run mon` VARCHAR(2),
	`run day` VARCHAR(2),
	`run hr` VARCHAR(2),
	`run min` VARCHAR(2),
	`run sec` VARCHAR(2),
	`run yr` VARCHAR(4),
	`Left Arm D1 momentum` BLOB,
	`Left Arm angle` VARCHAR(7),
	`Right Arm D1 momentum` VARCHAR(8),
	`Right Arm angle` VARCHAR(7),
	`HALLA:p` VARCHAR(7),
	`HALLA:dpp` VARCHAR(12),
	`Tiefenbach Hall A energy` VARCHAR(7),
	`Left Arm mispointing (HPT)` VARCHAR(1),
	`Right Arm mispointing (HPT)` VARCHAR(2),
	`Left Arm Top VDC Current` VARCHAR(10),
	`Left Arm Bottom VDC Current` VARCHAR(10),
	`Right Arm Top VDC Current` VARCHAR(1),
	`Right Arm Bottom VDC Current` VARCHAR(1),
	`Right septum set current` VARCHAR(7),
	`Right septum current readback` VARCHAR(6),
	`Left Arm Q1 power supply current` VARCHAR(1),
	`Left Arm Q1 momentum` VARCHAR(10),
	`Left Arm Q1 gauss meter` VARCHAR(1),
	`Left Arm Q1 power supply polarity` VARCHAR(1),
	`Left Arm Q2 power supply current` VARCHAR(12),
	`Left Arm Q2 momentum` VARCHAR(12),
	`Left Arm Q2 gauss meter` VARCHAR(1),
	`Left Arm Q2 power supply polarity` VARCHAR(8),
	`Left Arm D1 power supply current` VARCHAR(10),
	`Left Arm D1 NMR` VARCHAR(8),
	`Left Arm Q3 power supply current` VARCHAR(11),
	`Left Arm Q3 momentum` VARCHAR(11),
	`Left Arm Q3 gauss meter` VARCHAR(1),
	`Left Arm Q3 power supply polarity` VARCHAR(8),
	`Right Arm Q1 power supply current` VARCHAR(1),
	`Right Arm Q1 momentum` VARCHAR(10),
	`Right Arm Q1 gauss meter` VARCHAR(10),
	`Right Arm Q1 power supply polarity` VARCHAR(1),
	`Right Arm Q2 power supply current` VARCHAR(12),
	`Right Arm Q2 momentum` VARCHAR(12),
	`Right Arm Q2 gauss meter` VARCHAR(10),
	`Right Arm Q2 power supply polarity` VARCHAR(7),
	`Right Arm D1 power supply current` VARCHAR(10),
	`Right Arm D1 NMR` VARCHAR(8),
	`Right Arm Q3 power supply current` VARCHAR(12),
	`Right Arm Q3 momentum` VARCHAR(12),
	`Right Arm Q3 gauss meter` VARCHAR(10),
	`Right Arm Q3 power supply polarity` VARCHAR(8),
	`Average current of the two cavities` VARCHAR(9),
	`Current on Unser monitor` VARCHAR(8),
	`Current on Upstream bcm` VARCHAR(12),
	`Current on Downstream bcm` VARCHAR(9),
	`Upstream Cavity Coefficient` VARCHAR(4),
	`Downstream Cavity Coefficient` VARCHAR(4),
	`Current on IBC0L02 (source)` VARCHAR(10),
	`Hall C Current` BLOB,
	`MBSY1c Hall A Beam energy` VARCHAR(7),
	`MBSY1c magnet current (amp)` VARCHAR(9),
	`MBSY1c Bdl` VARCHAR(11),
	`MBSY3c Hall C Beam energy` VARCHAR(7),
	`Tiefenbach Hall C energy` VARCHAR(7),
	`Delta(E)/E width (MV_AI_DXWID)` VARCHAR(9),
	`IPM1C12.XPOS` VARCHAR(12),
	`IPM1H04A.XPOS` VARCHAR(12),
	`IPM1H04A.YPOS` VARCHAR(12),
	`IPM1H04B.XPOS` VARCHAR(12),
	`IPM1H04B.YPOS` VARCHAR(12),
	`Left Arm Collimator` VARCHAR(9),
	`Left LVDT HPM` VARCHAR(1),
	`Left LVDT VPM` VARCHAR(1),
	`HacL_HPE1313A:0_Ch58` VARCHAR(9),
	`HacL_HPE1313A:0_Ch55` VARCHAR(7),
	`HacL_HPE1313A:0_Ch54` VARCHAR(10),
	`HacL_alignROLL` VARCHAR(1),
	`HacL_alignPITCH` VARCHAR(1),
	`HacL_alignHPT` VARCHAR(1),
	`Right Arm Collimator` VARCHAR(12),
	`Right LVDT HPM` VARCHAR(7),
	`Right LVDT VPM` VARCHAR(5),
	`HacR_HPE1313A:0_Ch58` VARCHAR(9),
	`HacR_HPE1313A:0_Ch55` VARCHAR(7),
	`HacR_HPE1313A:0_Ch54` VARCHAR(9),
	`HacR_alignROLL` VARCHAR(9),
	`HacR_alignPITCH` VARCHAR(12),
	`HacR_alignHPT` VARCHAR(2),
	`Wien angle` VARCHAR(8),
	`Helicity Mode ON/OFF Random/Toggle` VARCHAR(3),
	`Wien BDL` VARCHAR(7),
	`Wien field` VARCHAR(6),
	`Laser attenuation Hall A` VARCHAR(3),
	`Laser power Hall A` VARCHAR(2),
	`Half-wave plate (off=out)` VARCHAR(3),
	`rotating waveplate` VARCHAR(4),
	`Beam Half-wave plate (off=out)` VARCHAR(3),
	`G0 Helicity Settle Set` VARCHAR(8),
	`G0 Helicity Delay Set` VARCHAR(8),
	`G0 Helicity Pattern Set` VARCHAR(7),
	`G0 Helicity Settle Read` VARCHAR(8),
	`G0 Helicity Delay Read` VARCHAR(8),
	`G0 Helicity Pattern` VARCHAR(7),
	`Target OTR x-position` VARCHAR(12),
	`Target OTR y-position` VARCHAR(11),
	`Target OTR x-width` VARCHAR(9),
	`Target OTR y-width` VARCHAR(9),
	`Target OTR data valid flag` VARCHAR(3),
	`Target OTR In/Out` VARCHAR(58),
	`Arc OTR x-position` VARCHAR(10),
	`Arc OTR y-position` VARCHAR(12),
	`Arc OTR x-width` VARCHAR(9),
	`Arc OTR y-width` VARCHAR(9),
	`Arc OTR data valid flag` VARCHAR(2),
	`Arc OTR In/Out` VARCHAR(14),
	`Polarized 3He Target RTD #1` VARCHAR(7),
	`Polarized 3He Target RTD #2` VARCHAR(7),
	`Polarized 3He Target RTD #3` VARCHAR(7),
	`Polarized 3He Target RTD #4` VARCHAR(7),
	`Polarized 3He Target RTD #5` VARCHAR(7),
	`Polarized 3He Target RTD #6` VARCHAR(7),
	`Polarized 3He Target RTD #7` VARCHAR(7),
	`Polarized 3He Ref. Cell RTD #8` VARCHAR(7),
	`Polarized 3He Ref. Cell RTD #9` VARCHAR(7),
	`Polarized 3He Ref. Cell RTD #10` VARCHAR(7),
	`Polarized 3He Target Ref. Cell Gas Pres.` VARCHAR(8),
	`Polarized 3He Target Ref. Cell Sys.Vac.` VARCHAR(9),
	`Polarized 3He Target Cooling Jet` VARCHAR(9),
	`Polarized 3He Target OVEN RTD` VARCHAR(5),
	`Polarized 3He Target OVEN SP1 SET` VARCHAR(3),
	`Polarized 3He Target OVEN SP1` VARCHAR(3),
	`Polarized 3He Target OVEN AL1 SET` VARCHAR(3),
	`Polarized 3He Target OVEN AL1` VARCHAR(3),
	`Polarized 3He Target OVEN AL1 STATUS` VARCHAR(13),
	`Polarized 3He Target Half-Wave Plate DIST` VARCHAR(7),
	`Polarized 3He Target Half-Wave Plate STAT` VARCHAR(7),
	`Polarized 3He Target Position (PA)` VARCHAR(8),
	`Polarized 3He Target Position (POS)` VARCHAR(15),
	`Polarized 3He Target Position (DA)` VARCHAR(8),
	`Polarized 3He Target Position (SS9)` VARCHAR(10),
	`Polarized 3He Target Position (SA10)` VARCHAR(1),
	`Polarized 3He Target Position (SA9)` VARCHAR(1),
	`Polarized 3He Laser#1 State` VARCHAR(2),
	`Polarized 3He Laser#1 Current` VARCHAR(2),
	`Polarized 3He Laser#1 Temperature` VARCHAR(4),
	`Polarized 3He Laser#2 State` VARCHAR(2),
	`Polarized 3He Laser#2 Current` VARCHAR(4),
	`Polarized 3He Laser#2 Temperature` VARCHAR(3),
	`Polarized 3He Laser#3 State` VARCHAR(2),
	`Polarized 3He Laser#3 Current` VARCHAR(4),
	`Polarized 3He Laser#3 Temperature` VARCHAR(4),
	`Polarized 3He Laser#4 State` VARCHAR(2),
	`Polarized 3He Laser#4 Current` VARCHAR(2),
	`Polarized 3He Laser#4 Temperature` VARCHAR(4),
	`Polarized 3He Laser#5 State` VARCHAR(2),
	`Polarized 3He Laser#5 Current` VARCHAR(4),
	`Polarized 3He Laser#5 Temperature` VARCHAR(4),
	`Polarized 3He Laser#6 State` VARCHAR(2),
	`Polarized 3He Laser#6 Current` VARCHAR(4),
	`Polarized 3He Laser#6 Temperature` VARCHAR(4),
	`Polarized 3He Laser#7 State` VARCHAR(2),
	`Polarized 3He Laser#7 Current` VARCHAR(2),
	`Polarized 3He Laser#7 Temperature` VARCHAR(3),
	`Polarized 3He Coil Current Longitudinal` VARCHAR(117),
	`Polarized 3He Coil Current Transverse` VARCHAR(6),
	`Transverse gradient coils (A) setup current` VARCHAR(8),
	`Transverse gradient coils (A) readback current` VARCHAR(11),
	`Longitudinal upstream gradient coil (B) setup current` VARCHAR(7),
	`Longitudinal upstream gradient coil (B) readback current` VARCHAR(12),
	`Longitudinal downstream gradient coil (C) setup current` VARCHAR(7),
	`Longitudinal downstream gradient coil (C) readback current` VARCHAR(12),
	`Small vertical gradient coils (D) setup current` VARCHAR(8),
	`Small vertical gradient coils (D) readback current` VARCHAR(12),
	`Left Arm D1 momentum 2` VARCHAR(8),
	`Right Arm D1 momentum 2` VARCHAR(8),
	`Tiefenbach Hall A energy 2` VARCHAR(7),
	`Log book entry time is secs from midnnight April 20` VARCHAR(8),
	`Run stop time is secs from midnnight April 20` VARCHAR(8),
	`kCOMMENTS` VARCHAR(134),
	`Number of run summary files for this run` VARCHAR(1),
	INDEX (krun)	
 );
LOAD DATA LOCAL INFILE '../html/right_end_raw.html' INTO TABLE wwwend;

##### translating to MySQL NULL value #####
UPDATE wwwbeg SET `krun` = NULL WHERE `krun` = "?";
UPDATE wwwbeg SET `Log entry time hr` = NULL WHERE `Log entry time hr` = "?";
UPDATE wwwbeg SET `Log entry time min` = NULL WHERE `Log entry time min` = "?";
UPDATE wwwbeg SET `Log entry time sec` = NULL WHERE `Log entry time sec` = "?";
UPDATE wwwbeg SET `Log entry time mon` = NULL WHERE `Log entry time mon` = "?";
UPDATE wwwbeg SET `Log entry time day` = NULL WHERE `Log entry time day` = "?";
UPDATE wwwbeg SET `Log entry time yr` = NULL WHERE `Log entry time yr` = "?";
UPDATE wwwbeg SET `Entry number` = NULL WHERE `Entry number` = "?";
UPDATE wwwbeg SET `keyword` = NULL WHERE `keyword` = "?";
UPDATE wwwbeg SET `User name` = NULL WHERE `User name` = "?";
UPDATE wwwbeg SET `kRun_type` = NULL WHERE `kRun_type` = "?";
UPDATE wwwbeg SET `kbeam_energy` = NULL WHERE `kbeam_energy` = "?";
UPDATE wwwbeg SET `kbeam_halfwaveplate` = NULL WHERE `kbeam_halfwaveplate` = "?";
UPDATE wwwbeg SET `kbeam_raster` = NULL WHERE `kbeam_raster` = "?";
UPDATE wwwbeg SET `kcomment_text` = NULL WHERE `kcomment_text` = "?";
UPDATE wwwbeg SET `kdaq_mode` = NULL WHERE `kdaq_mode` = "?";
UPDATE wwwbeg SET `kkin_name` = NULL WHERE `kkin_name` = "?";
UPDATE wwwbeg SET `kleftarm_p` = NULL WHERE `kleftarm_p` = "?";
UPDATE wwwbeg SET `kleftarm_theta` = NULL WHERE `kleftarm_theta` = "?";
UPDATE wwwbeg SET `krightarm_p` = NULL WHERE `krightarm_p` = "?";
UPDATE wwwbeg SET `krightarm_theta` = NULL WHERE `krightarm_theta` = "?";
UPDATE wwwbeg SET `ktarget_halfwaveplate` = NULL WHERE `ktarget_halfwaveplate` = "?";
UPDATE wwwbeg SET `ktarget_name` = NULL WHERE `ktarget_name` = "?";
UPDATE wwwbeg SET `ktarget_polarization` = NULL WHERE `ktarget_polarization` = "?";
UPDATE wwwbeg SET `ktarget_type` = NULL WHERE `ktarget_type` = "?";
UPDATE wwwbeg SET `ps1` = NULL WHERE `ps1` = "?";
UPDATE wwwbeg SET `ps2` = NULL WHERE `ps2` = "?";
UPDATE wwwbeg SET `ps3` = NULL WHERE `ps3` = "?";
UPDATE wwwbeg SET `ps4` = NULL WHERE `ps4` = "?";
UPDATE wwwbeg SET `ps5` = NULL WHERE `ps5` = "?";
UPDATE wwwbeg SET `ps6` = NULL WHERE `ps6` = "?";
UPDATE wwwbeg SET `ps7` = NULL WHERE `ps7` = "?";
UPDATE wwwbeg SET `ps8` = NULL WHERE `ps8` = "?";
UPDATE wwwbeg SET `EVENTS[0]` = NULL WHERE `EVENTS[0]` = "?";
UPDATE wwwbeg SET `EVENTS[+]` = NULL WHERE `EVENTS[+]` = "?";
UPDATE wwwbeg SET `EVENTS[-]` = NULL WHERE `EVENTS[-]` = "?";
UPDATE wwwbeg SET `TIME  [0]` = NULL WHERE `TIME  [0]` = "?";
UPDATE wwwbeg SET `TIME  [+]` = NULL WHERE `TIME  [+]` = "?";
UPDATE wwwbeg SET `TIME  [-]` = NULL WHERE `TIME  [-]` = "?";
UPDATE wwwbeg SET `LIVE  [0]` = NULL WHERE `LIVE  [0]` = "?";
UPDATE wwwbeg SET `LIVE  [+]` = NULL WHERE `LIVE  [+]` = "?";
UPDATE wwwbeg SET `LIVE  [-]` = NULL WHERE `LIVE  [-]` = "?";
UPDATE wwwbeg SET `T1[0] rate prescale` = NULL WHERE `T1[0] rate prescale` = "?";
UPDATE wwwbeg SET `T1[0] rate real` = NULL WHERE `T1[0] rate real` = "?";
UPDATE wwwbeg SET `T2[0] rate prescale` = NULL WHERE `T2[0] rate prescale` = "?";
UPDATE wwwbeg SET `T2[0] rate real` = NULL WHERE `T2[0] rate real` = "?";
UPDATE wwwbeg SET `T8[0] rate prescale` = NULL WHERE `T8[0] rate prescale` = "?";
UPDATE wwwbeg SET `T8[0] rate real` = NULL WHERE `T8[0] rate real` = "?";
UPDATE wwwbeg SET `T1[+] rate prescale` = NULL WHERE `T1[+] rate prescale` = "?";
UPDATE wwwbeg SET `T1[+] rate real` = NULL WHERE `T1[+] rate real` = "?";
UPDATE wwwbeg SET `T2[+] rate prescale` = NULL WHERE `T2[+] rate prescale` = "?";
UPDATE wwwbeg SET `T2[+] rate real` = NULL WHERE `T2[+] rate real` = "?";
UPDATE wwwbeg SET `T8[+] rate prescale` = NULL WHERE `T8[+] rate prescale` = "?";
UPDATE wwwbeg SET `T8[+] rate real` = NULL WHERE `T8[+] rate real` = "?";
UPDATE wwwbeg SET `T1[-] rate prescale` = NULL WHERE `T1[-] rate prescale` = "?";
UPDATE wwwbeg SET `T1[-] rate real` = NULL WHERE `T1[-] rate real` = "?";
UPDATE wwwbeg SET `T2[-] rate prescale` = NULL WHERE `T2[-] rate prescale` = "?";
UPDATE wwwbeg SET `T2[-] rate real` = NULL WHERE `T2[-] rate real` = "?";
UPDATE wwwbeg SET `T8[-] rate prescale` = NULL WHERE `T8[-] rate prescale` = "?";
UPDATE wwwbeg SET `T8[-] rate real` = NULL WHERE `T8[-] rate real` = "?";
UPDATE wwwbeg SET `T1[0] totals prescale` = NULL WHERE `T1[0] totals prescale` = "?";
UPDATE wwwbeg SET `T1[0] totals real` = NULL WHERE `T1[0] totals real` = "?";
UPDATE wwwbeg SET `T2[0] totals prescale` = NULL WHERE `T2[0] totals prescale` = "?";
UPDATE wwwbeg SET `T2[0] totals real` = NULL WHERE `T2[0] totals real` = "?";
UPDATE wwwbeg SET `T8[0] totals prescale` = NULL WHERE `T8[0] totals prescale` = "?";
UPDATE wwwbeg SET `T8[0] totals real` = NULL WHERE `T8[0] totals real` = "?";
UPDATE wwwbeg SET `T1[+] totals prescale` = NULL WHERE `T1[+] totals prescale` = "?";
UPDATE wwwbeg SET `T1[+] totals real` = NULL WHERE `T1[+] totals real` = "?";
UPDATE wwwbeg SET `T2[+] totals prescale` = NULL WHERE `T2[+] totals prescale` = "?";
UPDATE wwwbeg SET `T2[+] totals real` = NULL WHERE `T2[+] totals real` = "?";
UPDATE wwwbeg SET `T8[+] totals prescale` = NULL WHERE `T8[+] totals prescale` = "?";
UPDATE wwwbeg SET `T8[+] totals real` = NULL WHERE `T8[+] totals real` = "?";
UPDATE wwwbeg SET `T1[-] totals prescale` = NULL WHERE `T1[-] totals prescale` = "?";
UPDATE wwwbeg SET `T1[-] totals real` = NULL WHERE `T1[-] totals real` = "?";
UPDATE wwwbeg SET `T2[-] totals prescale` = NULL WHERE `T2[-] totals prescale` = "?";
UPDATE wwwbeg SET `T2[-] totals real` = NULL WHERE `T2[-] totals real` = "?";
UPDATE wwwbeg SET `T8[-] totals prescale` = NULL WHERE `T8[-] totals prescale` = "?";
UPDATE wwwbeg SET `T8[-] totals real` = NULL WHERE `T8[-] totals real` = "?";
UPDATE wwwbeg SET `BCM x1` = NULL WHERE `BCM x1` = "?";
UPDATE wwwbeg SET `BCM x3` = NULL WHERE `BCM x3` = "?";
UPDATE wwwbeg SET `BCM x10` = NULL WHERE `BCM x10` = "?";
UPDATE wwwbeg SET `BCM u1` = NULL WHERE `BCM u1` = "?";
UPDATE wwwbeg SET `BCM u3` = NULL WHERE `BCM u3` = "?";
UPDATE wwwbeg SET `BCM u10` = NULL WHERE `BCM u10` = "?";
UPDATE wwwbeg SET `BCM d1` = NULL WHERE `BCM d1` = "?";
UPDATE wwwbeg SET `BCM d3` = NULL WHERE `BCM d3` = "?";
UPDATE wwwbeg SET `BCM d10` = NULL WHERE `BCM d10` = "?";
UPDATE wwwbeg SET `BCM u1 [0]` = NULL WHERE `BCM u1 [0]` = "?";
UPDATE wwwbeg SET `BCM u3 [0]` = NULL WHERE `BCM u3 [0]` = "?";
UPDATE wwwbeg SET `BCM u10[0]` = NULL WHERE `BCM u10[0]` = "?";
UPDATE wwwbeg SET `BCM u1 [+]` = NULL WHERE `BCM u1 [+]` = "?";
UPDATE wwwbeg SET `BCM u3 [+]` = NULL WHERE `BCM u3 [+]` = "?";
UPDATE wwwbeg SET `BCM u10[+]` = NULL WHERE `BCM u10[+]` = "?";
UPDATE wwwbeg SET `BCM u1 [-]` = NULL WHERE `BCM u1 [-]` = "?";
UPDATE wwwbeg SET `BCM u3 [-]` = NULL WHERE `BCM u3 [-]` = "?";
UPDATE wwwbeg SET `BCM u10[-]` = NULL WHERE `BCM u10[-]` = "?";
UPDATE wwwbeg SET `BCM d1 [0]` = NULL WHERE `BCM d1 [0]` = "?";
UPDATE wwwbeg SET `BCM d3 [0]` = NULL WHERE `BCM d3 [0]` = "?";
UPDATE wwwbeg SET `BCM d10[0]` = NULL WHERE `BCM d10[0]` = "?";
UPDATE wwwbeg SET `BCM d1 [+]` = NULL WHERE `BCM d1 [+]` = "?";
UPDATE wwwbeg SET `BCM d3 [+]` = NULL WHERE `BCM d3 [+]` = "?";
UPDATE wwwbeg SET `BCM d10[+]` = NULL WHERE `BCM d10[+]` = "?";
UPDATE wwwbeg SET `BCM d1 [-]` = NULL WHERE `BCM d1 [-]` = "?";
UPDATE wwwbeg SET `BCM d3 [-]` = NULL WHERE `BCM d3 [-]` = "?";
UPDATE wwwbeg SET `BCM d10[-]` = NULL WHERE `BCM d10[-]` = "?";
UPDATE wwwbeg SET `Run Number` = NULL WHERE `Run Number` = "?";
UPDATE wwwbeg SET `run mon` = NULL WHERE `run mon` = "?";
UPDATE wwwbeg SET `run day` = NULL WHERE `run day` = "?";
UPDATE wwwbeg SET `run hr` = NULL WHERE `run hr` = "?";
UPDATE wwwbeg SET `run min` = NULL WHERE `run min` = "?";
UPDATE wwwbeg SET `run sec` = NULL WHERE `run sec` = "?";
UPDATE wwwbeg SET `run yr` = NULL WHERE `run yr` = "?";
UPDATE wwwbeg SET `Left Arm D1 momentum` = NULL WHERE `Left Arm D1 momentum` = "?";
UPDATE wwwbeg SET `Left Arm angle` = NULL WHERE `Left Arm angle` = "?";
UPDATE wwwbeg SET `Right Arm D1 momentum` = NULL WHERE `Right Arm D1 momentum` = "?";
UPDATE wwwbeg SET `Right Arm angle` = NULL WHERE `Right Arm angle` = "?";
UPDATE wwwbeg SET `HALLA:p` = NULL WHERE `HALLA:p` = "?";
UPDATE wwwbeg SET `HALLA:dpp` = NULL WHERE `HALLA:dpp` = "?";
UPDATE wwwbeg SET `Tiefenbach Hall A energy` = NULL WHERE `Tiefenbach Hall A energy` = "?";
UPDATE wwwbeg SET `Left Arm mispointing (HPT)` = NULL WHERE `Left Arm mispointing (HPT)` = "?";
UPDATE wwwbeg SET `Right Arm mispointing (HPT)` = NULL WHERE `Right Arm mispointing (HPT)` = "?";
UPDATE wwwbeg SET `Left Arm Top VDC Current` = NULL WHERE `Left Arm Top VDC Current` = "?";
UPDATE wwwbeg SET `Left Arm Bottom VDC Current` = NULL WHERE `Left Arm Bottom VDC Current` = "?";
UPDATE wwwbeg SET `Right Arm Top VDC Current` = NULL WHERE `Right Arm Top VDC Current` = "?";
UPDATE wwwbeg SET `Right Arm Bottom VDC Current` = NULL WHERE `Right Arm Bottom VDC Current` = "?";
UPDATE wwwbeg SET `Right septum set current` = NULL WHERE `Right septum set current` = "?";
UPDATE wwwbeg SET `Right septum current readback` = NULL WHERE `Right septum current readback` = "?";
UPDATE wwwbeg SET `Left Arm Q1 power supply current` = NULL WHERE `Left Arm Q1 power supply current` = "?";
UPDATE wwwbeg SET `Left Arm Q1 momentum` = NULL WHERE `Left Arm Q1 momentum` = "?";
UPDATE wwwbeg SET `Left Arm Q1 gauss meter` = NULL WHERE `Left Arm Q1 gauss meter` = "?";
UPDATE wwwbeg SET `Left Arm Q1 power supply polarity` = NULL WHERE `Left Arm Q1 power supply polarity` = "?";
UPDATE wwwbeg SET `Left Arm Q2 power supply current` = NULL WHERE `Left Arm Q2 power supply current` = "?";
UPDATE wwwbeg SET `Left Arm Q2 momentum` = NULL WHERE `Left Arm Q2 momentum` = "?";
UPDATE wwwbeg SET `Left Arm Q2 gauss meter` = NULL WHERE `Left Arm Q2 gauss meter` = "?";
UPDATE wwwbeg SET `Left Arm Q2 power supply polarity` = NULL WHERE `Left Arm Q2 power supply polarity` = "?";
UPDATE wwwbeg SET `Left Arm D1 power supply current` = NULL WHERE `Left Arm D1 power supply current` = "?";
UPDATE wwwbeg SET `Left Arm D1 NMR` = NULL WHERE `Left Arm D1 NMR` = "?";
UPDATE wwwbeg SET `Left Arm Q3 power supply current` = NULL WHERE `Left Arm Q3 power supply current` = "?";
UPDATE wwwbeg SET `Left Arm Q3 momentum` = NULL WHERE `Left Arm Q3 momentum` = "?";
UPDATE wwwbeg SET `Left Arm Q3 gauss meter` = NULL WHERE `Left Arm Q3 gauss meter` = "?";
UPDATE wwwbeg SET `Left Arm Q3 power supply polarity` = NULL WHERE `Left Arm Q3 power supply polarity` = "?";
UPDATE wwwbeg SET `Right Arm Q1 power supply current` = NULL WHERE `Right Arm Q1 power supply current` = "?";
UPDATE wwwbeg SET `Right Arm Q1 momentum` = NULL WHERE `Right Arm Q1 momentum` = "?";
UPDATE wwwbeg SET `Right Arm Q1 gauss meter` = NULL WHERE `Right Arm Q1 gauss meter` = "?";
UPDATE wwwbeg SET `Right Arm Q1 power supply polarity` = NULL WHERE `Right Arm Q1 power supply polarity` = "?";
UPDATE wwwbeg SET `Right Arm Q2 power supply current` = NULL WHERE `Right Arm Q2 power supply current` = "?";
UPDATE wwwbeg SET `Right Arm Q2 momentum` = NULL WHERE `Right Arm Q2 momentum` = "?";
UPDATE wwwbeg SET `Right Arm Q2 gauss meter` = NULL WHERE `Right Arm Q2 gauss meter` = "?";
UPDATE wwwbeg SET `Right Arm Q2 power supply polarity` = NULL WHERE `Right Arm Q2 power supply polarity` = "?";
UPDATE wwwbeg SET `Right Arm D1 power supply current` = NULL WHERE `Right Arm D1 power supply current` = "?";
UPDATE wwwbeg SET `Right Arm D1 NMR` = NULL WHERE `Right Arm D1 NMR` = "?";
UPDATE wwwbeg SET `Right Arm Q3 power supply current` = NULL WHERE `Right Arm Q3 power supply current` = "?";
UPDATE wwwbeg SET `Right Arm Q3 momentum` = NULL WHERE `Right Arm Q3 momentum` = "?";
UPDATE wwwbeg SET `Right Arm Q3 gauss meter` = NULL WHERE `Right Arm Q3 gauss meter` = "?";
UPDATE wwwbeg SET `Right Arm Q3 power supply polarity` = NULL WHERE `Right Arm Q3 power supply polarity` = "?";
UPDATE wwwbeg SET `Average current of the two cavities` = NULL WHERE `Average current of the two cavities` = "?";
UPDATE wwwbeg SET `Current on Unser monitor` = NULL WHERE `Current on Unser monitor` = "?";
UPDATE wwwbeg SET `Current on Upstream bcm` = NULL WHERE `Current on Upstream bcm` = "?";
UPDATE wwwbeg SET `Current on Downstream bcm` = NULL WHERE `Current on Downstream bcm` = "?";
UPDATE wwwbeg SET `Upstream Cavity Coefficient` = NULL WHERE `Upstream Cavity Coefficient` = "?";
UPDATE wwwbeg SET `Downstream Cavity Coefficient` = NULL WHERE `Downstream Cavity Coefficient` = "?";
UPDATE wwwbeg SET `Current on IBC0L02 (source)` = NULL WHERE `Current on IBC0L02 (source)` = "?";
UPDATE wwwbeg SET `Hall C Current` = NULL WHERE `Hall C Current` = "?";
UPDATE wwwbeg SET `MBSY1c Hall A Beam energy` = NULL WHERE `MBSY1c Hall A Beam energy` = "?";
UPDATE wwwbeg SET `MBSY1c magnet current (amp)` = NULL WHERE `MBSY1c magnet current (amp)` = "?";
UPDATE wwwbeg SET `MBSY1c Bdl` = NULL WHERE `MBSY1c Bdl` = "?";
UPDATE wwwbeg SET `MBSY3c Hall C Beam energy` = NULL WHERE `MBSY3c Hall C Beam energy` = "?";
UPDATE wwwbeg SET `Tiefenbach Hall C energy` = NULL WHERE `Tiefenbach Hall C energy` = "?";
UPDATE wwwbeg SET `Delta(E)/E width (MV_AI_DXWID)` = NULL WHERE `Delta(E)/E width (MV_AI_DXWID)` = "?";
UPDATE wwwbeg SET `IPM1C12.XPOS` = NULL WHERE `IPM1C12.XPOS` = "?";
UPDATE wwwbeg SET `IPM1H04A.XPOS` = NULL WHERE `IPM1H04A.XPOS` = "?";
UPDATE wwwbeg SET `IPM1H04A.YPOS` = NULL WHERE `IPM1H04A.YPOS` = "?";
UPDATE wwwbeg SET `IPM1H04B.XPOS` = NULL WHERE `IPM1H04B.XPOS` = "?";
UPDATE wwwbeg SET `IPM1H04B.YPOS` = NULL WHERE `IPM1H04B.YPOS` = "?";
UPDATE wwwbeg SET `Left Arm Collimator` = NULL WHERE `Left Arm Collimator` = "?";
UPDATE wwwbeg SET `Left LVDT HPM` = NULL WHERE `Left LVDT HPM` = "?";
UPDATE wwwbeg SET `Left LVDT VPM` = NULL WHERE `Left LVDT VPM` = "?";
UPDATE wwwbeg SET `HacL_HPE1313A:0_Ch58` = NULL WHERE `HacL_HPE1313A:0_Ch58` = "?";
UPDATE wwwbeg SET `HacL_HPE1313A:0_Ch55` = NULL WHERE `HacL_HPE1313A:0_Ch55` = "?";
UPDATE wwwbeg SET `HacL_HPE1313A:0_Ch54` = NULL WHERE `HacL_HPE1313A:0_Ch54` = "?";
UPDATE wwwbeg SET `HacL_alignROLL` = NULL WHERE `HacL_alignROLL` = "?";
UPDATE wwwbeg SET `HacL_alignPITCH` = NULL WHERE `HacL_alignPITCH` = "?";
UPDATE wwwbeg SET `HacL_alignHPT` = NULL WHERE `HacL_alignHPT` = "?";
UPDATE wwwbeg SET `Right Arm Collimator` = NULL WHERE `Right Arm Collimator` = "?";
UPDATE wwwbeg SET `Right LVDT HPM` = NULL WHERE `Right LVDT HPM` = "?";
UPDATE wwwbeg SET `Right LVDT VPM` = NULL WHERE `Right LVDT VPM` = "?";
UPDATE wwwbeg SET `HacR_HPE1313A:0_Ch58` = NULL WHERE `HacR_HPE1313A:0_Ch58` = "?";
UPDATE wwwbeg SET `HacR_HPE1313A:0_Ch55` = NULL WHERE `HacR_HPE1313A:0_Ch55` = "?";
UPDATE wwwbeg SET `HacR_HPE1313A:0_Ch54` = NULL WHERE `HacR_HPE1313A:0_Ch54` = "?";
UPDATE wwwbeg SET `HacR_alignROLL` = NULL WHERE `HacR_alignROLL` = "?";
UPDATE wwwbeg SET `HacR_alignPITCH` = NULL WHERE `HacR_alignPITCH` = "?";
UPDATE wwwbeg SET `HacR_alignHPT` = NULL WHERE `HacR_alignHPT` = "?";
UPDATE wwwbeg SET `Wien angle` = NULL WHERE `Wien angle` = "?";
UPDATE wwwbeg SET `Helicity Mode ON/OFF Random/Toggle` = NULL WHERE `Helicity Mode ON/OFF Random/Toggle` = "?";
UPDATE wwwbeg SET `Wien BDL` = NULL WHERE `Wien BDL` = "?";
UPDATE wwwbeg SET `Wien field` = NULL WHERE `Wien field` = "?";
UPDATE wwwbeg SET `Laser attenuation Hall A` = NULL WHERE `Laser attenuation Hall A` = "?";
UPDATE wwwbeg SET `Laser power Hall A` = NULL WHERE `Laser power Hall A` = "?";
UPDATE wwwbeg SET `Half-wave plate (off=out)` = NULL WHERE `Half-wave plate (off=out)` = "?";
UPDATE wwwbeg SET `rotating waveplate` = NULL WHERE `rotating waveplate` = "?";
UPDATE wwwbeg SET `Beam Half-wave plate (off=out)` = NULL WHERE `Beam Half-wave plate (off=out)` = "?";
UPDATE wwwbeg SET `G0 Helicity Settle Set` = NULL WHERE `G0 Helicity Settle Set` = "?";
UPDATE wwwbeg SET `G0 Helicity Delay Set` = NULL WHERE `G0 Helicity Delay Set` = "?";
UPDATE wwwbeg SET `G0 Helicity Pattern Set` = NULL WHERE `G0 Helicity Pattern Set` = "?";
UPDATE wwwbeg SET `G0 Helicity Settle Read` = NULL WHERE `G0 Helicity Settle Read` = "?";
UPDATE wwwbeg SET `G0 Helicity Delay Read` = NULL WHERE `G0 Helicity Delay Read` = "?";
UPDATE wwwbeg SET `G0 Helicity Pattern` = NULL WHERE `G0 Helicity Pattern` = "?";
UPDATE wwwbeg SET `Target OTR x-position` = NULL WHERE `Target OTR x-position` = "?";
UPDATE wwwbeg SET `Target OTR y-position` = NULL WHERE `Target OTR y-position` = "?";
UPDATE wwwbeg SET `Target OTR x-width` = NULL WHERE `Target OTR x-width` = "?";
UPDATE wwwbeg SET `Target OTR y-width` = NULL WHERE `Target OTR y-width` = "?";
UPDATE wwwbeg SET `Target OTR data valid flag` = NULL WHERE `Target OTR data valid flag` = "?";
UPDATE wwwbeg SET `Target OTR In/Out` = NULL WHERE `Target OTR In/Out` = "?";
UPDATE wwwbeg SET `Arc OTR x-position` = NULL WHERE `Arc OTR x-position` = "?";
UPDATE wwwbeg SET `Arc OTR y-position` = NULL WHERE `Arc OTR y-position` = "?";
UPDATE wwwbeg SET `Arc OTR x-width` = NULL WHERE `Arc OTR x-width` = "?";
UPDATE wwwbeg SET `Arc OTR y-width` = NULL WHERE `Arc OTR y-width` = "?";
UPDATE wwwbeg SET `Arc OTR data valid flag` = NULL WHERE `Arc OTR data valid flag` = "?";
UPDATE wwwbeg SET `Arc OTR In/Out` = NULL WHERE `Arc OTR In/Out` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #1` = NULL WHERE `Polarized 3He Target RTD #1` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #2` = NULL WHERE `Polarized 3He Target RTD #2` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #3` = NULL WHERE `Polarized 3He Target RTD #3` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #4` = NULL WHERE `Polarized 3He Target RTD #4` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #5` = NULL WHERE `Polarized 3He Target RTD #5` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #6` = NULL WHERE `Polarized 3He Target RTD #6` = "?";
UPDATE wwwbeg SET `Polarized 3He Target RTD #7` = NULL WHERE `Polarized 3He Target RTD #7` = "?";
UPDATE wwwbeg SET `Polarized 3He Ref. Cell RTD #8` = NULL WHERE `Polarized 3He Ref. Cell RTD #8` = "?";
UPDATE wwwbeg SET `Polarized 3He Ref. Cell RTD #9` = NULL WHERE `Polarized 3He Ref. Cell RTD #9` = "?";
UPDATE wwwbeg SET `Polarized 3He Ref. Cell RTD #10` = NULL WHERE `Polarized 3He Ref. Cell RTD #10` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Ref. Cell Gas Pres.` = NULL WHERE `Polarized 3He Target Ref. Cell Gas Pres.` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Ref. Cell Sys.Vac.` = NULL WHERE `Polarized 3He Target Ref. Cell Sys.Vac.` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Cooling Jet` = NULL WHERE `Polarized 3He Target Cooling Jet` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN RTD` = NULL WHERE `Polarized 3He Target OVEN RTD` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN SP1 SET` = NULL WHERE `Polarized 3He Target OVEN SP1 SET` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN SP1` = NULL WHERE `Polarized 3He Target OVEN SP1` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN AL1 SET` = NULL WHERE `Polarized 3He Target OVEN AL1 SET` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN AL1` = NULL WHERE `Polarized 3He Target OVEN AL1` = "?";
UPDATE wwwbeg SET `Polarized 3He Target OVEN AL1 STATUS` = NULL WHERE `Polarized 3He Target OVEN AL1 STATUS` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Half-Wave Plate DIST` = NULL WHERE `Polarized 3He Target Half-Wave Plate DIST` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Half-Wave Plate STAT` = NULL WHERE `Polarized 3He Target Half-Wave Plate STAT` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (PA)` = NULL WHERE `Polarized 3He Target Position (PA)` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (POS)` = NULL WHERE `Polarized 3He Target Position (POS)` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (DA)` = NULL WHERE `Polarized 3He Target Position (DA)` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (SS9)` = NULL WHERE `Polarized 3He Target Position (SS9)` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (SA10)` = NULL WHERE `Polarized 3He Target Position (SA10)` = "?";
UPDATE wwwbeg SET `Polarized 3He Target Position (SA9)` = NULL WHERE `Polarized 3He Target Position (SA9)` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#1 State` = NULL WHERE `Polarized 3He Laser#1 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#1 Current` = NULL WHERE `Polarized 3He Laser#1 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#1 Temperature` = NULL WHERE `Polarized 3He Laser#1 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#2 State` = NULL WHERE `Polarized 3He Laser#2 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#2 Current` = NULL WHERE `Polarized 3He Laser#2 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#2 Temperature` = NULL WHERE `Polarized 3He Laser#2 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#3 State` = NULL WHERE `Polarized 3He Laser#3 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#3 Current` = NULL WHERE `Polarized 3He Laser#3 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#3 Temperature` = NULL WHERE `Polarized 3He Laser#3 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#4 State` = NULL WHERE `Polarized 3He Laser#4 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#4 Current` = NULL WHERE `Polarized 3He Laser#4 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#4 Temperature` = NULL WHERE `Polarized 3He Laser#4 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#5 State` = NULL WHERE `Polarized 3He Laser#5 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#5 Current` = NULL WHERE `Polarized 3He Laser#5 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#5 Temperature` = NULL WHERE `Polarized 3He Laser#5 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#6 State` = NULL WHERE `Polarized 3He Laser#6 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#6 Current` = NULL WHERE `Polarized 3He Laser#6 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#6 Temperature` = NULL WHERE `Polarized 3He Laser#6 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#7 State` = NULL WHERE `Polarized 3He Laser#7 State` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#7 Current` = NULL WHERE `Polarized 3He Laser#7 Current` = "?";
UPDATE wwwbeg SET `Polarized 3He Laser#7 Temperature` = NULL WHERE `Polarized 3He Laser#7 Temperature` = "?";
UPDATE wwwbeg SET `Polarized 3He Coil Current Longitudinal` = NULL WHERE `Polarized 3He Coil Current Longitudinal` = "?";
UPDATE wwwbeg SET `Polarized 3He Coil Current Transverse` = NULL WHERE `Polarized 3He Coil Current Transverse` = "?";
UPDATE wwwbeg SET `Transverse gradient coils (A) setup current` = NULL WHERE `Transverse gradient coils (A) setup current` = "?";
UPDATE wwwbeg SET `Transverse gradient coils (A) readback current` = NULL WHERE `Transverse gradient coils (A) readback current` = "?";
UPDATE wwwbeg SET `Longitudinal upstream gradient coil (B) setup current` = NULL WHERE `Longitudinal upstream gradient coil (B) setup current` = "?";
UPDATE wwwbeg SET `Longitudinal upstream gradient coil (B) readback current` = NULL WHERE `Longitudinal upstream gradient coil (B) readback current` = "?";
UPDATE wwwbeg SET `Longitudinal downstream gradient coil (C) setup current` = NULL WHERE `Longitudinal downstream gradient coil (C) setup current` = "?";
UPDATE wwwbeg SET `Longitudinal downstream gradient coil (C) readback current` = NULL WHERE `Longitudinal downstream gradient coil (C) readback current` = "?";
UPDATE wwwbeg SET `Small vertical gradient coils (D) setup current` = NULL WHERE `Small vertical gradient coils (D) setup current` = "?";
UPDATE wwwbeg SET `Small vertical gradient coils (D) readback current` = NULL WHERE `Small vertical gradient coils (D) readback current` = "?";
UPDATE wwwbeg SET `Left Arm D1 momentum 2` = NULL WHERE `Left Arm D1 momentum 2` = "?";
UPDATE wwwbeg SET `Right Arm D1 momentum 2` = NULL WHERE `Right Arm D1 momentum 2` = "?";
UPDATE wwwbeg SET `Tiefenbach Hall A energy 2` = NULL WHERE `Tiefenbach Hall A energy 2` = "?";
UPDATE wwwbeg SET `Log book entry time is secs from midnnight April 20` = NULL WHERE `Log book entry time is secs from midnnight April 20` = "?";
UPDATE wwwbeg SET `Run stop time is secs from midnnight April 20` = NULL WHERE `Run stop time is secs from midnnight April 20` = "?";
UPDATE wwwbeg SET `kCOMMENTS` = NULL WHERE `kCOMMENTS` = "?";
UPDATE wwwbeg SET `Number of run summary files for this run` = NULL WHERE `Number of run summary files for this run` = "?";
UPDATE wwwbeg SET `Right Arm Top VDC voltage` = NULL WHERE `Right Arm Top VDC voltage` = "?";
UPDATE wwwbeg SET `Right Arm Bottom VDC voltage` = NULL WHERE `Right Arm Bottom VDC voltage` = "?";
UPDATE wwwbeg SET `Arc1 dp/p` = NULL WHERE `Arc1 dp/p` = "?";
UPDATE wwwbeg SET `Arc2 dp/p` = NULL WHERE `Arc2 dp/p` = "?";
UPDATE wwwbeg SET `Right Arm Angle Floor Angle` = NULL WHERE `Right Arm Angle Floor Angle` = "?";
UPDATE wwwbeg SET `Right Arm Angle Vernier` = NULL WHERE `Right Arm Angle Vernier` = "?";
UPDATE wwwbeg SET `IPM1C12.YPOS` = NULL WHERE `IPM1C12.YPOS` = "?";
UPDATE wwwbeg SET `Survey X offset bpmA` = NULL WHERE `Survey X offset bpmA` = "?";
UPDATE wwwbeg SET `Survey Y offset bpmA` = NULL WHERE `Survey Y offset bpmA` = "?";
UPDATE wwwbeg SET `Survey X offset bpmB` = NULL WHERE `Survey X offset bpmB` = "?";
UPDATE wwwbeg SET `Survey Y offset bpmB` = NULL WHERE `Survey Y offset bpmB` = "?";
UPDATE wwwend SET `krun` = NULL WHERE `krun` = "?";
UPDATE wwwend SET `Log entry time hr` = NULL WHERE `Log entry time hr` = "?";
UPDATE wwwend SET `Log entry time min` = NULL WHERE `Log entry time min` = "?";
UPDATE wwwend SET `Log entry time sec` = NULL WHERE `Log entry time sec` = "?";
UPDATE wwwend SET `Log entry time mon` = NULL WHERE `Log entry time mon` = "?";
UPDATE wwwend SET `Log entry time day` = NULL WHERE `Log entry time day` = "?";
UPDATE wwwend SET `Log entry time yr` = NULL WHERE `Log entry time yr` = "?";
UPDATE wwwend SET `Entry number` = NULL WHERE `Entry number` = "?";
UPDATE wwwend SET `keyword` = NULL WHERE `keyword` = "?";
UPDATE wwwend SET `User name` = NULL WHERE `User name` = "?";
UPDATE wwwend SET `kRun_type` = NULL WHERE `kRun_type` = "?";
UPDATE wwwend SET `kbeam_energy` = NULL WHERE `kbeam_energy` = "?";
UPDATE wwwend SET `kbeam_halfwaveplate` = NULL WHERE `kbeam_halfwaveplate` = "?";
UPDATE wwwend SET `kbeam_raster` = NULL WHERE `kbeam_raster` = "?";
UPDATE wwwend SET `kcomment_text` = NULL WHERE `kcomment_text` = "?";
UPDATE wwwend SET `kdaq_mode` = NULL WHERE `kdaq_mode` = "?";
UPDATE wwwend SET `kkin_name` = NULL WHERE `kkin_name` = "?";
UPDATE wwwend SET `kleftarm_p` = NULL WHERE `kleftarm_p` = "?";
UPDATE wwwend SET `kleftarm_theta` = NULL WHERE `kleftarm_theta` = "?";
UPDATE wwwend SET `krightarm_p` = NULL WHERE `krightarm_p` = "?";
UPDATE wwwend SET `krightarm_theta` = NULL WHERE `krightarm_theta` = "?";
UPDATE wwwend SET `ktarget_halfwaveplate` = NULL WHERE `ktarget_halfwaveplate` = "?";
UPDATE wwwend SET `ktarget_name` = NULL WHERE `ktarget_name` = "?";
UPDATE wwwend SET `ktarget_polarization` = NULL WHERE `ktarget_polarization` = "?";
UPDATE wwwend SET `ktarget_type` = NULL WHERE `ktarget_type` = "?";
UPDATE wwwend SET `ps1` = NULL WHERE `ps1` = "?";
UPDATE wwwend SET `ps2` = NULL WHERE `ps2` = "?";
UPDATE wwwend SET `ps3` = NULL WHERE `ps3` = "?";
UPDATE wwwend SET `ps4` = NULL WHERE `ps4` = "?";
UPDATE wwwend SET `ps5` = NULL WHERE `ps5` = "?";
UPDATE wwwend SET `ps6` = NULL WHERE `ps6` = "?";
UPDATE wwwend SET `ps7` = NULL WHERE `ps7` = "?";
UPDATE wwwend SET `ps8` = NULL WHERE `ps8` = "?";
UPDATE wwwend SET `EVENTS[0]` = NULL WHERE `EVENTS[0]` = "?";
UPDATE wwwend SET `EVENTS[+]` = NULL WHERE `EVENTS[+]` = "?";
UPDATE wwwend SET `EVENTS[-]` = NULL WHERE `EVENTS[-]` = "?";
UPDATE wwwend SET `TIME  [0]` = NULL WHERE `TIME  [0]` = "?";
UPDATE wwwend SET `TIME  [+]` = NULL WHERE `TIME  [+]` = "?";
UPDATE wwwend SET `TIME  [-]` = NULL WHERE `TIME  [-]` = "?";
UPDATE wwwend SET `LIVE  [0]` = NULL WHERE `LIVE  [0]` = "?";
UPDATE wwwend SET `LIVE  [+]` = NULL WHERE `LIVE  [+]` = "?";
UPDATE wwwend SET `LIVE  [-]` = NULL WHERE `LIVE  [-]` = "?";
UPDATE wwwend SET `T1[0] rate prescale` = NULL WHERE `T1[0] rate prescale` = "?";
UPDATE wwwend SET `T1[0] rate real` = NULL WHERE `T1[0] rate real` = "?";
UPDATE wwwend SET `T2[0] rate prescale` = NULL WHERE `T2[0] rate prescale` = "?";
UPDATE wwwend SET `T2[0] rate real` = NULL WHERE `T2[0] rate real` = "?";
UPDATE wwwend SET `T8[0] rate prescale` = NULL WHERE `T8[0] rate prescale` = "?";
UPDATE wwwend SET `T8[0] rate real` = NULL WHERE `T8[0] rate real` = "?";
UPDATE wwwend SET `T1[+] rate prescale` = NULL WHERE `T1[+] rate prescale` = "?";
UPDATE wwwend SET `T1[+] rate real` = NULL WHERE `T1[+] rate real` = "?";
UPDATE wwwend SET `T2[+] rate prescale` = NULL WHERE `T2[+] rate prescale` = "?";
UPDATE wwwend SET `T2[+] rate real` = NULL WHERE `T2[+] rate real` = "?";
UPDATE wwwend SET `T8[+] rate prescale` = NULL WHERE `T8[+] rate prescale` = "?";
UPDATE wwwend SET `T8[+] rate real` = NULL WHERE `T8[+] rate real` = "?";
UPDATE wwwend SET `T1[-] rate prescale` = NULL WHERE `T1[-] rate prescale` = "?";
UPDATE wwwend SET `T1[-] rate real` = NULL WHERE `T1[-] rate real` = "?";
UPDATE wwwend SET `T2[-] rate prescale` = NULL WHERE `T2[-] rate prescale` = "?";
UPDATE wwwend SET `T2[-] rate real` = NULL WHERE `T2[-] rate real` = "?";
UPDATE wwwend SET `T8[-] rate prescale` = NULL WHERE `T8[-] rate prescale` = "?";
UPDATE wwwend SET `T8[-] rate real` = NULL WHERE `T8[-] rate real` = "?";
UPDATE wwwend SET `T1[0] totals prescale` = NULL WHERE `T1[0] totals prescale` = "?";
UPDATE wwwend SET `T1[0] totals real` = NULL WHERE `T1[0] totals real` = "?";
UPDATE wwwend SET `T2[0] totals prescale` = NULL WHERE `T2[0] totals prescale` = "?";
UPDATE wwwend SET `T2[0] totals real` = NULL WHERE `T2[0] totals real` = "?";
UPDATE wwwend SET `T8[0] totals prescale` = NULL WHERE `T8[0] totals prescale` = "?";
UPDATE wwwend SET `T8[0] totals real` = NULL WHERE `T8[0] totals real` = "?";
UPDATE wwwend SET `T1[+] totals prescale` = NULL WHERE `T1[+] totals prescale` = "?";
UPDATE wwwend SET `T1[+] totals real` = NULL WHERE `T1[+] totals real` = "?";
UPDATE wwwend SET `T2[+] totals prescale` = NULL WHERE `T2[+] totals prescale` = "?";
UPDATE wwwend SET `T2[+] totals real` = NULL WHERE `T2[+] totals real` = "?";
UPDATE wwwend SET `T8[+] totals prescale` = NULL WHERE `T8[+] totals prescale` = "?";
UPDATE wwwend SET `T8[+] totals real` = NULL WHERE `T8[+] totals real` = "?";
UPDATE wwwend SET `T1[-] totals prescale` = NULL WHERE `T1[-] totals prescale` = "?";
UPDATE wwwend SET `T1[-] totals real` = NULL WHERE `T1[-] totals real` = "?";
UPDATE wwwend SET `T2[-] totals prescale` = NULL WHERE `T2[-] totals prescale` = "?";
UPDATE wwwend SET `T2[-] totals real` = NULL WHERE `T2[-] totals real` = "?";
UPDATE wwwend SET `T8[-] totals prescale` = NULL WHERE `T8[-] totals prescale` = "?";
UPDATE wwwend SET `T8[-] totals real` = NULL WHERE `T8[-] totals real` = "?";
UPDATE wwwend SET `BCM x1` = NULL WHERE `BCM x1` = "?";
UPDATE wwwend SET `BCM x3` = NULL WHERE `BCM x3` = "?";
UPDATE wwwend SET `BCM x10` = NULL WHERE `BCM x10` = "?";
UPDATE wwwend SET `BCM u1` = NULL WHERE `BCM u1` = "?";
UPDATE wwwend SET `BCM u3` = NULL WHERE `BCM u3` = "?";
UPDATE wwwend SET `BCM u10` = NULL WHERE `BCM u10` = "?";
UPDATE wwwend SET `BCM d1` = NULL WHERE `BCM d1` = "?";
UPDATE wwwend SET `BCM d3` = NULL WHERE `BCM d3` = "?";
UPDATE wwwend SET `BCM d10` = NULL WHERE `BCM d10` = "?";
UPDATE wwwend SET `BCM u1 [0]` = NULL WHERE `BCM u1 [0]` = "?";
UPDATE wwwend SET `BCM u3 [0]` = NULL WHERE `BCM u3 [0]` = "?";
UPDATE wwwend SET `BCM u10[0]` = NULL WHERE `BCM u10[0]` = "?";
UPDATE wwwend SET `BCM u1 [+]` = NULL WHERE `BCM u1 [+]` = "?";
UPDATE wwwend SET `BCM u3 [+]` = NULL WHERE `BCM u3 [+]` = "?";
UPDATE wwwend SET `BCM u10[+]` = NULL WHERE `BCM u10[+]` = "?";
UPDATE wwwend SET `BCM u1 [-]` = NULL WHERE `BCM u1 [-]` = "?";
UPDATE wwwend SET `BCM u3 [-]` = NULL WHERE `BCM u3 [-]` = "?";
UPDATE wwwend SET `BCM u10[-]` = NULL WHERE `BCM u10[-]` = "?";
UPDATE wwwend SET `BCM d1 [0]` = NULL WHERE `BCM d1 [0]` = "?";
UPDATE wwwend SET `BCM d3 [0]` = NULL WHERE `BCM d3 [0]` = "?";
UPDATE wwwend SET `BCM d10[0]` = NULL WHERE `BCM d10[0]` = "?";
UPDATE wwwend SET `BCM d1 [+]` = NULL WHERE `BCM d1 [+]` = "?";
UPDATE wwwend SET `BCM d3 [+]` = NULL WHERE `BCM d3 [+]` = "?";
UPDATE wwwend SET `BCM d10[+]` = NULL WHERE `BCM d10[+]` = "?";
UPDATE wwwend SET `BCM d1 [-]` = NULL WHERE `BCM d1 [-]` = "?";
UPDATE wwwend SET `BCM d3 [-]` = NULL WHERE `BCM d3 [-]` = "?";
UPDATE wwwend SET `BCM d10[-]` = NULL WHERE `BCM d10[-]` = "?";
UPDATE wwwend SET `Run Number` = NULL WHERE `Run Number` = "?";
UPDATE wwwend SET `run mon` = NULL WHERE `run mon` = "?";
UPDATE wwwend SET `run day` = NULL WHERE `run day` = "?";
UPDATE wwwend SET `run hr` = NULL WHERE `run hr` = "?";
UPDATE wwwend SET `run min` = NULL WHERE `run min` = "?";
UPDATE wwwend SET `run sec` = NULL WHERE `run sec` = "?";
UPDATE wwwend SET `run yr` = NULL WHERE `run yr` = "?";
UPDATE wwwend SET `Left Arm D1 momentum` = NULL WHERE `Left Arm D1 momentum` = "?";
UPDATE wwwend SET `Left Arm angle` = NULL WHERE `Left Arm angle` = "?";
UPDATE wwwend SET `Right Arm D1 momentum` = NULL WHERE `Right Arm D1 momentum` = "?";
UPDATE wwwend SET `Right Arm angle` = NULL WHERE `Right Arm angle` = "?";
UPDATE wwwend SET `HALLA:p` = NULL WHERE `HALLA:p` = "?";
UPDATE wwwend SET `HALLA:dpp` = NULL WHERE `HALLA:dpp` = "?";
UPDATE wwwend SET `Tiefenbach Hall A energy` = NULL WHERE `Tiefenbach Hall A energy` = "?";
UPDATE wwwend SET `Left Arm mispointing (HPT)` = NULL WHERE `Left Arm mispointing (HPT)` = "?";
UPDATE wwwend SET `Right Arm mispointing (HPT)` = NULL WHERE `Right Arm mispointing (HPT)` = "?";
UPDATE wwwend SET `Left Arm Top VDC Current` = NULL WHERE `Left Arm Top VDC Current` = "?";
UPDATE wwwend SET `Left Arm Bottom VDC Current` = NULL WHERE `Left Arm Bottom VDC Current` = "?";
UPDATE wwwend SET `Right Arm Top VDC Current` = NULL WHERE `Right Arm Top VDC Current` = "?";
UPDATE wwwend SET `Right Arm Bottom VDC Current` = NULL WHERE `Right Arm Bottom VDC Current` = "?";
UPDATE wwwend SET `Right septum set current` = NULL WHERE `Right septum set current` = "?";
UPDATE wwwend SET `Right septum current readback` = NULL WHERE `Right septum current readback` = "?";
UPDATE wwwend SET `Left Arm Q1 power supply current` = NULL WHERE `Left Arm Q1 power supply current` = "?";
UPDATE wwwend SET `Left Arm Q1 momentum` = NULL WHERE `Left Arm Q1 momentum` = "?";
UPDATE wwwend SET `Left Arm Q1 gauss meter` = NULL WHERE `Left Arm Q1 gauss meter` = "?";
UPDATE wwwend SET `Left Arm Q1 power supply polarity` = NULL WHERE `Left Arm Q1 power supply polarity` = "?";
UPDATE wwwend SET `Left Arm Q2 power supply current` = NULL WHERE `Left Arm Q2 power supply current` = "?";
UPDATE wwwend SET `Left Arm Q2 momentum` = NULL WHERE `Left Arm Q2 momentum` = "?";
UPDATE wwwend SET `Left Arm Q2 gauss meter` = NULL WHERE `Left Arm Q2 gauss meter` = "?";
UPDATE wwwend SET `Left Arm Q2 power supply polarity` = NULL WHERE `Left Arm Q2 power supply polarity` = "?";
UPDATE wwwend SET `Left Arm D1 power supply current` = NULL WHERE `Left Arm D1 power supply current` = "?";
UPDATE wwwend SET `Left Arm D1 NMR` = NULL WHERE `Left Arm D1 NMR` = "?";
UPDATE wwwend SET `Left Arm Q3 power supply current` = NULL WHERE `Left Arm Q3 power supply current` = "?";
UPDATE wwwend SET `Left Arm Q3 momentum` = NULL WHERE `Left Arm Q3 momentum` = "?";
UPDATE wwwend SET `Left Arm Q3 gauss meter` = NULL WHERE `Left Arm Q3 gauss meter` = "?";
UPDATE wwwend SET `Left Arm Q3 power supply polarity` = NULL WHERE `Left Arm Q3 power supply polarity` = "?";
UPDATE wwwend SET `Right Arm Q1 power supply current` = NULL WHERE `Right Arm Q1 power supply current` = "?";
UPDATE wwwend SET `Right Arm Q1 momentum` = NULL WHERE `Right Arm Q1 momentum` = "?";
UPDATE wwwend SET `Right Arm Q1 gauss meter` = NULL WHERE `Right Arm Q1 gauss meter` = "?";
UPDATE wwwend SET `Right Arm Q1 power supply polarity` = NULL WHERE `Right Arm Q1 power supply polarity` = "?";
UPDATE wwwend SET `Right Arm Q2 power supply current` = NULL WHERE `Right Arm Q2 power supply current` = "?";
UPDATE wwwend SET `Right Arm Q2 momentum` = NULL WHERE `Right Arm Q2 momentum` = "?";
UPDATE wwwend SET `Right Arm Q2 gauss meter` = NULL WHERE `Right Arm Q2 gauss meter` = "?";
UPDATE wwwend SET `Right Arm Q2 power supply polarity` = NULL WHERE `Right Arm Q2 power supply polarity` = "?";
UPDATE wwwend SET `Right Arm D1 power supply current` = NULL WHERE `Right Arm D1 power supply current` = "?";
UPDATE wwwend SET `Right Arm D1 NMR` = NULL WHERE `Right Arm D1 NMR` = "?";
UPDATE wwwend SET `Right Arm Q3 power supply current` = NULL WHERE `Right Arm Q3 power supply current` = "?";
UPDATE wwwend SET `Right Arm Q3 momentum` = NULL WHERE `Right Arm Q3 momentum` = "?";
UPDATE wwwend SET `Right Arm Q3 gauss meter` = NULL WHERE `Right Arm Q3 gauss meter` = "?";
UPDATE wwwend SET `Right Arm Q3 power supply polarity` = NULL WHERE `Right Arm Q3 power supply polarity` = "?";
UPDATE wwwend SET `Average current of the two cavities` = NULL WHERE `Average current of the two cavities` = "?";
UPDATE wwwend SET `Current on Unser monitor` = NULL WHERE `Current on Unser monitor` = "?";
UPDATE wwwend SET `Current on Upstream bcm` = NULL WHERE `Current on Upstream bcm` = "?";
UPDATE wwwend SET `Current on Downstream bcm` = NULL WHERE `Current on Downstream bcm` = "?";
UPDATE wwwend SET `Upstream Cavity Coefficient` = NULL WHERE `Upstream Cavity Coefficient` = "?";
UPDATE wwwend SET `Downstream Cavity Coefficient` = NULL WHERE `Downstream Cavity Coefficient` = "?";
UPDATE wwwend SET `Current on IBC0L02 (source)` = NULL WHERE `Current on IBC0L02 (source)` = "?";
UPDATE wwwend SET `Hall C Current` = NULL WHERE `Hall C Current` = "?";
UPDATE wwwend SET `MBSY1c Hall A Beam energy` = NULL WHERE `MBSY1c Hall A Beam energy` = "?";
UPDATE wwwend SET `MBSY1c magnet current (amp)` = NULL WHERE `MBSY1c magnet current (amp)` = "?";
UPDATE wwwend SET `MBSY1c Bdl` = NULL WHERE `MBSY1c Bdl` = "?";
UPDATE wwwend SET `MBSY3c Hall C Beam energy` = NULL WHERE `MBSY3c Hall C Beam energy` = "?";
UPDATE wwwend SET `Tiefenbach Hall C energy` = NULL WHERE `Tiefenbach Hall C energy` = "?";
UPDATE wwwend SET `Delta(E)/E width (MV_AI_DXWID)` = NULL WHERE `Delta(E)/E width (MV_AI_DXWID)` = "?";
UPDATE wwwend SET `IPM1C12.XPOS` = NULL WHERE `IPM1C12.XPOS` = "?";
UPDATE wwwend SET `IPM1H04A.XPOS` = NULL WHERE `IPM1H04A.XPOS` = "?";
UPDATE wwwend SET `IPM1H04A.YPOS` = NULL WHERE `IPM1H04A.YPOS` = "?";
UPDATE wwwend SET `IPM1H04B.XPOS` = NULL WHERE `IPM1H04B.XPOS` = "?";
UPDATE wwwend SET `IPM1H04B.YPOS` = NULL WHERE `IPM1H04B.YPOS` = "?";
UPDATE wwwend SET `Left Arm Collimator` = NULL WHERE `Left Arm Collimator` = "?";
UPDATE wwwend SET `Left LVDT HPM` = NULL WHERE `Left LVDT HPM` = "?";
UPDATE wwwend SET `Left LVDT VPM` = NULL WHERE `Left LVDT VPM` = "?";
UPDATE wwwend SET `HacL_HPE1313A:0_Ch58` = NULL WHERE `HacL_HPE1313A:0_Ch58` = "?";
UPDATE wwwend SET `HacL_HPE1313A:0_Ch55` = NULL WHERE `HacL_HPE1313A:0_Ch55` = "?";
UPDATE wwwend SET `HacL_HPE1313A:0_Ch54` = NULL WHERE `HacL_HPE1313A:0_Ch54` = "?";
UPDATE wwwend SET `HacL_alignROLL` = NULL WHERE `HacL_alignROLL` = "?";
UPDATE wwwend SET `HacL_alignPITCH` = NULL WHERE `HacL_alignPITCH` = "?";
UPDATE wwwend SET `HacL_alignHPT` = NULL WHERE `HacL_alignHPT` = "?";
UPDATE wwwend SET `Right Arm Collimator` = NULL WHERE `Right Arm Collimator` = "?";
UPDATE wwwend SET `Right LVDT HPM` = NULL WHERE `Right LVDT HPM` = "?";
UPDATE wwwend SET `Right LVDT VPM` = NULL WHERE `Right LVDT VPM` = "?";
UPDATE wwwend SET `HacR_HPE1313A:0_Ch58` = NULL WHERE `HacR_HPE1313A:0_Ch58` = "?";
UPDATE wwwend SET `HacR_HPE1313A:0_Ch55` = NULL WHERE `HacR_HPE1313A:0_Ch55` = "?";
UPDATE wwwend SET `HacR_HPE1313A:0_Ch54` = NULL WHERE `HacR_HPE1313A:0_Ch54` = "?";
UPDATE wwwend SET `HacR_alignROLL` = NULL WHERE `HacR_alignROLL` = "?";
UPDATE wwwend SET `HacR_alignPITCH` = NULL WHERE `HacR_alignPITCH` = "?";
UPDATE wwwend SET `HacR_alignHPT` = NULL WHERE `HacR_alignHPT` = "?";
UPDATE wwwend SET `Wien angle` = NULL WHERE `Wien angle` = "?";
UPDATE wwwend SET `Helicity Mode ON/OFF Random/Toggle` = NULL WHERE `Helicity Mode ON/OFF Random/Toggle` = "?";
UPDATE wwwend SET `Wien BDL` = NULL WHERE `Wien BDL` = "?";
UPDATE wwwend SET `Wien field` = NULL WHERE `Wien field` = "?";
UPDATE wwwend SET `Laser attenuation Hall A` = NULL WHERE `Laser attenuation Hall A` = "?";
UPDATE wwwend SET `Laser power Hall A` = NULL WHERE `Laser power Hall A` = "?";
UPDATE wwwend SET `Half-wave plate (off=out)` = NULL WHERE `Half-wave plate (off=out)` = "?";
UPDATE wwwend SET `rotating waveplate` = NULL WHERE `rotating waveplate` = "?";
UPDATE wwwend SET `Beam Half-wave plate (off=out)` = NULL WHERE `Beam Half-wave plate (off=out)` = "?";
UPDATE wwwend SET `G0 Helicity Settle Set` = NULL WHERE `G0 Helicity Settle Set` = "?";
UPDATE wwwend SET `G0 Helicity Delay Set` = NULL WHERE `G0 Helicity Delay Set` = "?";
UPDATE wwwend SET `G0 Helicity Pattern Set` = NULL WHERE `G0 Helicity Pattern Set` = "?";
UPDATE wwwend SET `G0 Helicity Settle Read` = NULL WHERE `G0 Helicity Settle Read` = "?";
UPDATE wwwend SET `G0 Helicity Delay Read` = NULL WHERE `G0 Helicity Delay Read` = "?";
UPDATE wwwend SET `G0 Helicity Pattern` = NULL WHERE `G0 Helicity Pattern` = "?";
UPDATE wwwend SET `Target OTR x-position` = NULL WHERE `Target OTR x-position` = "?";
UPDATE wwwend SET `Target OTR y-position` = NULL WHERE `Target OTR y-position` = "?";
UPDATE wwwend SET `Target OTR x-width` = NULL WHERE `Target OTR x-width` = "?";
UPDATE wwwend SET `Target OTR y-width` = NULL WHERE `Target OTR y-width` = "?";
UPDATE wwwend SET `Target OTR data valid flag` = NULL WHERE `Target OTR data valid flag` = "?";
UPDATE wwwend SET `Target OTR In/Out` = NULL WHERE `Target OTR In/Out` = "?";
UPDATE wwwend SET `Arc OTR x-position` = NULL WHERE `Arc OTR x-position` = "?";
UPDATE wwwend SET `Arc OTR y-position` = NULL WHERE `Arc OTR y-position` = "?";
UPDATE wwwend SET `Arc OTR x-width` = NULL WHERE `Arc OTR x-width` = "?";
UPDATE wwwend SET `Arc OTR y-width` = NULL WHERE `Arc OTR y-width` = "?";
UPDATE wwwend SET `Arc OTR data valid flag` = NULL WHERE `Arc OTR data valid flag` = "?";
UPDATE wwwend SET `Arc OTR In/Out` = NULL WHERE `Arc OTR In/Out` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #1` = NULL WHERE `Polarized 3He Target RTD #1` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #2` = NULL WHERE `Polarized 3He Target RTD #2` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #3` = NULL WHERE `Polarized 3He Target RTD #3` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #4` = NULL WHERE `Polarized 3He Target RTD #4` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #5` = NULL WHERE `Polarized 3He Target RTD #5` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #6` = NULL WHERE `Polarized 3He Target RTD #6` = "?";
UPDATE wwwend SET `Polarized 3He Target RTD #7` = NULL WHERE `Polarized 3He Target RTD #7` = "?";
UPDATE wwwend SET `Polarized 3He Ref. Cell RTD #8` = NULL WHERE `Polarized 3He Ref. Cell RTD #8` = "?";
UPDATE wwwend SET `Polarized 3He Ref. Cell RTD #9` = NULL WHERE `Polarized 3He Ref. Cell RTD #9` = "?";
UPDATE wwwend SET `Polarized 3He Ref. Cell RTD #10` = NULL WHERE `Polarized 3He Ref. Cell RTD #10` = "?";
UPDATE wwwend SET `Polarized 3He Target Ref. Cell Gas Pres.` = NULL WHERE `Polarized 3He Target Ref. Cell Gas Pres.` = "?";
UPDATE wwwend SET `Polarized 3He Target Ref. Cell Sys.Vac.` = NULL WHERE `Polarized 3He Target Ref. Cell Sys.Vac.` = "?";
UPDATE wwwend SET `Polarized 3He Target Cooling Jet` = NULL WHERE `Polarized 3He Target Cooling Jet` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN RTD` = NULL WHERE `Polarized 3He Target OVEN RTD` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN SP1 SET` = NULL WHERE `Polarized 3He Target OVEN SP1 SET` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN SP1` = NULL WHERE `Polarized 3He Target OVEN SP1` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN AL1 SET` = NULL WHERE `Polarized 3He Target OVEN AL1 SET` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN AL1` = NULL WHERE `Polarized 3He Target OVEN AL1` = "?";
UPDATE wwwend SET `Polarized 3He Target OVEN AL1 STATUS` = NULL WHERE `Polarized 3He Target OVEN AL1 STATUS` = "?";
UPDATE wwwend SET `Polarized 3He Target Half-Wave Plate DIST` = NULL WHERE `Polarized 3He Target Half-Wave Plate DIST` = "?";
UPDATE wwwend SET `Polarized 3He Target Half-Wave Plate STAT` = NULL WHERE `Polarized 3He Target Half-Wave Plate STAT` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (PA)` = NULL WHERE `Polarized 3He Target Position (PA)` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (POS)` = NULL WHERE `Polarized 3He Target Position (POS)` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (DA)` = NULL WHERE `Polarized 3He Target Position (DA)` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (SS9)` = NULL WHERE `Polarized 3He Target Position (SS9)` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (SA10)` = NULL WHERE `Polarized 3He Target Position (SA10)` = "?";
UPDATE wwwend SET `Polarized 3He Target Position (SA9)` = NULL WHERE `Polarized 3He Target Position (SA9)` = "?";
UPDATE wwwend SET `Polarized 3He Laser#1 State` = NULL WHERE `Polarized 3He Laser#1 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#1 Current` = NULL WHERE `Polarized 3He Laser#1 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#1 Temperature` = NULL WHERE `Polarized 3He Laser#1 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#2 State` = NULL WHERE `Polarized 3He Laser#2 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#2 Current` = NULL WHERE `Polarized 3He Laser#2 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#2 Temperature` = NULL WHERE `Polarized 3He Laser#2 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#3 State` = NULL WHERE `Polarized 3He Laser#3 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#3 Current` = NULL WHERE `Polarized 3He Laser#3 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#3 Temperature` = NULL WHERE `Polarized 3He Laser#3 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#4 State` = NULL WHERE `Polarized 3He Laser#4 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#4 Current` = NULL WHERE `Polarized 3He Laser#4 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#4 Temperature` = NULL WHERE `Polarized 3He Laser#4 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#5 State` = NULL WHERE `Polarized 3He Laser#5 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#5 Current` = NULL WHERE `Polarized 3He Laser#5 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#5 Temperature` = NULL WHERE `Polarized 3He Laser#5 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#6 State` = NULL WHERE `Polarized 3He Laser#6 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#6 Current` = NULL WHERE `Polarized 3He Laser#6 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#6 Temperature` = NULL WHERE `Polarized 3He Laser#6 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Laser#7 State` = NULL WHERE `Polarized 3He Laser#7 State` = "?";
UPDATE wwwend SET `Polarized 3He Laser#7 Current` = NULL WHERE `Polarized 3He Laser#7 Current` = "?";
UPDATE wwwend SET `Polarized 3He Laser#7 Temperature` = NULL WHERE `Polarized 3He Laser#7 Temperature` = "?";
UPDATE wwwend SET `Polarized 3He Coil Current Longitudinal` = NULL WHERE `Polarized 3He Coil Current Longitudinal` = "?";
UPDATE wwwend SET `Polarized 3He Coil Current Transverse` = NULL WHERE `Polarized 3He Coil Current Transverse` = "?";
UPDATE wwwend SET `Transverse gradient coils (A) setup current` = NULL WHERE `Transverse gradient coils (A) setup current` = "?";
UPDATE wwwend SET `Transverse gradient coils (A) readback current` = NULL WHERE `Transverse gradient coils (A) readback current` = "?";
UPDATE wwwend SET `Longitudinal upstream gradient coil (B) setup current` = NULL WHERE `Longitudinal upstream gradient coil (B) setup current` = "?";
UPDATE wwwend SET `Longitudinal upstream gradient coil (B) readback current` = NULL WHERE `Longitudinal upstream gradient coil (B) readback current` = "?";
UPDATE wwwend SET `Longitudinal downstream gradient coil (C) setup current` = NULL WHERE `Longitudinal downstream gradient coil (C) setup current` = "?";
UPDATE wwwend SET `Longitudinal downstream gradient coil (C) readback current` = NULL WHERE `Longitudinal downstream gradient coil (C) readback current` = "?";
UPDATE wwwend SET `Small vertical gradient coils (D) setup current` = NULL WHERE `Small vertical gradient coils (D) setup current` = "?";
UPDATE wwwend SET `Small vertical gradient coils (D) readback current` = NULL WHERE `Small vertical gradient coils (D) readback current` = "?";
UPDATE wwwend SET `Left Arm D1 momentum 2` = NULL WHERE `Left Arm D1 momentum 2` = "?";
UPDATE wwwend SET `Right Arm D1 momentum 2` = NULL WHERE `Right Arm D1 momentum 2` = "?";
UPDATE wwwend SET `Tiefenbach Hall A energy 2` = NULL WHERE `Tiefenbach Hall A energy 2` = "?";
UPDATE wwwend SET `Log book entry time is secs from midnnight April 20` = NULL WHERE `Log book entry time is secs from midnnight April 20` = "?";
UPDATE wwwend SET `Run stop time is secs from midnnight April 20` = NULL WHERE `Run stop time is secs from midnnight April 20` = "?";
UPDATE wwwend SET `kCOMMENTS` = NULL WHERE `kCOMMENTS` = "?";
UPDATE wwwend SET `Number of run summary files for this run` = NULL WHERE `Number of run summary files for this run` = "?";

##### info from start run summary that was stored in the MSS, more complete than halog #####
CREATE TABLE mssend
 (
	`krun` SMALLINT,
	`Log entry time hr` VARCHAR(3),
	`Log entry time min` VARCHAR(3),
	`Log entry time sec` VARCHAR(3),
	`Log entry time mon` VARCHAR(3),
	`Log entry time day` VARCHAR(3),
	`Log entry time yr` VARCHAR(3),
	`Entry number` VARCHAR(3),
	`keyword` VARCHAR(3),
	`User name` VARCHAR(3),
	`kRun_type` VARCHAR(11),
	`kbeam_energy` VARCHAR(8),
	`kbeam_halfwaveplate` VARCHAR(4),
	`kbeam_raster` VARCHAR(4),
	`kcomment_text` VARCHAR(132),
	`kdaq_mode` VARCHAR(13),
	`kkin_name` VARCHAR(5),
	`kleftarm_p` VARCHAR(7),
	`kleftarm_theta` VARCHAR(7),
	`krightarm_p` VARCHAR(8),
	`krightarm_theta` VARCHAR(7),
	`ktarget_halfwaveplate` VARCHAR(4),
	`ktarget_name` VARCHAR(9),
	`ktarget_polarization` VARCHAR(6),
	`ktarget_type` VARCHAR(70),
	`ps1` VARCHAR(5),
	`ps2` VARCHAR(5),
	`ps3` VARCHAR(5),
	`ps4` VARCHAR(5),
	`ps5` VARCHAR(6),
	`ps6` VARCHAR(6),
	`ps7` VARCHAR(6),
	`ps8` VARCHAR(6),
	`EVENTS[0]` VARCHAR(9),
	`EVENTS[+]` VARCHAR(9),
	`EVENTS[-]` VARCHAR(9),
	`TIME  [0]` VARCHAR(9),
	`TIME  [+]` VARCHAR(9),
	`TIME  [-]` VARCHAR(9),
	`LIVE  [0]` VARCHAR(7),
	`LIVE  [+]` VARCHAR(9),
	`LIVE  [-]` VARCHAR(8),
	`T1[0] rate prescale` VARCHAR(9),
	`T1[0] rate real` VARCHAR(9),
	`T2[0] rate prescale` VARCHAR(7),
	`T2[0] rate real` VARCHAR(8),
	`T8[0] rate prescale` VARCHAR(7),
	`T8[0] rate real` VARCHAR(7),
	`T1[+] rate prescale` VARCHAR(9),
	`T1[+] rate real` VARCHAR(9),
	`T2[+] rate prescale` VARCHAR(7),
	`T2[+] rate real` VARCHAR(8),
	`T8[+] rate prescale` VARCHAR(7),
	`T8[+] rate real` VARCHAR(7),
	`T1[-] rate prescale` VARCHAR(9),
	`T1[-] rate real` VARCHAR(9),
	`T2[-] rate prescale` VARCHAR(7),
	`T2[-] rate real` VARCHAR(8),
	`T8[-] rate prescale` VARCHAR(7),
	`T8[-] rate real` VARCHAR(7),
	`T1[0] totals prescale` VARCHAR(10),
	`T1[0] totals real` VARCHAR(12),
	`T2[0] totals prescale` VARCHAR(8),
	`T2[0] totals real` VARCHAR(10),
	`T8[0] totals prescale` VARCHAR(7),
	`T8[0] totals real` VARCHAR(12),
	`T1[+] totals prescale` VARCHAR(10),
	`T1[+] totals real` VARCHAR(12),
	`T2[+] totals prescale` VARCHAR(7),
	`T2[+] totals real` VARCHAR(10),
	`T8[+] totals prescale` VARCHAR(7),
	`T8[+] totals real` VARCHAR(11),
	`T1[-] totals prescale` VARCHAR(10),
	`T1[-] totals real` VARCHAR(12),
	`T2[-] totals prescale` VARCHAR(7),
	`T2[-] totals real` VARCHAR(10),
	`T8[-] totals prescale` VARCHAR(7),
	`T8[-] totals real` VARCHAR(11),
	`BCM x1` VARCHAR(7),
	`BCM x3` VARCHAR(7),
	`BCM x10` VARCHAR(7),
	`BCM u1` VARCHAR(11),
	`BCM u3` VARCHAR(11),
	`BCM u10` VARCHAR(11),
	`BCM d1` VARCHAR(11),
	`BCM d3` VARCHAR(11),
	`BCM d10` VARCHAR(11),
	`BCM u1 [0]` VARCHAR(16),
	`BCM u3 [0]` VARCHAR(16),
	`BCM u10[0]` VARCHAR(16),
	`BCM u1 [+]` VARCHAR(16),
	`BCM u3 [+]` VARCHAR(16),
	`BCM u10[+]` VARCHAR(16),
	`BCM u1 [-]` VARCHAR(16),
	`BCM u3 [-]` VARCHAR(16),
	`BCM u10[-]` VARCHAR(16),
	`BCM d1 [0]` VARCHAR(16),
	`BCM d3 [0]` VARCHAR(16),
	`BCM d10[0]` VARCHAR(16),
	`BCM d1 [+]` VARCHAR(16),
	`BCM d3 [+]` VARCHAR(16),
	`BCM d10[+]` VARCHAR(16),
	`BCM d1 [-]` VARCHAR(16),
	`BCM d3 [-]` VARCHAR(16),
	`BCM d10[-]` VARCHAR(16),
	`Run Number` VARCHAR(3),
	`run mon` VARCHAR(3),
	`run day` VARCHAR(3),
	`run hr` VARCHAR(3),
	`run min` VARCHAR(3),
	`run sec` VARCHAR(3),
	`run yr` VARCHAR(5),
	`Left Arm D1 momentum` VARCHAR(3),
	`Left Arm angle` VARCHAR(8),
	`Right Arm D1 momentum` VARCHAR(3),
	`Right Arm angle` VARCHAR(8),
	`HALLA:p` VARCHAR(8),
	`HALLA:dpp` VARCHAR(13),
	`Tiefenbach Hall A energy` VARCHAR(8),
	`Left Arm mispointing (HPT)` VARCHAR(3),
	`Right Arm mispointing (HPT)` VARCHAR(3),
	`Left Arm Top VDC Current` VARCHAR(11),
	`Left Arm Bottom VDC Current` VARCHAR(11),
	`Right Arm Top VDC Current` VARCHAR(3),
	`Right Arm Bottom VDC Current` VARCHAR(3),
	`Right septum set current` VARCHAR(8),
	`Right septum current readback` VARCHAR(7),
	`Left Arm Q1 power supply current` VARCHAR(3),
	`Left Arm Q1 momentum` VARCHAR(11),
	`Left Arm Q1 gauss meter` VARCHAR(3),
	`Left Arm Q1 power supply polarity` VARCHAR(3),
	`Left Arm Q2 power supply current` VARCHAR(13),
	`Left Arm Q2 momentum` VARCHAR(13),
	`Left Arm Q2 gauss meter` VARCHAR(3),
	`Left Arm Q2 power supply polarity` VARCHAR(9),
	`Left Arm D1 power supply current` VARCHAR(11),
	`Left Arm D1 NMR` VARCHAR(9),
	`Left Arm Q3 power supply current` VARCHAR(12),
	`Left Arm Q3 momentum` VARCHAR(12),
	`Left Arm Q3 gauss meter` VARCHAR(3),
	`Left Arm Q3 power supply polarity` VARCHAR(9),
	`Right Arm Q1 power supply current` VARCHAR(3),
	`Right Arm Q1 momentum` VARCHAR(11),
	`Right Arm Q1 gauss meter` VARCHAR(11),
	`Right Arm Q1 power supply polarity` VARCHAR(3),
	`Right Arm Q2 power supply current` VARCHAR(13),
	`Right Arm Q2 momentum` VARCHAR(13),
	`Right Arm Q2 gauss meter` VARCHAR(11),
	`Right Arm Q2 power supply polarity` VARCHAR(8),
	`Right Arm D1 power supply current` VARCHAR(11),
	`Right Arm D1 NMR` VARCHAR(9),
	`Right Arm Q3 power supply current` VARCHAR(13),
	`Right Arm Q3 momentum` VARCHAR(13),
	`Right Arm Q3 gauss meter` VARCHAR(11),
	`Right Arm Q3 power supply polarity` VARCHAR(9),
	`Average current of the two cavities` VARCHAR(13),
	`Current on Unser monitor` VARCHAR(9),
	`Current on Upstream bcm` VARCHAR(13),
	`Current on Downstream bcm` VARCHAR(12),
	`Upstream Cavity Coefficient` VARCHAR(5),
	`Downstream Cavity Coefficient` VARCHAR(5),
	`Current on IBC0L02 (source)` VARCHAR(11),
	`Hall C Current` BLOB,
	`MBSY1c Hall A Beam energy` VARCHAR(8),
	`MBSY1c magnet current (amp)` VARCHAR(10),
	`MBSY1c Bdl` VARCHAR(12),
	`MBSY3c Hall C Beam energy` VARCHAR(8),
	`Tiefenbach Hall C energy` VARCHAR(8),
	`Delta(E)/E width (MV_AI_DXWID)` VARCHAR(10),
	`IPM1C12.XPOS` VARCHAR(13),
	`IPM1H04A.XPOS` VARCHAR(13),
	`IPM1H04A.YPOS` VARCHAR(13),
	`IPM1H04B.XPOS` VARCHAR(13),
	`IPM1H04B.YPOS` VARCHAR(13),
	`Left Arm Collimator` VARCHAR(10),
	`Left LVDT HPM` VARCHAR(3),
	`Left LVDT VPM` VARCHAR(3),
	`HacL_HPE1313A:0_Ch58` VARCHAR(10),
	`HacL_HPE1313A:0_Ch55` VARCHAR(8),
	`HacL_HPE1313A:0_Ch54` VARCHAR(11),
	`HacL_alignROLL` VARCHAR(3),
	`HacL_alignPITCH` VARCHAR(3),
	`HacL_alignHPT` VARCHAR(3),
	`Right Arm Collimator` VARCHAR(13),
	`Right LVDT HPM` VARCHAR(8),
	`Right LVDT VPM` VARCHAR(6),
	`HacR_HPE1313A:0_Ch58` VARCHAR(10),
	`HacR_HPE1313A:0_Ch55` VARCHAR(8),
	`HacR_HPE1313A:0_Ch54` VARCHAR(10),
	`HacR_alignROLL` VARCHAR(10),
	`HacR_alignPITCH` VARCHAR(13),
	`HacR_alignHPT` VARCHAR(3),
	`Wien angle` VARCHAR(9),
	`Helicity Mode ON/OFF Random/Toggle` VARCHAR(4),
	`Wien BDL` VARCHAR(8),
	`Wien field` VARCHAR(7),
	`Laser attenuation Hall A` VARCHAR(4),
	`Laser power Hall A` VARCHAR(3),
	`Half-wave plate (off=out)` VARCHAR(4),
	`rotating waveplate` VARCHAR(5),
	`Beam Half-wave plate (off=out)` VARCHAR(4),
	`G0 Helicity Settle Set` VARCHAR(9),
	`G0 Helicity Delay Set` VARCHAR(9),
	`G0 Helicity Pattern Set` VARCHAR(8),
	`G0 Helicity Settle Read` VARCHAR(9),
	`G0 Helicity Delay Read` VARCHAR(9),
	`G0 Helicity Pattern` VARCHAR(8),
	`Target OTR x-position` VARCHAR(13),
	`Target OTR y-position` VARCHAR(12),
	`Target OTR x-width` VARCHAR(10),
	`Target OTR y-width` VARCHAR(10),
	`Target OTR data valid flag` VARCHAR(4),
	`Target OTR In/Out` VARCHAR(59),
	`Arc OTR x-position` VARCHAR(11),
	`Arc OTR y-position` VARCHAR(13),
	`Arc OTR x-width` VARCHAR(10),
	`Arc OTR y-width` VARCHAR(10),
	`Arc OTR data valid flag` VARCHAR(4),
	`Arc OTR In/Out` VARCHAR(15),
	`Polarized 3He Target RTD #1` VARCHAR(8),
	`Polarized 3He Target RTD #2` VARCHAR(8),
	`Polarized 3He Target RTD #3` VARCHAR(8),
	`Polarized 3He Target RTD #4` VARCHAR(8),
	`Polarized 3He Target RTD #5` VARCHAR(8),
	`Polarized 3He Target RTD #6` VARCHAR(8),
	`Polarized 3He Target RTD #7` VARCHAR(8),
	`Polarized 3He Ref. Cell RTD #8` VARCHAR(8),
	`Polarized 3He Ref. Cell RTD #9` VARCHAR(8),
	`Polarized 3He Ref. Cell RTD #10` VARCHAR(8),
	`Polarized 3He Target Ref. Cell Gas Pres.` VARCHAR(9),
	`Polarized 3He Target Ref. Cell Sys.Vac.` VARCHAR(10),
	`Polarized 3He Target Cooling Jet` VARCHAR(10),
	`Polarized 3He Target OVEN RTD` VARCHAR(6),
	`Polarized 3He Target OVEN SP1 SET` VARCHAR(4),
	`Polarized 3He Target OVEN SP1` VARCHAR(4),
	`Polarized 3He Target OVEN AL1 SET` VARCHAR(4),
	`Polarized 3He Target OVEN AL1` VARCHAR(4),
	`Polarized 3He Target OVEN AL1 STATUS` VARCHAR(14),
	`Polarized 3He Target Half-Wave Plate DIST` VARCHAR(8),
	`Polarized 3He Target Half-Wave Plate STAT` VARCHAR(8),
	`Polarized 3He Target Position (PA)` VARCHAR(9),
	`Polarized 3He Target Position (POS)` VARCHAR(16),
	`Polarized 3He Target Position (DA)` VARCHAR(9),
	`Polarized 3He Target Position (SS9)` VARCHAR(11),
	`Polarized 3He Target Position (SA10)` VARCHAR(3),
	`Polarized 3He Target Position (SA9)` VARCHAR(3),
	`Polarized 3He Laser#1 State` VARCHAR(3),
	`Polarized 3He Laser#1 Current` VARCHAR(3),
	`Polarized 3He Laser#1 Temperature` VARCHAR(5),
	`Polarized 3He Laser#2 State` VARCHAR(3),
	`Polarized 3He Laser#2 Current` VARCHAR(5),
	`Polarized 3He Laser#2 Temperature` VARCHAR(4),
	`Polarized 3He Laser#3 State` VARCHAR(3),
	`Polarized 3He Laser#3 Current` VARCHAR(5),
	`Polarized 3He Laser#3 Temperature` VARCHAR(5),
	`Polarized 3He Laser#4 State` VARCHAR(3),
	`Polarized 3He Laser#4 Current` VARCHAR(3),
	`Polarized 3He Laser#4 Temperature` VARCHAR(5),
	`Polarized 3He Laser#5 State` VARCHAR(3),
	`Polarized 3He Laser#5 Current` VARCHAR(5),
	`Polarized 3He Laser#5 Temperature` VARCHAR(5),
	`Polarized 3He Laser#6 State` VARCHAR(3),
	`Polarized 3He Laser#6 Current` VARCHAR(5),
	`Polarized 3He Laser#6 Temperature` VARCHAR(5),
	`Polarized 3He Laser#7 State` VARCHAR(3),
	`Polarized 3He Laser#7 Current` VARCHAR(3),
	`Polarized 3He Laser#7 Temperature` VARCHAR(4),
	`Polarized 3He Coil Current Longitudinal` VARCHAR(118),
	`Polarized 3He Coil Current Transverse` VARCHAR(7),
	`Transverse gradient coils (A) setup current` VARCHAR(9),
	`Transverse gradient coils (A) readback current` VARCHAR(12),
	`Longitudinal upstream gradient coil (B) setup current` VARCHAR(8),
	`Longitudinal upstream gradient coil (B) readback current` VARCHAR(13),
	`Longitudinal downstream gradient coil (C) setup current` VARCHAR(8),
	`Longitudinal downstream gradient coil (C) readback current` VARCHAR(13),
	`Small vertical gradient coils (D) setup current` VARCHAR(9),
	`Small vertical gradient coils (D) readback current` VARCHAR(13),
	`Left Arm D1 momentum 2` VARCHAR(9),
	`Right Arm D1 momentum 2` VARCHAR(9),
	`Tiefenbach Hall A energy 2` VARCHAR(8),
	`Log book entry time is secs from midnnight April 20` VARCHAR(3),
	`Run stop time is secs from midnnight April 20` VARCHAR(9),
	`kCOMMENTS` VARCHAR(135),
	`Number of run summary files for this run` VARCHAR(2),
	INDEX (krun)	
 );
LOAD DATA LOCAL INFILE '~/gdh/runfiles_gdh_from_mss/rightend_mss.raw' INTO TABLE mssend;

##### translating to MySQL NULL value #####
UPDATE mssend SET `krun` = NULL WHERE `krun` = "?";
UPDATE mssend SET `Log entry time hr` = NULL WHERE `Log entry time hr` = "?";
UPDATE mssend SET `Log entry time min` = NULL WHERE `Log entry time min` = "?";
UPDATE mssend SET `Log entry time sec` = NULL WHERE `Log entry time sec` = "?";
UPDATE mssend SET `Log entry time mon` = NULL WHERE `Log entry time mon` = "?";
UPDATE mssend SET `Log entry time day` = NULL WHERE `Log entry time day` = "?";
UPDATE mssend SET `Log entry time yr` = NULL WHERE `Log entry time yr` = "?";
UPDATE mssend SET `Entry number` = NULL WHERE `Entry number` = "?";
UPDATE mssend SET `keyword` = NULL WHERE `keyword` = "?";
UPDATE mssend SET `User name` = NULL WHERE `User name` = "?";
UPDATE mssend SET `kRun_type` = NULL WHERE `kRun_type` = "?";
UPDATE mssend SET `kbeam_energy` = NULL WHERE `kbeam_energy` = "?";
UPDATE mssend SET `kbeam_halfwaveplate` = NULL WHERE `kbeam_halfwaveplate` = "?";
UPDATE mssend SET `kbeam_raster` = NULL WHERE `kbeam_raster` = "?";
UPDATE mssend SET `kcomment_text` = NULL WHERE `kcomment_text` = "?";
UPDATE mssend SET `kdaq_mode` = NULL WHERE `kdaq_mode` = "?";
UPDATE mssend SET `kkin_name` = NULL WHERE `kkin_name` = "?";
UPDATE mssend SET `kleftarm_p` = NULL WHERE `kleftarm_p` = "?";
UPDATE mssend SET `kleftarm_theta` = NULL WHERE `kleftarm_theta` = "?";
UPDATE mssend SET `krightarm_p` = NULL WHERE `krightarm_p` = "?";
UPDATE mssend SET `krightarm_theta` = NULL WHERE `krightarm_theta` = "?";
UPDATE mssend SET `ktarget_halfwaveplate` = NULL WHERE `ktarget_halfwaveplate` = "?";
UPDATE mssend SET `ktarget_name` = NULL WHERE `ktarget_name` = "?";
UPDATE mssend SET `ktarget_polarization` = NULL WHERE `ktarget_polarization` = "?";
UPDATE mssend SET `ktarget_type` = NULL WHERE `ktarget_type` = "?";
UPDATE mssend SET `ps1` = NULL WHERE `ps1` = "?";
UPDATE mssend SET `ps2` = NULL WHERE `ps2` = "?";
UPDATE mssend SET `ps3` = NULL WHERE `ps3` = "?";
UPDATE mssend SET `ps4` = NULL WHERE `ps4` = "?";
UPDATE mssend SET `ps5` = NULL WHERE `ps5` = "?";
UPDATE mssend SET `ps6` = NULL WHERE `ps6` = "?";
UPDATE mssend SET `ps7` = NULL WHERE `ps7` = "?";
UPDATE mssend SET `ps8` = NULL WHERE `ps8` = "?";
UPDATE mssend SET `EVENTS[0]` = NULL WHERE `EVENTS[0]` = "?";
UPDATE mssend SET `EVENTS[+]` = NULL WHERE `EVENTS[+]` = "?";
UPDATE mssend SET `EVENTS[-]` = NULL WHERE `EVENTS[-]` = "?";
UPDATE mssend SET `TIME  [0]` = NULL WHERE `TIME  [0]` = "?";
UPDATE mssend SET `TIME  [+]` = NULL WHERE `TIME  [+]` = "?";
UPDATE mssend SET `TIME  [-]` = NULL WHERE `TIME  [-]` = "?";
UPDATE mssend SET `LIVE  [0]` = NULL WHERE `LIVE  [0]` = "?";
UPDATE mssend SET `LIVE  [+]` = NULL WHERE `LIVE  [+]` = "?";
UPDATE mssend SET `LIVE  [-]` = NULL WHERE `LIVE  [-]` = "?";
UPDATE mssend SET `T1[0] rate prescale` = NULL WHERE `T1[0] rate prescale` = "?";
UPDATE mssend SET `T1[0] rate real` = NULL WHERE `T1[0] rate real` = "?";
UPDATE mssend SET `T2[0] rate prescale` = NULL WHERE `T2[0] rate prescale` = "?";
UPDATE mssend SET `T2[0] rate real` = NULL WHERE `T2[0] rate real` = "?";
UPDATE mssend SET `T8[0] rate prescale` = NULL WHERE `T8[0] rate prescale` = "?";
UPDATE mssend SET `T8[0] rate real` = NULL WHERE `T8[0] rate real` = "?";
UPDATE mssend SET `T1[+] rate prescale` = NULL WHERE `T1[+] rate prescale` = "?";
UPDATE mssend SET `T1[+] rate real` = NULL WHERE `T1[+] rate real` = "?";
UPDATE mssend SET `T2[+] rate prescale` = NULL WHERE `T2[+] rate prescale` = "?";
UPDATE mssend SET `T2[+] rate real` = NULL WHERE `T2[+] rate real` = "?";
UPDATE mssend SET `T8[+] rate prescale` = NULL WHERE `T8[+] rate prescale` = "?";
UPDATE mssend SET `T8[+] rate real` = NULL WHERE `T8[+] rate real` = "?";
UPDATE mssend SET `T1[-] rate prescale` = NULL WHERE `T1[-] rate prescale` = "?";
UPDATE mssend SET `T1[-] rate real` = NULL WHERE `T1[-] rate real` = "?";
UPDATE mssend SET `T2[-] rate prescale` = NULL WHERE `T2[-] rate prescale` = "?";
UPDATE mssend SET `T2[-] rate real` = NULL WHERE `T2[-] rate real` = "?";
UPDATE mssend SET `T8[-] rate prescale` = NULL WHERE `T8[-] rate prescale` = "?";
UPDATE mssend SET `T8[-] rate real` = NULL WHERE `T8[-] rate real` = "?";
UPDATE mssend SET `T1[0] totals prescale` = NULL WHERE `T1[0] totals prescale` = "?";
UPDATE mssend SET `T1[0] totals real` = NULL WHERE `T1[0] totals real` = "?";
UPDATE mssend SET `T2[0] totals prescale` = NULL WHERE `T2[0] totals prescale` = "?";
UPDATE mssend SET `T2[0] totals real` = NULL WHERE `T2[0] totals real` = "?";
UPDATE mssend SET `T8[0] totals prescale` = NULL WHERE `T8[0] totals prescale` = "?";
UPDATE mssend SET `T8[0] totals real` = NULL WHERE `T8[0] totals real` = "?";
UPDATE mssend SET `T1[+] totals prescale` = NULL WHERE `T1[+] totals prescale` = "?";
UPDATE mssend SET `T1[+] totals real` = NULL WHERE `T1[+] totals real` = "?";
UPDATE mssend SET `T2[+] totals prescale` = NULL WHERE `T2[+] totals prescale` = "?";
UPDATE mssend SET `T2[+] totals real` = NULL WHERE `T2[+] totals real` = "?";
UPDATE mssend SET `T8[+] totals prescale` = NULL WHERE `T8[+] totals prescale` = "?";
UPDATE mssend SET `T8[+] totals real` = NULL WHERE `T8[+] totals real` = "?";
UPDATE mssend SET `T1[-] totals prescale` = NULL WHERE `T1[-] totals prescale` = "?";
UPDATE mssend SET `T1[-] totals real` = NULL WHERE `T1[-] totals real` = "?";
UPDATE mssend SET `T2[-] totals prescale` = NULL WHERE `T2[-] totals prescale` = "?";
UPDATE mssend SET `T2[-] totals real` = NULL WHERE `T2[-] totals real` = "?";
UPDATE mssend SET `T8[-] totals prescale` = NULL WHERE `T8[-] totals prescale` = "?";
UPDATE mssend SET `T8[-] totals real` = NULL WHERE `T8[-] totals real` = "?";
UPDATE mssend SET `BCM x1` = NULL WHERE `BCM x1` = "?";
UPDATE mssend SET `BCM x3` = NULL WHERE `BCM x3` = "?";
UPDATE mssend SET `BCM x10` = NULL WHERE `BCM x10` = "?";
UPDATE mssend SET `BCM u1` = NULL WHERE `BCM u1` = "?";
UPDATE mssend SET `BCM u3` = NULL WHERE `BCM u3` = "?";
UPDATE mssend SET `BCM u10` = NULL WHERE `BCM u10` = "?";
UPDATE mssend SET `BCM d1` = NULL WHERE `BCM d1` = "?";
UPDATE mssend SET `BCM d3` = NULL WHERE `BCM d3` = "?";
UPDATE mssend SET `BCM d10` = NULL WHERE `BCM d10` = "?";
UPDATE mssend SET `BCM u1 [0]` = NULL WHERE `BCM u1 [0]` = "?";
UPDATE mssend SET `BCM u3 [0]` = NULL WHERE `BCM u3 [0]` = "?";
UPDATE mssend SET `BCM u10[0]` = NULL WHERE `BCM u10[0]` = "?";
UPDATE mssend SET `BCM u1 [+]` = NULL WHERE `BCM u1 [+]` = "?";
UPDATE mssend SET `BCM u3 [+]` = NULL WHERE `BCM u3 [+]` = "?";
UPDATE mssend SET `BCM u10[+]` = NULL WHERE `BCM u10[+]` = "?";
UPDATE mssend SET `BCM u1 [-]` = NULL WHERE `BCM u1 [-]` = "?";
UPDATE mssend SET `BCM u3 [-]` = NULL WHERE `BCM u3 [-]` = "?";
UPDATE mssend SET `BCM u10[-]` = NULL WHERE `BCM u10[-]` = "?";
UPDATE mssend SET `BCM d1 [0]` = NULL WHERE `BCM d1 [0]` = "?";
UPDATE mssend SET `BCM d3 [0]` = NULL WHERE `BCM d3 [0]` = "?";
UPDATE mssend SET `BCM d10[0]` = NULL WHERE `BCM d10[0]` = "?";
UPDATE mssend SET `BCM d1 [+]` = NULL WHERE `BCM d1 [+]` = "?";
UPDATE mssend SET `BCM d3 [+]` = NULL WHERE `BCM d3 [+]` = "?";
UPDATE mssend SET `BCM d10[+]` = NULL WHERE `BCM d10[+]` = "?";
UPDATE mssend SET `BCM d1 [-]` = NULL WHERE `BCM d1 [-]` = "?";
UPDATE mssend SET `BCM d3 [-]` = NULL WHERE `BCM d3 [-]` = "?";
UPDATE mssend SET `BCM d10[-]` = NULL WHERE `BCM d10[-]` = "?";
UPDATE mssend SET `Run Number` = NULL WHERE `Run Number` = "?";
UPDATE mssend SET `run mon` = NULL WHERE `run mon` = "?";
UPDATE mssend SET `run day` = NULL WHERE `run day` = "?";
UPDATE mssend SET `run hr` = NULL WHERE `run hr` = "?";
UPDATE mssend SET `run min` = NULL WHERE `run min` = "?";
UPDATE mssend SET `run sec` = NULL WHERE `run sec` = "?";
UPDATE mssend SET `run yr` = NULL WHERE `run yr` = "?";
UPDATE mssend SET `Left Arm D1 momentum` = NULL WHERE `Left Arm D1 momentum` = "?";
UPDATE mssend SET `Left Arm angle` = NULL WHERE `Left Arm angle` = "?";
UPDATE mssend SET `Right Arm D1 momentum` = NULL WHERE `Right Arm D1 momentum` = "?";
UPDATE mssend SET `Right Arm angle` = NULL WHERE `Right Arm angle` = "?";
UPDATE mssend SET `HALLA:p` = NULL WHERE `HALLA:p` = "?";
UPDATE mssend SET `HALLA:dpp` = NULL WHERE `HALLA:dpp` = "?";
UPDATE mssend SET `Tiefenbach Hall A energy` = NULL WHERE `Tiefenbach Hall A energy` = "?";
UPDATE mssend SET `Left Arm mispointing (HPT)` = NULL WHERE `Left Arm mispointing (HPT)` = "?";
UPDATE mssend SET `Right Arm mispointing (HPT)` = NULL WHERE `Right Arm mispointing (HPT)` = "?";
UPDATE mssend SET `Left Arm Top VDC Current` = NULL WHERE `Left Arm Top VDC Current` = "?";
UPDATE mssend SET `Left Arm Bottom VDC Current` = NULL WHERE `Left Arm Bottom VDC Current` = "?";
UPDATE mssend SET `Right Arm Top VDC Current` = NULL WHERE `Right Arm Top VDC Current` = "?";
UPDATE mssend SET `Right Arm Bottom VDC Current` = NULL WHERE `Right Arm Bottom VDC Current` = "?";
UPDATE mssend SET `Right septum set current` = NULL WHERE `Right septum set current` = "?";
UPDATE mssend SET `Right septum current readback` = NULL WHERE `Right septum current readback` = "?";
UPDATE mssend SET `Left Arm Q1 power supply current` = NULL WHERE `Left Arm Q1 power supply current` = "?";
UPDATE mssend SET `Left Arm Q1 momentum` = NULL WHERE `Left Arm Q1 momentum` = "?";
UPDATE mssend SET `Left Arm Q1 gauss meter` = NULL WHERE `Left Arm Q1 gauss meter` = "?";
UPDATE mssend SET `Left Arm Q1 power supply polarity` = NULL WHERE `Left Arm Q1 power supply polarity` = "?";
UPDATE mssend SET `Left Arm Q2 power supply current` = NULL WHERE `Left Arm Q2 power supply current` = "?";
UPDATE mssend SET `Left Arm Q2 momentum` = NULL WHERE `Left Arm Q2 momentum` = "?";
UPDATE mssend SET `Left Arm Q2 gauss meter` = NULL WHERE `Left Arm Q2 gauss meter` = "?";
UPDATE mssend SET `Left Arm Q2 power supply polarity` = NULL WHERE `Left Arm Q2 power supply polarity` = "?";
UPDATE mssend SET `Left Arm D1 power supply current` = NULL WHERE `Left Arm D1 power supply current` = "?";
UPDATE mssend SET `Left Arm D1 NMR` = NULL WHERE `Left Arm D1 NMR` = "?";
UPDATE mssend SET `Left Arm Q3 power supply current` = NULL WHERE `Left Arm Q3 power supply current` = "?";
UPDATE mssend SET `Left Arm Q3 momentum` = NULL WHERE `Left Arm Q3 momentum` = "?";
UPDATE mssend SET `Left Arm Q3 gauss meter` = NULL WHERE `Left Arm Q3 gauss meter` = "?";
UPDATE mssend SET `Left Arm Q3 power supply polarity` = NULL WHERE `Left Arm Q3 power supply polarity` = "?";
UPDATE mssend SET `Right Arm Q1 power supply current` = NULL WHERE `Right Arm Q1 power supply current` = "?";
UPDATE mssend SET `Right Arm Q1 momentum` = NULL WHERE `Right Arm Q1 momentum` = "?";
UPDATE mssend SET `Right Arm Q1 gauss meter` = NULL WHERE `Right Arm Q1 gauss meter` = "?";
UPDATE mssend SET `Right Arm Q1 power supply polarity` = NULL WHERE `Right Arm Q1 power supply polarity` = "?";
UPDATE mssend SET `Right Arm Q2 power supply current` = NULL WHERE `Right Arm Q2 power supply current` = "?";
UPDATE mssend SET `Right Arm Q2 momentum` = NULL WHERE `Right Arm Q2 momentum` = "?";
UPDATE mssend SET `Right Arm Q2 gauss meter` = NULL WHERE `Right Arm Q2 gauss meter` = "?";
UPDATE mssend SET `Right Arm Q2 power supply polarity` = NULL WHERE `Right Arm Q2 power supply polarity` = "?";
UPDATE mssend SET `Right Arm D1 power supply current` = NULL WHERE `Right Arm D1 power supply current` = "?";
UPDATE mssend SET `Right Arm D1 NMR` = NULL WHERE `Right Arm D1 NMR` = "?";
UPDATE mssend SET `Right Arm Q3 power supply current` = NULL WHERE `Right Arm Q3 power supply current` = "?";
UPDATE mssend SET `Right Arm Q3 momentum` = NULL WHERE `Right Arm Q3 momentum` = "?";
UPDATE mssend SET `Right Arm Q3 gauss meter` = NULL WHERE `Right Arm Q3 gauss meter` = "?";
UPDATE mssend SET `Right Arm Q3 power supply polarity` = NULL WHERE `Right Arm Q3 power supply polarity` = "?";
UPDATE mssend SET `Average current of the two cavities` = NULL WHERE `Average current of the two cavities` = "?";
UPDATE mssend SET `Current on Unser monitor` = NULL WHERE `Current on Unser monitor` = "?";
UPDATE mssend SET `Current on Upstream bcm` = NULL WHERE `Current on Upstream bcm` = "?";
UPDATE mssend SET `Current on Downstream bcm` = NULL WHERE `Current on Downstream bcm` = "?";
UPDATE mssend SET `Upstream Cavity Coefficient` = NULL WHERE `Upstream Cavity Coefficient` = "?";
UPDATE mssend SET `Downstream Cavity Coefficient` = NULL WHERE `Downstream Cavity Coefficient` = "?";
UPDATE mssend SET `Current on IBC0L02 (source)` = NULL WHERE `Current on IBC0L02 (source)` = "?";
UPDATE mssend SET `Hall C Current` = NULL WHERE `Hall C Current` = "?";
UPDATE mssend SET `MBSY1c Hall A Beam energy` = NULL WHERE `MBSY1c Hall A Beam energy` = "?";
UPDATE mssend SET `MBSY1c magnet current (amp)` = NULL WHERE `MBSY1c magnet current (amp)` = "?";
UPDATE mssend SET `MBSY1c Bdl` = NULL WHERE `MBSY1c Bdl` = "?";
UPDATE mssend SET `MBSY3c Hall C Beam energy` = NULL WHERE `MBSY3c Hall C Beam energy` = "?";
UPDATE mssend SET `Tiefenbach Hall C energy` = NULL WHERE `Tiefenbach Hall C energy` = "?";
UPDATE mssend SET `Delta(E)/E width (MV_AI_DXWID)` = NULL WHERE `Delta(E)/E width (MV_AI_DXWID)` = "?";
UPDATE mssend SET `IPM1C12.XPOS` = NULL WHERE `IPM1C12.XPOS` = "?";
UPDATE mssend SET `IPM1H04A.XPOS` = NULL WHERE `IPM1H04A.XPOS` = "?";
UPDATE mssend SET `IPM1H04A.YPOS` = NULL WHERE `IPM1H04A.YPOS` = "?";
UPDATE mssend SET `IPM1H04B.XPOS` = NULL WHERE `IPM1H04B.XPOS` = "?";
UPDATE mssend SET `IPM1H04B.YPOS` = NULL WHERE `IPM1H04B.YPOS` = "?";
UPDATE mssend SET `Left Arm Collimator` = NULL WHERE `Left Arm Collimator` = "?";
UPDATE mssend SET `Left LVDT HPM` = NULL WHERE `Left LVDT HPM` = "?";
UPDATE mssend SET `Left LVDT VPM` = NULL WHERE `Left LVDT VPM` = "?";
UPDATE mssend SET `HacL_HPE1313A:0_Ch58` = NULL WHERE `HacL_HPE1313A:0_Ch58` = "?";
UPDATE mssend SET `HacL_HPE1313A:0_Ch55` = NULL WHERE `HacL_HPE1313A:0_Ch55` = "?";
UPDATE mssend SET `HacL_HPE1313A:0_Ch54` = NULL WHERE `HacL_HPE1313A:0_Ch54` = "?";
UPDATE mssend SET `HacL_alignROLL` = NULL WHERE `HacL_alignROLL` = "?";
UPDATE mssend SET `HacL_alignPITCH` = NULL WHERE `HacL_alignPITCH` = "?";
UPDATE mssend SET `HacL_alignHPT` = NULL WHERE `HacL_alignHPT` = "?";
UPDATE mssend SET `Right Arm Collimator` = NULL WHERE `Right Arm Collimator` = "?";
UPDATE mssend SET `Right LVDT HPM` = NULL WHERE `Right LVDT HPM` = "?";
UPDATE mssend SET `Right LVDT VPM` = NULL WHERE `Right LVDT VPM` = "?";
UPDATE mssend SET `HacR_HPE1313A:0_Ch58` = NULL WHERE `HacR_HPE1313A:0_Ch58` = "?";
UPDATE mssend SET `HacR_HPE1313A:0_Ch55` = NULL WHERE `HacR_HPE1313A:0_Ch55` = "?";
UPDATE mssend SET `HacR_HPE1313A:0_Ch54` = NULL WHERE `HacR_HPE1313A:0_Ch54` = "?";
UPDATE mssend SET `HacR_alignROLL` = NULL WHERE `HacR_alignROLL` = "?";
UPDATE mssend SET `HacR_alignPITCH` = NULL WHERE `HacR_alignPITCH` = "?";
UPDATE mssend SET `HacR_alignHPT` = NULL WHERE `HacR_alignHPT` = "?";
UPDATE mssend SET `Wien angle` = NULL WHERE `Wien angle` = "?";
UPDATE mssend SET `Helicity Mode ON/OFF Random/Toggle` = NULL WHERE `Helicity Mode ON/OFF Random/Toggle` = "?";
UPDATE mssend SET `Wien BDL` = NULL WHERE `Wien BDL` = "?";
UPDATE mssend SET `Wien field` = NULL WHERE `Wien field` = "?";
UPDATE mssend SET `Laser attenuation Hall A` = NULL WHERE `Laser attenuation Hall A` = "?";
UPDATE mssend SET `Laser power Hall A` = NULL WHERE `Laser power Hall A` = "?";
UPDATE mssend SET `Half-wave plate (off=out)` = NULL WHERE `Half-wave plate (off=out)` = "?";
UPDATE mssend SET `rotating waveplate` = NULL WHERE `rotating waveplate` = "?";
UPDATE mssend SET `Beam Half-wave plate (off=out)` = NULL WHERE `Beam Half-wave plate (off=out)` = "?";
UPDATE mssend SET `G0 Helicity Settle Set` = NULL WHERE `G0 Helicity Settle Set` = "?";
UPDATE mssend SET `G0 Helicity Delay Set` = NULL WHERE `G0 Helicity Delay Set` = "?";
UPDATE mssend SET `G0 Helicity Pattern Set` = NULL WHERE `G0 Helicity Pattern Set` = "?";
UPDATE mssend SET `G0 Helicity Settle Read` = NULL WHERE `G0 Helicity Settle Read` = "?";
UPDATE mssend SET `G0 Helicity Delay Read` = NULL WHERE `G0 Helicity Delay Read` = "?";
UPDATE mssend SET `G0 Helicity Pattern` = NULL WHERE `G0 Helicity Pattern` = "?";
UPDATE mssend SET `Target OTR x-position` = NULL WHERE `Target OTR x-position` = "?";
UPDATE mssend SET `Target OTR y-position` = NULL WHERE `Target OTR y-position` = "?";
UPDATE mssend SET `Target OTR x-width` = NULL WHERE `Target OTR x-width` = "?";
UPDATE mssend SET `Target OTR y-width` = NULL WHERE `Target OTR y-width` = "?";
UPDATE mssend SET `Target OTR data valid flag` = NULL WHERE `Target OTR data valid flag` = "?";
UPDATE mssend SET `Target OTR In/Out` = NULL WHERE `Target OTR In/Out` = "?";
UPDATE mssend SET `Arc OTR x-position` = NULL WHERE `Arc OTR x-position` = "?";
UPDATE mssend SET `Arc OTR y-position` = NULL WHERE `Arc OTR y-position` = "?";
UPDATE mssend SET `Arc OTR x-width` = NULL WHERE `Arc OTR x-width` = "?";
UPDATE mssend SET `Arc OTR y-width` = NULL WHERE `Arc OTR y-width` = "?";
UPDATE mssend SET `Arc OTR data valid flag` = NULL WHERE `Arc OTR data valid flag` = "?";
UPDATE mssend SET `Arc OTR In/Out` = NULL WHERE `Arc OTR In/Out` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #1` = NULL WHERE `Polarized 3He Target RTD #1` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #2` = NULL WHERE `Polarized 3He Target RTD #2` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #3` = NULL WHERE `Polarized 3He Target RTD #3` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #4` = NULL WHERE `Polarized 3He Target RTD #4` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #5` = NULL WHERE `Polarized 3He Target RTD #5` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #6` = NULL WHERE `Polarized 3He Target RTD #6` = "?";
UPDATE mssend SET `Polarized 3He Target RTD #7` = NULL WHERE `Polarized 3He Target RTD #7` = "?";
UPDATE mssend SET `Polarized 3He Ref. Cell RTD #8` = NULL WHERE `Polarized 3He Ref. Cell RTD #8` = "?";
UPDATE mssend SET `Polarized 3He Ref. Cell RTD #9` = NULL WHERE `Polarized 3He Ref. Cell RTD #9` = "?";
UPDATE mssend SET `Polarized 3He Ref. Cell RTD #10` = NULL WHERE `Polarized 3He Ref. Cell RTD #10` = "?";
UPDATE mssend SET `Polarized 3He Target Ref. Cell Gas Pres.` = NULL WHERE `Polarized 3He Target Ref. Cell Gas Pres.` = "?";
UPDATE mssend SET `Polarized 3He Target Ref. Cell Sys.Vac.` = NULL WHERE `Polarized 3He Target Ref. Cell Sys.Vac.` = "?";
UPDATE mssend SET `Polarized 3He Target Cooling Jet` = NULL WHERE `Polarized 3He Target Cooling Jet` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN RTD` = NULL WHERE `Polarized 3He Target OVEN RTD` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN SP1 SET` = NULL WHERE `Polarized 3He Target OVEN SP1 SET` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN SP1` = NULL WHERE `Polarized 3He Target OVEN SP1` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN AL1 SET` = NULL WHERE `Polarized 3He Target OVEN AL1 SET` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN AL1` = NULL WHERE `Polarized 3He Target OVEN AL1` = "?";
UPDATE mssend SET `Polarized 3He Target OVEN AL1 STATUS` = NULL WHERE `Polarized 3He Target OVEN AL1 STATUS` = "?";
UPDATE mssend SET `Polarized 3He Target Half-Wave Plate DIST` = NULL WHERE `Polarized 3He Target Half-Wave Plate DIST` = "?";
UPDATE mssend SET `Polarized 3He Target Half-Wave Plate STAT` = NULL WHERE `Polarized 3He Target Half-Wave Plate STAT` = "?";
UPDATE mssend SET `Polarized 3He Target Position (PA)` = NULL WHERE `Polarized 3He Target Position (PA)` = "?";
UPDATE mssend SET `Polarized 3He Target Position (POS)` = NULL WHERE `Polarized 3He Target Position (POS)` = "?";
UPDATE mssend SET `Polarized 3He Target Position (DA)` = NULL WHERE `Polarized 3He Target Position (DA)` = "?";
UPDATE mssend SET `Polarized 3He Target Position (SS9)` = NULL WHERE `Polarized 3He Target Position (SS9)` = "?";
UPDATE mssend SET `Polarized 3He Target Position (SA10)` = NULL WHERE `Polarized 3He Target Position (SA10)` = "?";
UPDATE mssend SET `Polarized 3He Target Position (SA9)` = NULL WHERE `Polarized 3He Target Position (SA9)` = "?";
UPDATE mssend SET `Polarized 3He Laser#1 State` = NULL WHERE `Polarized 3He Laser#1 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#1 Current` = NULL WHERE `Polarized 3He Laser#1 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#1 Temperature` = NULL WHERE `Polarized 3He Laser#1 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#2 State` = NULL WHERE `Polarized 3He Laser#2 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#2 Current` = NULL WHERE `Polarized 3He Laser#2 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#2 Temperature` = NULL WHERE `Polarized 3He Laser#2 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#3 State` = NULL WHERE `Polarized 3He Laser#3 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#3 Current` = NULL WHERE `Polarized 3He Laser#3 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#3 Temperature` = NULL WHERE `Polarized 3He Laser#3 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#4 State` = NULL WHERE `Polarized 3He Laser#4 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#4 Current` = NULL WHERE `Polarized 3He Laser#4 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#4 Temperature` = NULL WHERE `Polarized 3He Laser#4 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#5 State` = NULL WHERE `Polarized 3He Laser#5 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#5 Current` = NULL WHERE `Polarized 3He Laser#5 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#5 Temperature` = NULL WHERE `Polarized 3He Laser#5 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#6 State` = NULL WHERE `Polarized 3He Laser#6 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#6 Current` = NULL WHERE `Polarized 3He Laser#6 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#6 Temperature` = NULL WHERE `Polarized 3He Laser#6 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Laser#7 State` = NULL WHERE `Polarized 3He Laser#7 State` = "?";
UPDATE mssend SET `Polarized 3He Laser#7 Current` = NULL WHERE `Polarized 3He Laser#7 Current` = "?";
UPDATE mssend SET `Polarized 3He Laser#7 Temperature` = NULL WHERE `Polarized 3He Laser#7 Temperature` = "?";
UPDATE mssend SET `Polarized 3He Coil Current Longitudinal` = NULL WHERE `Polarized 3He Coil Current Longitudinal` = "?";
UPDATE mssend SET `Polarized 3He Coil Current Transverse` = NULL WHERE `Polarized 3He Coil Current Transverse` = "?";
UPDATE mssend SET `Transverse gradient coils (A) setup current` = NULL WHERE `Transverse gradient coils (A) setup current` = "?";
UPDATE mssend SET `Transverse gradient coils (A) readback current` = NULL WHERE `Transverse gradient coils (A) readback current` = "?";
UPDATE mssend SET `Longitudinal upstream gradient coil (B) setup current` = NULL WHERE `Longitudinal upstream gradient coil (B) setup current` = "?";
UPDATE mssend SET `Longitudinal upstream gradient coil (B) readback current` = NULL WHERE `Longitudinal upstream gradient coil (B) readback current` = "?";
UPDATE mssend SET `Longitudinal downstream gradient coil (C) setup current` = NULL WHERE `Longitudinal downstream gradient coil (C) setup current` = "?";
UPDATE mssend SET `Longitudinal downstream gradient coil (C) readback current` = NULL WHERE `Longitudinal downstream gradient coil (C) readback current` = "?";
UPDATE mssend SET `Small vertical gradient coils (D) setup current` = NULL WHERE `Small vertical gradient coils (D) setup current` = "?";
UPDATE mssend SET `Small vertical gradient coils (D) readback current` = NULL WHERE `Small vertical gradient coils (D) readback current` = "?";
UPDATE mssend SET `Left Arm D1 momentum 2` = NULL WHERE `Left Arm D1 momentum 2` = "?";
UPDATE mssend SET `Right Arm D1 momentum 2` = NULL WHERE `Right Arm D1 momentum 2` = "?";
UPDATE mssend SET `Tiefenbach Hall A energy 2` = NULL WHERE `Tiefenbach Hall A energy 2` = "?";
UPDATE mssend SET `Log book entry time is secs from midnnight April 20` = NULL WHERE `Log book entry time is secs from midnnight April 20` = "?";
UPDATE mssend SET `Run stop time is secs from midnnight April 20` = NULL WHERE `Run stop time is secs from midnnight April 20` = "?";
UPDATE mssend SET `kCOMMENTS` = NULL WHERE `kCOMMENTS` = "?";
UPDATE mssend SET `Number of run summary files for this run` = NULL WHERE `Number of run summary files for this run` = "?";

##### info from start run summary that was stored in the MSS, more complete than halog #####
CREATE TABLE mssbeg
 (
	`krun` SMALLINT,
	`Log entry time hr` VARCHAR(3),
	`Log entry time min` VARCHAR(3),
	`Log entry time sec` VARCHAR(3),
	`Log entry time mon` VARCHAR(3),
	`Log entry time day` VARCHAR(3),
	`Log entry time yr` VARCHAR(3),
	`Entry number` VARCHAR(3),
	`keyword` VARCHAR(3),
	`User name` VARCHAR(3),
	`kRun_type` VARCHAR(3),
	`kbeam_energy` VARCHAR(3),
	`kbeam_halfwaveplate` VARCHAR(3),
	`kbeam_raster` VARCHAR(3),
	`kcomment_text` VARCHAR(3),
	`kdaq_mode` VARCHAR(3),
	`kkin_name` VARCHAR(3),
	`kleftarm_p` VARCHAR(3),
	`kleftarm_theta` VARCHAR(3),
	`krightarm_p` VARCHAR(3),
	`krightarm_theta` VARCHAR(3),
	`ktarget_halfwaveplate` VARCHAR(3),
	`ktarget_name` VARCHAR(3),
	`ktarget_polarization` VARCHAR(3),
	`ktarget_type` VARCHAR(3),
	`ps1` VARCHAR(5),
	`ps2` VARCHAR(5),
	`ps3` VARCHAR(5),
	`ps4` VARCHAR(5),
	`ps5` VARCHAR(6),
	`ps6` VARCHAR(6),
	`ps7` VARCHAR(6),
	`ps8` VARCHAR(6),
	`EVENTS[0]` VARCHAR(3),
	`EVENTS[+]` VARCHAR(3),
	`EVENTS[-]` VARCHAR(3),
	`TIME  [0]` VARCHAR(3),
	`TIME  [+]` VARCHAR(3),
	`TIME  [-]` VARCHAR(3),
	`LIVE  [0]` VARCHAR(3),
	`LIVE  [+]` VARCHAR(3),
	`LIVE  [-]` VARCHAR(3),
	`T1[0] rate prescale` VARCHAR(3),
	`T1[0] rate real` VARCHAR(3),
	`T2[0] rate prescale` VARCHAR(3),
	`T2[0] rate real` VARCHAR(3),
	`T8[0] rate prescale` VARCHAR(3),
	`T8[0] rate real` VARCHAR(3),
	`T1[+] rate prescale` VARCHAR(3),
	`T1[+] rate real` VARCHAR(3),
	`T2[+] rate prescale` VARCHAR(3),
	`T2[+] rate real` VARCHAR(3),
	`T8[+] rate prescale` VARCHAR(3),
	`T8[+] rate real` VARCHAR(3),
	`T1[-] rate prescale` VARCHAR(3),
	`T1[-] rate real` VARCHAR(3),
	`T2[-] rate prescale` VARCHAR(3),
	`T2[-] rate real` VARCHAR(3),
	`T8[-] rate prescale` VARCHAR(3),
	`T8[-] rate real` VARCHAR(3),
	`T1[0] totals prescale` VARCHAR(3),
	`T1[0] totals real` VARCHAR(3),
	`T2[0] totals prescale` VARCHAR(3),
	`T2[0] totals real` VARCHAR(3),
	`T8[0] totals prescale` VARCHAR(3),
	`T8[0] totals real` VARCHAR(3),
	`T1[+] totals prescale` VARCHAR(3),
	`T1[+] totals real` VARCHAR(3),
	`T2[+] totals prescale` VARCHAR(3),
	`T2[+] totals real` VARCHAR(3),
	`T8[+] totals prescale` VARCHAR(3),
	`T8[+] totals real` VARCHAR(3),
	`T1[-] totals prescale` VARCHAR(3),
	`T1[-] totals real` VARCHAR(3),
	`T2[-] totals prescale` VARCHAR(3),
	`T2[-] totals real` VARCHAR(3),
	`T8[-] totals prescale` VARCHAR(3),
	`T8[-] totals real` VARCHAR(3),
	`BCM x1` VARCHAR(3),
	`BCM x3` VARCHAR(3),
	`BCM x10` VARCHAR(3),
	`BCM u1` VARCHAR(3),
	`BCM u3` VARCHAR(3),
	`BCM u10` VARCHAR(3),
	`BCM d1` VARCHAR(3),
	`BCM d3` VARCHAR(3),
	`BCM d10` VARCHAR(3),
	`BCM u1 [0]` VARCHAR(3),
	`BCM u3 [0]` VARCHAR(3),
	`BCM u10[0]` VARCHAR(3),
	`BCM u1 [+]` VARCHAR(3),
	`BCM u3 [+]` VARCHAR(3),
	`BCM u10[+]` VARCHAR(3),
	`BCM u1 [-]` VARCHAR(3),
	`BCM u3 [-]` VARCHAR(3),
	`BCM u10[-]` VARCHAR(3),
	`BCM d1 [0]` VARCHAR(3),
	`BCM d3 [0]` VARCHAR(3),
	`BCM d10[0]` VARCHAR(3),
	`BCM d1 [+]` VARCHAR(3),
	`BCM d3 [+]` VARCHAR(3),
	`BCM d10[+]` VARCHAR(3),
	`BCM d1 [-]` VARCHAR(3),
	`BCM d3 [-]` VARCHAR(3),
	`BCM d10[-]` VARCHAR(3),
	`Run Number` VARCHAR(3),
	`run mon` VARCHAR(3),
	`run day` VARCHAR(3),
	`run hr` VARCHAR(3),
	`run min` VARCHAR(3),
	`run sec` VARCHAR(3),
	`run yr` VARCHAR(5),
	`Left Arm D1 momentum` VARCHAR(3),
	`Left Arm angle` VARCHAR(3),
	`Right Arm D1 momentum` VARCHAR(9),
	`Right Arm angle` VARCHAR(8),
	`HALLA:p` VARCHAR(8),
	`HALLA:dpp` VARCHAR(13),
	`Tiefenbach Hall A energy` VARCHAR(8),
	`Left Arm mispointing (HPT)` VARCHAR(3),
	`Right Arm mispointing (HPT)` VARCHAR(3),
	`Left Arm Top VDC Current` VARCHAR(3),
	`Left Arm Bottom VDC Current` VARCHAR(3),
	`Right Arm Top VDC Current` VARCHAR(3),
	`Right Arm Bottom VDC Current` VARCHAR(3),
	`Right septum set current` VARCHAR(8),
	`Right septum current readback` VARCHAR(7),
	`Left Arm Q1 power supply current` VARCHAR(3),
	`Left Arm Q1 momentum` VARCHAR(3),
	`Left Arm Q1 gauss meter` VARCHAR(3),
	`Left Arm Q1 power supply polarity` VARCHAR(3),
	`Left Arm Q2 power supply current` VARCHAR(3),
	`Left Arm Q2 momentum` VARCHAR(3),
	`Left Arm Q2 gauss meter` VARCHAR(3),
	`Left Arm Q2 power supply polarity` VARCHAR(3),
	`Left Arm D1 power supply current` VARCHAR(3),
	`Left Arm D1 NMR` VARCHAR(3),
	`Left Arm Q3 power supply current` VARCHAR(3),
	`Left Arm Q3 momentum` VARCHAR(3),
	`Left Arm Q3 gauss meter` VARCHAR(3),
	`Left Arm Q3 power supply polarity` VARCHAR(3),
	`Right Arm Q1 power supply current` VARCHAR(3),
	`Right Arm Q1 momentum` VARCHAR(11),
	`Right Arm Q1 gauss meter` VARCHAR(11),
	`Right Arm Q1 power supply polarity` VARCHAR(3),
	`Right Arm Q2 power supply current` VARCHAR(13),
	`Right Arm Q2 momentum` VARCHAR(13),
	`Right Arm Q2 gauss meter` VARCHAR(11),
	`Right Arm Q2 power supply polarity` VARCHAR(8),
	`Right Arm D1 power supply current` VARCHAR(11),
	`Right Arm D1 NMR` VARCHAR(9),
	`Right Arm Q3 power supply current` VARCHAR(13),
	`Right Arm Q3 momentum` VARCHAR(13),
	`Right Arm Q3 gauss meter` VARCHAR(11),
	`Right Arm Q3 power supply polarity` VARCHAR(9),
	`Average current of the two cavities` VARCHAR(10),
	`Current on Unser monitor` VARCHAR(10),
	`Current on Upstream bcm` VARCHAR(10),
	`Current on Downstream bcm` VARCHAR(10),
	`Upstream Cavity Coefficient` VARCHAR(5),
	`Downstream Cavity Coefficient` VARCHAR(5),
	`Current on IBC0L02 (source)` VARCHAR(11),
	`Hall C Current` VARCHAR(3),
	`MBSY1c Hall A Beam energy` VARCHAR(8),
	`MBSY1c magnet current (amp)` VARCHAR(10),
	`MBSY1c Bdl` VARCHAR(12),
	`MBSY3c Hall C Beam energy` VARCHAR(8),
	`Tiefenbach Hall C energy` VARCHAR(8),
	`Delta(E)/E width (MV_AI_DXWID)` VARCHAR(10),
	`IPM1C12.XPOS` VARCHAR(13),
	`IPM1H04A.XPOS` VARCHAR(13),
	`IPM1H04A.YPOS` VARCHAR(13),
	`IPM1H04B.XPOS` VARCHAR(13),
	`IPM1H04B.YPOS` VARCHAR(13),
	`Left Arm Collimator` VARCHAR(3),
	`Left LVDT HPM` VARCHAR(3),
	`Left LVDT VPM` VARCHAR(3),
	`HacL_HPE1313A:0_Ch58` VARCHAR(3),
	`HacL_HPE1313A:0_Ch55` VARCHAR(3),
	`HacL_HPE1313A:0_Ch54` VARCHAR(3),
	`HacL_alignROLL` VARCHAR(3),
	`HacL_alignPITCH` VARCHAR(3),
	`HacL_alignHPT` VARCHAR(3),
	`Right Arm Collimator` VARCHAR(13),
	`Right LVDT HPM` VARCHAR(8),
	`Right LVDT VPM` VARCHAR(6),
	`HacR_HPE1313A:0_Ch58` VARCHAR(10),
	`HacR_HPE1313A:0_Ch55` VARCHAR(8),
	`HacR_HPE1313A:0_Ch54` VARCHAR(10),
	`HacR_alignROLL` VARCHAR(10),
	`HacR_alignPITCH` VARCHAR(13),
	`HacR_alignHPT` VARCHAR(3),
	`Wien angle` VARCHAR(9),
	`Helicity Mode ON/OFF Random/Toggle` VARCHAR(4),
	`Wien BDL` VARCHAR(8),
	`Wien field` VARCHAR(7),
	`Laser attenuation Hall A` VARCHAR(4),
	`Laser power Hall A` VARCHAR(3),
	`Half-wave plate (off=out)` VARCHAR(4),
	`rotating waveplate` VARCHAR(5),
	`Beam Half-wave plate (off=out)` VARCHAR(4),
	`G0 Helicity Settle Set` VARCHAR(9),
	`G0 Helicity Delay Set` VARCHAR(9),
	`G0 Helicity Pattern Set` VARCHAR(8),
	`G0 Helicity Settle Read` VARCHAR(9),
	`G0 Helicity Delay Read` VARCHAR(9),
	`G0 Helicity Pattern` VARCHAR(8),
	`Target OTR x-position` VARCHAR(12),
	`Target OTR y-position` VARCHAR(11),
	`Target OTR x-width` VARCHAR(10),
	`Target OTR y-width` VARCHAR(10),
	`Target OTR data valid flag` VARCHAR(4),
	`Target OTR In/Out` VARCHAR(16),
	`Arc OTR x-position` VARCHAR(10),
	`Arc OTR y-position` VARCHAR(13),
	`Arc OTR x-width` VARCHAR(10),
	`Arc OTR y-width` VARCHAR(10),
	`Arc OTR data valid flag` VARCHAR(4),
	`Arc OTR In/Out` VARCHAR(15),
	`Polarized 3He Target RTD #1` VARCHAR(3),
	`Polarized 3He Target RTD #2` VARCHAR(3),
	`Polarized 3He Target RTD #3` VARCHAR(3),
	`Polarized 3He Target RTD #4` VARCHAR(3),
	`Polarized 3He Target RTD #5` VARCHAR(3),
	`Polarized 3He Target RTD #6` VARCHAR(3),
	`Polarized 3He Target RTD #7` VARCHAR(3),
	`Polarized 3He Ref. Cell RTD #8` VARCHAR(3),
	`Polarized 3He Ref. Cell RTD #9` VARCHAR(3),
	`Polarized 3He Ref. Cell RTD #10` VARCHAR(3),
	`Polarized 3He Target Ref. Cell Gas Pres.` VARCHAR(3),
	`Polarized 3He Target Ref. Cell Sys.Vac.` VARCHAR(3),
	`Polarized 3He Target Cooling Jet` VARCHAR(3),
	`Polarized 3He Target OVEN RTD` VARCHAR(3),
	`Polarized 3He Target OVEN SP1 SET` VARCHAR(3),
	`Polarized 3He Target OVEN SP1` VARCHAR(3),
	`Polarized 3He Target OVEN AL1 SET` VARCHAR(3),
	`Polarized 3He Target OVEN AL1` VARCHAR(3),
	`Polarized 3He Target OVEN AL1 STATUS` VARCHAR(3),
	`Polarized 3He Target Half-Wave Plate DIST` VARCHAR(3),
	`Polarized 3He Target Half-Wave Plate STAT` VARCHAR(3),
	`Polarized 3He Target Position (PA)` VARCHAR(3),
	`Polarized 3He Target Position (POS)` VARCHAR(3),
	`Polarized 3He Target Position (DA)` VARCHAR(3),
	`Polarized 3He Target Position (SS9)` VARCHAR(3),
	`Polarized 3He Target Position (SA10)` VARCHAR(3),
	`Polarized 3He Target Position (SA9)` VARCHAR(3),
	`Polarized 3He Laser#1 State` VARCHAR(3),
	`Polarized 3He Laser#1 Current` VARCHAR(3),
	`Polarized 3He Laser#1 Temperature` VARCHAR(3),
	`Polarized 3He Laser#2 State` VARCHAR(3),
	`Polarized 3He Laser#2 Current` VARCHAR(3),
	`Polarized 3He Laser#2 Temperature` VARCHAR(3),
	`Polarized 3He Laser#3 State` VARCHAR(3),
	`Polarized 3He Laser#3 Current` VARCHAR(3),
	`Polarized 3He Laser#3 Temperature` VARCHAR(3),
	`Polarized 3He Laser#4 State` VARCHAR(3),
	`Polarized 3He Laser#4 Current` VARCHAR(3),
	`Polarized 3He Laser#4 Temperature` VARCHAR(3),
	`Polarized 3He Laser#5 State` VARCHAR(3),
	`Polarized 3He Laser#5 Current` VARCHAR(3),
	`Polarized 3He Laser#5 Temperature` VARCHAR(3),
	`Polarized 3He Laser#6 State` VARCHAR(3),
	`Polarized 3He Laser#6 Current` VARCHAR(3),
	`Polarized 3He Laser#6 Temperature` VARCHAR(3),
	`Polarized 3He Laser#7 State` VARCHAR(3),
	`Polarized 3He Laser#7 Current` VARCHAR(3),
	`Polarized 3He Laser#7 Temperature` VARCHAR(3),
	`Polarized 3He Coil Current Longitudinal` VARCHAR(7),
	`Polarized 3He Coil Current Transverse` VARCHAR(7),
	`Transverse gradient coils (A) setup current` VARCHAR(9),
	`Transverse gradient coils (A) readback current` VARCHAR(12),
	`Longitudinal upstream gradient coil (B) setup current` VARCHAR(8),
	`Longitudinal upstream gradient coil (B) readback current` VARCHAR(12),
	`Longitudinal downstream gradient coil (C) setup current` VARCHAR(8),
	`Longitudinal downstream gradient coil (C) readback current` VARCHAR(13),
	`Small vertical gradient coils (D) setup current` VARCHAR(9),
	`Small vertical gradient coils (D) readback current` VARCHAR(13),
	`Left Arm D1 momentum 2` VARCHAR(3),
	`Right Arm D1 momentum 2` VARCHAR(3),
	`Tiefenbach Hall A energy 2` VARCHAR(3),
	`Log book entry time is secs from midnnight April 20` VARCHAR(3),
	`Run stop time is secs from midnnight April 20` VARCHAR(9),
	`kCOMMENTS` VARCHAR(3),
	`Number of run summary files for this run` VARCHAR(2),
	`Right Arm Top VDC voltage` VARCHAR(12),
	`Right Arm Bottom VDC voltage` VARCHAR(12),
	`Arc1 dp/p` VARCHAR(12),
	`Arc2 dp/p` VARCHAR(12),
	`Right Arm Angle Floor Angle` VARCHAR(5),
	`Right Arm Angle Vernier` VARCHAR(6),
	`IPM1C12.YPOS` VARCHAR(13),
	`Survey X offset bpmA` VARCHAR(6),
	`Survey Y offset bpmA` VARCHAR(5),
	`Survey X offset bpmB` VARCHAR(5),
	`Survey Y offset bpmB` VARCHAR(3),
	INDEX (krun)	
 );
LOAD DATA LOCAL INFILE '~/gdh/runfiles_gdh_from_mss/rightbeg_mss.raw' INTO TABLE mssbeg;

##### translating to MySQL NULL value #####
UPDATE mssbeg SET `krun` = NULL WHERE `krun` = "?";
UPDATE mssbeg SET `Log entry time hr` = NULL WHERE `Log entry time hr` = "?";
UPDATE mssbeg SET `Log entry time min` = NULL WHERE `Log entry time min` = "?";
UPDATE mssbeg SET `Log entry time sec` = NULL WHERE `Log entry time sec` = "?";
UPDATE mssbeg SET `Log entry time mon` = NULL WHERE `Log entry time mon` = "?";
UPDATE mssbeg SET `Log entry time day` = NULL WHERE `Log entry time day` = "?";
UPDATE mssbeg SET `Log entry time yr` = NULL WHERE `Log entry time yr` = "?";
UPDATE mssbeg SET `Entry number` = NULL WHERE `Entry number` = "?";
UPDATE mssbeg SET `keyword` = NULL WHERE `keyword` = "?";
UPDATE mssbeg SET `User name` = NULL WHERE `User name` = "?";
UPDATE mssbeg SET `kRun_type` = NULL WHERE `kRun_type` = "?";
UPDATE mssbeg SET `kbeam_energy` = NULL WHERE `kbeam_energy` = "?";
UPDATE mssbeg SET `kbeam_halfwaveplate` = NULL WHERE `kbeam_halfwaveplate` = "?";
UPDATE mssbeg SET `kbeam_raster` = NULL WHERE `kbeam_raster` = "?";
UPDATE mssbeg SET `kcomment_text` = NULL WHERE `kcomment_text` = "?";
UPDATE mssbeg SET `kdaq_mode` = NULL WHERE `kdaq_mode` = "?";
UPDATE mssbeg SET `kkin_name` = NULL WHERE `kkin_name` = "?";
UPDATE mssbeg SET `kleftarm_p` = NULL WHERE `kleftarm_p` = "?";
UPDATE mssbeg SET `kleftarm_theta` = NULL WHERE `kleftarm_theta` = "?";
UPDATE mssbeg SET `krightarm_p` = NULL WHERE `krightarm_p` = "?";
UPDATE mssbeg SET `krightarm_theta` = NULL WHERE `krightarm_theta` = "?";
UPDATE mssbeg SET `ktarget_halfwaveplate` = NULL WHERE `ktarget_halfwaveplate` = "?";
UPDATE mssbeg SET `ktarget_name` = NULL WHERE `ktarget_name` = "?";
UPDATE mssbeg SET `ktarget_polarization` = NULL WHERE `ktarget_polarization` = "?";
UPDATE mssbeg SET `ktarget_type` = NULL WHERE `ktarget_type` = "?";
UPDATE mssbeg SET `ps1` = NULL WHERE `ps1` = "?";
UPDATE mssbeg SET `ps2` = NULL WHERE `ps2` = "?";
UPDATE mssbeg SET `ps3` = NULL WHERE `ps3` = "?";
UPDATE mssbeg SET `ps4` = NULL WHERE `ps4` = "?";
UPDATE mssbeg SET `ps5` = NULL WHERE `ps5` = "?";
UPDATE mssbeg SET `ps6` = NULL WHERE `ps6` = "?";
UPDATE mssbeg SET `ps7` = NULL WHERE `ps7` = "?";
UPDATE mssbeg SET `ps8` = NULL WHERE `ps8` = "?";
UPDATE mssbeg SET `EVENTS[0]` = NULL WHERE `EVENTS[0]` = "?";
UPDATE mssbeg SET `EVENTS[+]` = NULL WHERE `EVENTS[+]` = "?";
UPDATE mssbeg SET `EVENTS[-]` = NULL WHERE `EVENTS[-]` = "?";
UPDATE mssbeg SET `TIME  [0]` = NULL WHERE `TIME  [0]` = "?";
UPDATE mssbeg SET `TIME  [+]` = NULL WHERE `TIME  [+]` = "?";
UPDATE mssbeg SET `TIME  [-]` = NULL WHERE `TIME  [-]` = "?";
UPDATE mssbeg SET `LIVE  [0]` = NULL WHERE `LIVE  [0]` = "?";
UPDATE mssbeg SET `LIVE  [+]` = NULL WHERE `LIVE  [+]` = "?";
UPDATE mssbeg SET `LIVE  [-]` = NULL WHERE `LIVE  [-]` = "?";
UPDATE mssbeg SET `T1[0] rate prescale` = NULL WHERE `T1[0] rate prescale` = "?";
UPDATE mssbeg SET `T1[0] rate real` = NULL WHERE `T1[0] rate real` = "?";
UPDATE mssbeg SET `T2[0] rate prescale` = NULL WHERE `T2[0] rate prescale` = "?";
UPDATE mssbeg SET `T2[0] rate real` = NULL WHERE `T2[0] rate real` = "?";
UPDATE mssbeg SET `T8[0] rate prescale` = NULL WHERE `T8[0] rate prescale` = "?";
UPDATE mssbeg SET `T8[0] rate real` = NULL WHERE `T8[0] rate real` = "?";
UPDATE mssbeg SET `T1[+] rate prescale` = NULL WHERE `T1[+] rate prescale` = "?";
UPDATE mssbeg SET `T1[+] rate real` = NULL WHERE `T1[+] rate real` = "?";
UPDATE mssbeg SET `T2[+] rate prescale` = NULL WHERE `T2[+] rate prescale` = "?";
UPDATE mssbeg SET `T2[+] rate real` = NULL WHERE `T2[+] rate real` = "?";
UPDATE mssbeg SET `T8[+] rate prescale` = NULL WHERE `T8[+] rate prescale` = "?";
UPDATE mssbeg SET `T8[+] rate real` = NULL WHERE `T8[+] rate real` = "?";
UPDATE mssbeg SET `T1[-] rate prescale` = NULL WHERE `T1[-] rate prescale` = "?";
UPDATE mssbeg SET `T1[-] rate real` = NULL WHERE `T1[-] rate real` = "?";
UPDATE mssbeg SET `T2[-] rate prescale` = NULL WHERE `T2[-] rate prescale` = "?";
UPDATE mssbeg SET `T2[-] rate real` = NULL WHERE `T2[-] rate real` = "?";
UPDATE mssbeg SET `T8[-] rate prescale` = NULL WHERE `T8[-] rate prescale` = "?";
UPDATE mssbeg SET `T8[-] rate real` = NULL WHERE `T8[-] rate real` = "?";
UPDATE mssbeg SET `T1[0] totals prescale` = NULL WHERE `T1[0] totals prescale` = "?";
UPDATE mssbeg SET `T1[0] totals real` = NULL WHERE `T1[0] totals real` = "?";
UPDATE mssbeg SET `T2[0] totals prescale` = NULL WHERE `T2[0] totals prescale` = "?";
UPDATE mssbeg SET `T2[0] totals real` = NULL WHERE `T2[0] totals real` = "?";
UPDATE mssbeg SET `T8[0] totals prescale` = NULL WHERE `T8[0] totals prescale` = "?";
UPDATE mssbeg SET `T8[0] totals real` = NULL WHERE `T8[0] totals real` = "?";
UPDATE mssbeg SET `T1[+] totals prescale` = NULL WHERE `T1[+] totals prescale` = "?";
UPDATE mssbeg SET `T1[+] totals real` = NULL WHERE `T1[+] totals real` = "?";
UPDATE mssbeg SET `T2[+] totals prescale` = NULL WHERE `T2[+] totals prescale` = "?";
UPDATE mssbeg SET `T2[+] totals real` = NULL WHERE `T2[+] totals real` = "?";
UPDATE mssbeg SET `T8[+] totals prescale` = NULL WHERE `T8[+] totals prescale` = "?";
UPDATE mssbeg SET `T8[+] totals real` = NULL WHERE `T8[+] totals real` = "?";
UPDATE mssbeg SET `T1[-] totals prescale` = NULL WHERE `T1[-] totals prescale` = "?";
UPDATE mssbeg SET `T1[-] totals real` = NULL WHERE `T1[-] totals real` = "?";
UPDATE mssbeg SET `T2[-] totals prescale` = NULL WHERE `T2[-] totals prescale` = "?";
UPDATE mssbeg SET `T2[-] totals real` = NULL WHERE `T2[-] totals real` = "?";
UPDATE mssbeg SET `T8[-] totals prescale` = NULL WHERE `T8[-] totals prescale` = "?";
UPDATE mssbeg SET `T8[-] totals real` = NULL WHERE `T8[-] totals real` = "?";
UPDATE mssbeg SET `BCM x1` = NULL WHERE `BCM x1` = "?";
UPDATE mssbeg SET `BCM x3` = NULL WHERE `BCM x3` = "?";
UPDATE mssbeg SET `BCM x10` = NULL WHERE `BCM x10` = "?";
UPDATE mssbeg SET `BCM u1` = NULL WHERE `BCM u1` = "?";
UPDATE mssbeg SET `BCM u3` = NULL WHERE `BCM u3` = "?";
UPDATE mssbeg SET `BCM u10` = NULL WHERE `BCM u10` = "?";
UPDATE mssbeg SET `BCM d1` = NULL WHERE `BCM d1` = "?";
UPDATE mssbeg SET `BCM d3` = NULL WHERE `BCM d3` = "?";
UPDATE mssbeg SET `BCM d10` = NULL WHERE `BCM d10` = "?";
UPDATE mssbeg SET `BCM u1 [0]` = NULL WHERE `BCM u1 [0]` = "?";
UPDATE mssbeg SET `BCM u3 [0]` = NULL WHERE `BCM u3 [0]` = "?";
UPDATE mssbeg SET `BCM u10[0]` = NULL WHERE `BCM u10[0]` = "?";
UPDATE mssbeg SET `BCM u1 [+]` = NULL WHERE `BCM u1 [+]` = "?";
UPDATE mssbeg SET `BCM u3 [+]` = NULL WHERE `BCM u3 [+]` = "?";
UPDATE mssbeg SET `BCM u10[+]` = NULL WHERE `BCM u10[+]` = "?";
UPDATE mssbeg SET `BCM u1 [-]` = NULL WHERE `BCM u1 [-]` = "?";
UPDATE mssbeg SET `BCM u3 [-]` = NULL WHERE `BCM u3 [-]` = "?";
UPDATE mssbeg SET `BCM u10[-]` = NULL WHERE `BCM u10[-]` = "?";
UPDATE mssbeg SET `BCM d1 [0]` = NULL WHERE `BCM d1 [0]` = "?";
UPDATE mssbeg SET `BCM d3 [0]` = NULL WHERE `BCM d3 [0]` = "?";
UPDATE mssbeg SET `BCM d10[0]` = NULL WHERE `BCM d10[0]` = "?";
UPDATE mssbeg SET `BCM d1 [+]` = NULL WHERE `BCM d1 [+]` = "?";
UPDATE mssbeg SET `BCM d3 [+]` = NULL WHERE `BCM d3 [+]` = "?";
UPDATE mssbeg SET `BCM d10[+]` = NULL WHERE `BCM d10[+]` = "?";
UPDATE mssbeg SET `BCM d1 [-]` = NULL WHERE `BCM d1 [-]` = "?";
UPDATE mssbeg SET `BCM d3 [-]` = NULL WHERE `BCM d3 [-]` = "?";
UPDATE mssbeg SET `BCM d10[-]` = NULL WHERE `BCM d10[-]` = "?";
UPDATE mssbeg SET `Run Number` = NULL WHERE `Run Number` = "?";
UPDATE mssbeg SET `run mon` = NULL WHERE `run mon` = "?";
UPDATE mssbeg SET `run day` = NULL WHERE `run day` = "?";
UPDATE mssbeg SET `run hr` = NULL WHERE `run hr` = "?";
UPDATE mssbeg SET `run min` = NULL WHERE `run min` = "?";
UPDATE mssbeg SET `run sec` = NULL WHERE `run sec` = "?";
UPDATE mssbeg SET `run yr` = NULL WHERE `run yr` = "?";
UPDATE mssbeg SET `Left Arm D1 momentum` = NULL WHERE `Left Arm D1 momentum` = "?";
UPDATE mssbeg SET `Left Arm angle` = NULL WHERE `Left Arm angle` = "?";
UPDATE mssbeg SET `Right Arm D1 momentum` = NULL WHERE `Right Arm D1 momentum` = "?";
UPDATE mssbeg SET `Right Arm angle` = NULL WHERE `Right Arm angle` = "?";
UPDATE mssbeg SET `HALLA:p` = NULL WHERE `HALLA:p` = "?";
UPDATE mssbeg SET `HALLA:dpp` = NULL WHERE `HALLA:dpp` = "?";
UPDATE mssbeg SET `Tiefenbach Hall A energy` = NULL WHERE `Tiefenbach Hall A energy` = "?";
UPDATE mssbeg SET `Left Arm mispointing (HPT)` = NULL WHERE `Left Arm mispointing (HPT)` = "?";
UPDATE mssbeg SET `Right Arm mispointing (HPT)` = NULL WHERE `Right Arm mispointing (HPT)` = "?";
UPDATE mssbeg SET `Left Arm Top VDC Current` = NULL WHERE `Left Arm Top VDC Current` = "?";
UPDATE mssbeg SET `Left Arm Bottom VDC Current` = NULL WHERE `Left Arm Bottom VDC Current` = "?";
UPDATE mssbeg SET `Right Arm Top VDC Current` = NULL WHERE `Right Arm Top VDC Current` = "?";
UPDATE mssbeg SET `Right Arm Bottom VDC Current` = NULL WHERE `Right Arm Bottom VDC Current` = "?";
UPDATE mssbeg SET `Right septum set current` = NULL WHERE `Right septum set current` = "?";
UPDATE mssbeg SET `Right septum current readback` = NULL WHERE `Right septum current readback` = "?";
UPDATE mssbeg SET `Left Arm Q1 power supply current` = NULL WHERE `Left Arm Q1 power supply current` = "?";
UPDATE mssbeg SET `Left Arm Q1 momentum` = NULL WHERE `Left Arm Q1 momentum` = "?";
UPDATE mssbeg SET `Left Arm Q1 gauss meter` = NULL WHERE `Left Arm Q1 gauss meter` = "?";
UPDATE mssbeg SET `Left Arm Q1 power supply polarity` = NULL WHERE `Left Arm Q1 power supply polarity` = "?";
UPDATE mssbeg SET `Left Arm Q2 power supply current` = NULL WHERE `Left Arm Q2 power supply current` = "?";
UPDATE mssbeg SET `Left Arm Q2 momentum` = NULL WHERE `Left Arm Q2 momentum` = "?";
UPDATE mssbeg SET `Left Arm Q2 gauss meter` = NULL WHERE `Left Arm Q2 gauss meter` = "?";
UPDATE mssbeg SET `Left Arm Q2 power supply polarity` = NULL WHERE `Left Arm Q2 power supply polarity` = "?";
UPDATE mssbeg SET `Left Arm D1 power supply current` = NULL WHERE `Left Arm D1 power supply current` = "?";
UPDATE mssbeg SET `Left Arm D1 NMR` = NULL WHERE `Left Arm D1 NMR` = "?";
UPDATE mssbeg SET `Left Arm Q3 power supply current` = NULL WHERE `Left Arm Q3 power supply current` = "?";
UPDATE mssbeg SET `Left Arm Q3 momentum` = NULL WHERE `Left Arm Q3 momentum` = "?";
UPDATE mssbeg SET `Left Arm Q3 gauss meter` = NULL WHERE `Left Arm Q3 gauss meter` = "?";
UPDATE mssbeg SET `Left Arm Q3 power supply polarity` = NULL WHERE `Left Arm Q3 power supply polarity` = "?";
UPDATE mssbeg SET `Right Arm Q1 power supply current` = NULL WHERE `Right Arm Q1 power supply current` = "?";
UPDATE mssbeg SET `Right Arm Q1 momentum` = NULL WHERE `Right Arm Q1 momentum` = "?";
UPDATE mssbeg SET `Right Arm Q1 gauss meter` = NULL WHERE `Right Arm Q1 gauss meter` = "?";
UPDATE mssbeg SET `Right Arm Q1 power supply polarity` = NULL WHERE `Right Arm Q1 power supply polarity` = "?";
UPDATE mssbeg SET `Right Arm Q2 power supply current` = NULL WHERE `Right Arm Q2 power supply current` = "?";
UPDATE mssbeg SET `Right Arm Q2 momentum` = NULL WHERE `Right Arm Q2 momentum` = "?";
UPDATE mssbeg SET `Right Arm Q2 gauss meter` = NULL WHERE `Right Arm Q2 gauss meter` = "?";
UPDATE mssbeg SET `Right Arm Q2 power supply polarity` = NULL WHERE `Right Arm Q2 power supply polarity` = "?";
UPDATE mssbeg SET `Right Arm D1 power supply current` = NULL WHERE `Right Arm D1 power supply current` = "?";
UPDATE mssbeg SET `Right Arm D1 NMR` = NULL WHERE `Right Arm D1 NMR` = "?";
UPDATE mssbeg SET `Right Arm Q3 power supply current` = NULL WHERE `Right Arm Q3 power supply current` = "?";
UPDATE mssbeg SET `Right Arm Q3 momentum` = NULL WHERE `Right Arm Q3 momentum` = "?";
UPDATE mssbeg SET `Right Arm Q3 gauss meter` = NULL WHERE `Right Arm Q3 gauss meter` = "?";
UPDATE mssbeg SET `Right Arm Q3 power supply polarity` = NULL WHERE `Right Arm Q3 power supply polarity` = "?";
UPDATE mssbeg SET `Average current of the two cavities` = NULL WHERE `Average current of the two cavities` = "?";
UPDATE mssbeg SET `Current on Unser monitor` = NULL WHERE `Current on Unser monitor` = "?";
UPDATE mssbeg SET `Current on Upstream bcm` = NULL WHERE `Current on Upstream bcm` = "?";
UPDATE mssbeg SET `Current on Downstream bcm` = NULL WHERE `Current on Downstream bcm` = "?";
UPDATE mssbeg SET `Upstream Cavity Coefficient` = NULL WHERE `Upstream Cavity Coefficient` = "?";
UPDATE mssbeg SET `Downstream Cavity Coefficient` = NULL WHERE `Downstream Cavity Coefficient` = "?";
UPDATE mssbeg SET `Current on IBC0L02 (source)` = NULL WHERE `Current on IBC0L02 (source)` = "?";
UPDATE mssbeg SET `Hall C Current` = NULL WHERE `Hall C Current` = "?";
UPDATE mssbeg SET `MBSY1c Hall A Beam energy` = NULL WHERE `MBSY1c Hall A Beam energy` = "?";
UPDATE mssbeg SET `MBSY1c magnet current (amp)` = NULL WHERE `MBSY1c magnet current (amp)` = "?";
UPDATE mssbeg SET `MBSY1c Bdl` = NULL WHERE `MBSY1c Bdl` = "?";
UPDATE mssbeg SET `MBSY3c Hall C Beam energy` = NULL WHERE `MBSY3c Hall C Beam energy` = "?";
UPDATE mssbeg SET `Tiefenbach Hall C energy` = NULL WHERE `Tiefenbach Hall C energy` = "?";
UPDATE mssbeg SET `Delta(E)/E width (MV_AI_DXWID)` = NULL WHERE `Delta(E)/E width (MV_AI_DXWID)` = "?";
UPDATE mssbeg SET `IPM1C12.XPOS` = NULL WHERE `IPM1C12.XPOS` = "?";
UPDATE mssbeg SET `IPM1H04A.XPOS` = NULL WHERE `IPM1H04A.XPOS` = "?";
UPDATE mssbeg SET `IPM1H04A.YPOS` = NULL WHERE `IPM1H04A.YPOS` = "?";
UPDATE mssbeg SET `IPM1H04B.XPOS` = NULL WHERE `IPM1H04B.XPOS` = "?";
UPDATE mssbeg SET `IPM1H04B.YPOS` = NULL WHERE `IPM1H04B.YPOS` = "?";
UPDATE mssbeg SET `Left Arm Collimator` = NULL WHERE `Left Arm Collimator` = "?";
UPDATE mssbeg SET `Left LVDT HPM` = NULL WHERE `Left LVDT HPM` = "?";
UPDATE mssbeg SET `Left LVDT VPM` = NULL WHERE `Left LVDT VPM` = "?";
UPDATE mssbeg SET `HacL_HPE1313A:0_Ch58` = NULL WHERE `HacL_HPE1313A:0_Ch58` = "?";
UPDATE mssbeg SET `HacL_HPE1313A:0_Ch55` = NULL WHERE `HacL_HPE1313A:0_Ch55` = "?";
UPDATE mssbeg SET `HacL_HPE1313A:0_Ch54` = NULL WHERE `HacL_HPE1313A:0_Ch54` = "?";
UPDATE mssbeg SET `HacL_alignROLL` = NULL WHERE `HacL_alignROLL` = "?";
UPDATE mssbeg SET `HacL_alignPITCH` = NULL WHERE `HacL_alignPITCH` = "?";
UPDATE mssbeg SET `HacL_alignHPT` = NULL WHERE `HacL_alignHPT` = "?";
UPDATE mssbeg SET `Right Arm Collimator` = NULL WHERE `Right Arm Collimator` = "?";
UPDATE mssbeg SET `Right LVDT HPM` = NULL WHERE `Right LVDT HPM` = "?";
UPDATE mssbeg SET `Right LVDT VPM` = NULL WHERE `Right LVDT VPM` = "?";
UPDATE mssbeg SET `HacR_HPE1313A:0_Ch58` = NULL WHERE `HacR_HPE1313A:0_Ch58` = "?";
UPDATE mssbeg SET `HacR_HPE1313A:0_Ch55` = NULL WHERE `HacR_HPE1313A:0_Ch55` = "?";
UPDATE mssbeg SET `HacR_HPE1313A:0_Ch54` = NULL WHERE `HacR_HPE1313A:0_Ch54` = "?";
UPDATE mssbeg SET `HacR_alignROLL` = NULL WHERE `HacR_alignROLL` = "?";
UPDATE mssbeg SET `HacR_alignPITCH` = NULL WHERE `HacR_alignPITCH` = "?";
UPDATE mssbeg SET `HacR_alignHPT` = NULL WHERE `HacR_alignHPT` = "?";
UPDATE mssbeg SET `Wien angle` = NULL WHERE `Wien angle` = "?";
UPDATE mssbeg SET `Helicity Mode ON/OFF Random/Toggle` = NULL WHERE `Helicity Mode ON/OFF Random/Toggle` = "?";
UPDATE mssbeg SET `Wien BDL` = NULL WHERE `Wien BDL` = "?";
UPDATE mssbeg SET `Wien field` = NULL WHERE `Wien field` = "?";
UPDATE mssbeg SET `Laser attenuation Hall A` = NULL WHERE `Laser attenuation Hall A` = "?";
UPDATE mssbeg SET `Laser power Hall A` = NULL WHERE `Laser power Hall A` = "?";
UPDATE mssbeg SET `Half-wave plate (off=out)` = NULL WHERE `Half-wave plate (off=out)` = "?";
UPDATE mssbeg SET `rotating waveplate` = NULL WHERE `rotating waveplate` = "?";
UPDATE mssbeg SET `Beam Half-wave plate (off=out)` = NULL WHERE `Beam Half-wave plate (off=out)` = "?";
UPDATE mssbeg SET `G0 Helicity Settle Set` = NULL WHERE `G0 Helicity Settle Set` = "?";
UPDATE mssbeg SET `G0 Helicity Delay Set` = NULL WHERE `G0 Helicity Delay Set` = "?";
UPDATE mssbeg SET `G0 Helicity Pattern Set` = NULL WHERE `G0 Helicity Pattern Set` = "?";
UPDATE mssbeg SET `G0 Helicity Settle Read` = NULL WHERE `G0 Helicity Settle Read` = "?";
UPDATE mssbeg SET `G0 Helicity Delay Read` = NULL WHERE `G0 Helicity Delay Read` = "?";
UPDATE mssbeg SET `G0 Helicity Pattern` = NULL WHERE `G0 Helicity Pattern` = "?";
UPDATE mssbeg SET `Target OTR x-position` = NULL WHERE `Target OTR x-position` = "?";
UPDATE mssbeg SET `Target OTR y-position` = NULL WHERE `Target OTR y-position` = "?";
UPDATE mssbeg SET `Target OTR x-width` = NULL WHERE `Target OTR x-width` = "?";
UPDATE mssbeg SET `Target OTR y-width` = NULL WHERE `Target OTR y-width` = "?";
UPDATE mssbeg SET `Target OTR data valid flag` = NULL WHERE `Target OTR data valid flag` = "?";
UPDATE mssbeg SET `Target OTR In/Out` = NULL WHERE `Target OTR In/Out` = "?";
UPDATE mssbeg SET `Arc OTR x-position` = NULL WHERE `Arc OTR x-position` = "?";
UPDATE mssbeg SET `Arc OTR y-position` = NULL WHERE `Arc OTR y-position` = "?";
UPDATE mssbeg SET `Arc OTR x-width` = NULL WHERE `Arc OTR x-width` = "?";
UPDATE mssbeg SET `Arc OTR y-width` = NULL WHERE `Arc OTR y-width` = "?";
UPDATE mssbeg SET `Arc OTR data valid flag` = NULL WHERE `Arc OTR data valid flag` = "?";
UPDATE mssbeg SET `Arc OTR In/Out` = NULL WHERE `Arc OTR In/Out` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #1` = NULL WHERE `Polarized 3He Target RTD #1` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #2` = NULL WHERE `Polarized 3He Target RTD #2` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #3` = NULL WHERE `Polarized 3He Target RTD #3` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #4` = NULL WHERE `Polarized 3He Target RTD #4` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #5` = NULL WHERE `Polarized 3He Target RTD #5` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #6` = NULL WHERE `Polarized 3He Target RTD #6` = "?";
UPDATE mssbeg SET `Polarized 3He Target RTD #7` = NULL WHERE `Polarized 3He Target RTD #7` = "?";
UPDATE mssbeg SET `Polarized 3He Ref. Cell RTD #8` = NULL WHERE `Polarized 3He Ref. Cell RTD #8` = "?";
UPDATE mssbeg SET `Polarized 3He Ref. Cell RTD #9` = NULL WHERE `Polarized 3He Ref. Cell RTD #9` = "?";
UPDATE mssbeg SET `Polarized 3He Ref. Cell RTD #10` = NULL WHERE `Polarized 3He Ref. Cell RTD #10` = "?";
UPDATE mssbeg SET `Polarized 3He Target Ref. Cell Gas Pres.` = NULL WHERE `Polarized 3He Target Ref. Cell Gas Pres.` = "?";
UPDATE mssbeg SET `Polarized 3He Target Ref. Cell Sys.Vac.` = NULL WHERE `Polarized 3He Target Ref. Cell Sys.Vac.` = "?";
UPDATE mssbeg SET `Polarized 3He Target Cooling Jet` = NULL WHERE `Polarized 3He Target Cooling Jet` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN RTD` = NULL WHERE `Polarized 3He Target OVEN RTD` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN SP1 SET` = NULL WHERE `Polarized 3He Target OVEN SP1 SET` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN SP1` = NULL WHERE `Polarized 3He Target OVEN SP1` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN AL1 SET` = NULL WHERE `Polarized 3He Target OVEN AL1 SET` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN AL1` = NULL WHERE `Polarized 3He Target OVEN AL1` = "?";
UPDATE mssbeg SET `Polarized 3He Target OVEN AL1 STATUS` = NULL WHERE `Polarized 3He Target OVEN AL1 STATUS` = "?";
UPDATE mssbeg SET `Polarized 3He Target Half-Wave Plate DIST` = NULL WHERE `Polarized 3He Target Half-Wave Plate DIST` = "?";
UPDATE mssbeg SET `Polarized 3He Target Half-Wave Plate STAT` = NULL WHERE `Polarized 3He Target Half-Wave Plate STAT` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (PA)` = NULL WHERE `Polarized 3He Target Position (PA)` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (POS)` = NULL WHERE `Polarized 3He Target Position (POS)` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (DA)` = NULL WHERE `Polarized 3He Target Position (DA)` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (SS9)` = NULL WHERE `Polarized 3He Target Position (SS9)` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (SA10)` = NULL WHERE `Polarized 3He Target Position (SA10)` = "?";
UPDATE mssbeg SET `Polarized 3He Target Position (SA9)` = NULL WHERE `Polarized 3He Target Position (SA9)` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#1 State` = NULL WHERE `Polarized 3He Laser#1 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#1 Current` = NULL WHERE `Polarized 3He Laser#1 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#1 Temperature` = NULL WHERE `Polarized 3He Laser#1 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#2 State` = NULL WHERE `Polarized 3He Laser#2 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#2 Current` = NULL WHERE `Polarized 3He Laser#2 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#2 Temperature` = NULL WHERE `Polarized 3He Laser#2 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#3 State` = NULL WHERE `Polarized 3He Laser#3 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#3 Current` = NULL WHERE `Polarized 3He Laser#3 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#3 Temperature` = NULL WHERE `Polarized 3He Laser#3 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#4 State` = NULL WHERE `Polarized 3He Laser#4 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#4 Current` = NULL WHERE `Polarized 3He Laser#4 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#4 Temperature` = NULL WHERE `Polarized 3He Laser#4 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#5 State` = NULL WHERE `Polarized 3He Laser#5 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#5 Current` = NULL WHERE `Polarized 3He Laser#5 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#5 Temperature` = NULL WHERE `Polarized 3He Laser#5 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#6 State` = NULL WHERE `Polarized 3He Laser#6 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#6 Current` = NULL WHERE `Polarized 3He Laser#6 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#6 Temperature` = NULL WHERE `Polarized 3He Laser#6 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#7 State` = NULL WHERE `Polarized 3He Laser#7 State` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#7 Current` = NULL WHERE `Polarized 3He Laser#7 Current` = "?";
UPDATE mssbeg SET `Polarized 3He Laser#7 Temperature` = NULL WHERE `Polarized 3He Laser#7 Temperature` = "?";
UPDATE mssbeg SET `Polarized 3He Coil Current Longitudinal` = NULL WHERE `Polarized 3He Coil Current Longitudinal` = "?";
UPDATE mssbeg SET `Polarized 3He Coil Current Transverse` = NULL WHERE `Polarized 3He Coil Current Transverse` = "?";
UPDATE mssbeg SET `Transverse gradient coils (A) setup current` = NULL WHERE `Transverse gradient coils (A) setup current` = "?";
UPDATE mssbeg SET `Transverse gradient coils (A) readback current` = NULL WHERE `Transverse gradient coils (A) readback current` = "?";
UPDATE mssbeg SET `Longitudinal upstream gradient coil (B) setup current` = NULL WHERE `Longitudinal upstream gradient coil (B) setup current` = "?";
UPDATE mssbeg SET `Longitudinal upstream gradient coil (B) readback current` = NULL WHERE `Longitudinal upstream gradient coil (B) readback current` = "?";
UPDATE mssbeg SET `Longitudinal downstream gradient coil (C) setup current` = NULL WHERE `Longitudinal downstream gradient coil (C) setup current` = "?";
UPDATE mssbeg SET `Longitudinal downstream gradient coil (C) readback current` = NULL WHERE `Longitudinal downstream gradient coil (C) readback current` = "?";
UPDATE mssbeg SET `Small vertical gradient coils (D) setup current` = NULL WHERE `Small vertical gradient coils (D) setup current` = "?";
UPDATE mssbeg SET `Small vertical gradient coils (D) readback current` = NULL WHERE `Small vertical gradient coils (D) readback current` = "?";
UPDATE mssbeg SET `Left Arm D1 momentum 2` = NULL WHERE `Left Arm D1 momentum 2` = "?";
UPDATE mssbeg SET `Right Arm D1 momentum 2` = NULL WHERE `Right Arm D1 momentum 2` = "?";
UPDATE mssbeg SET `Tiefenbach Hall A energy 2` = NULL WHERE `Tiefenbach Hall A energy 2` = "?";
UPDATE mssbeg SET `Log book entry time is secs from midnnight April 20` = NULL WHERE `Log book entry time is secs from midnnight April 20` = "?";
UPDATE mssbeg SET `Run stop time is secs from midnnight April 20` = NULL WHERE `Run stop time is secs from midnnight April 20` = "?";
UPDATE mssbeg SET `kCOMMENTS` = NULL WHERE `kCOMMENTS` = "?";
UPDATE mssbeg SET `Number of run summary files for this run` = NULL WHERE `Number of run summary files for this run` = "?";
UPDATE mssbeg SET `Right Arm Top VDC voltage` = NULL WHERE `Right Arm Top VDC voltage` = "?";
UPDATE mssbeg SET `Right Arm Bottom VDC voltage` = NULL WHERE `Right Arm Bottom VDC voltage` = "?";
UPDATE mssbeg SET `Arc1 dp/p` = NULL WHERE `Arc1 dp/p` = "?";
UPDATE mssbeg SET `Arc2 dp/p` = NULL WHERE `Arc2 dp/p` = "?";
UPDATE mssbeg SET `Right Arm Angle Floor Angle` = NULL WHERE `Right Arm Angle Floor Angle` = "?";
UPDATE mssbeg SET `Right Arm Angle Vernier` = NULL WHERE `Right Arm Angle Vernier` = "?";
UPDATE mssbeg SET `IPM1C12.YPOS` = NULL WHERE `IPM1C12.YPOS` = "?";
UPDATE mssbeg SET `Survey X offset bpmA` = NULL WHERE `Survey X offset bpmA` = "?";
UPDATE mssbeg SET `Survey Y offset bpmA` = NULL WHERE `Survey Y offset bpmA` = "?";
UPDATE mssbeg SET `Survey X offset bpmB` = NULL WHERE `Survey X offset bpmB` = "?";
UPDATE mssbeg SET `Survey Y offset bpmB` = NULL WHERE `Survey Y offset bpmB` = "?";

##### this method for geetting the run start/end times is now obsolete 07/26/06 #####
#CREATE TABLE runbegtimes SELECT `krun`,`run yr`,`run mon`, `run day`, `run hr`, `run min`, `run sec`,
#FROM_DAYS(TO_DAYS(CONCAT(`run yr`,"-",`run mon`,"-",`run day`))+0) AS begdate,
#SEC_TO_TIME(TIME_TO_SEC(CONCAT(`run hr`,":",`run min`,":",`run sec`))+0) AS begtime
#FROM mssbeg;
#ALTER TABLE runbegtimes ADD INDEX (krun);
#CREATE TABLE runendtimes SELECT `krun`,`run yr`,`run mon`, `run day`, `run hr`, `run min`, `run sec`,
#FROM_DAYS(TO_DAYS(CONCAT(`run yr`,"-",`run mon`,"-",`run day`))+0) AS enddate,
#SEC_TO_TIME(TIME_TO_SEC(CONCAT(`run hr`,":",`run min`,":",`run sec`))+0) AS endtime
#FROM mssend;
#ALTER TABLE runendtimes ADD INDEX (krun);
