drop table if exists test_refcell_empty;
drop table if exists test_refcell_empty_pressure;
drop table if exists refcell_pressures;
##### this table finds the closet empty refcell run before the current run #####
create table test_refcell_empty
select 
	refrtd.run as run_num, 
	refrtd.run-min(refrtd.run-summary.run) as close_run 
from 	
	summary , refrtd 
where 
	target1 = "refcell" 
	and target2 = "empty" 
	and flag > 1 
	and summary.run <= refrtd.run 
group by 
	refrtd.run;

##### this table get all the information from the closest empty refcell run for each run #####
create table test_refcell_empty_pressure
select 	*
from 	refrtd , test_refcell_empty
where	close_run = refrtd.run;

create table refcell_pressures
select 
	summary.run,
	target1,
	target2,
	taraux1+14.696 as taraux1,
	taraux2+14.696 as taraux2,
	refcell_press,
	refcell_press_sigma,
	refcell_vac,
	refcell_vac_sigma	
from
	refrtd,summary
where	
	target1 = "refcell"
	and flag > 1.0
	and refrtd.run = summary.run;

##### these two statments subtracts out the empty refcell reading from the current refcell reading
UPDATE refcell_pressures , test_refcell_empty_pressure SET refcell_pressures.refcell_press = refcell_pressures.refcell_press - test_refcell_empty_pressure.refcell_press WHERE refcell_pressures.run = test_refcell_empty_pressure.run_num;
UPDATE refcell_pressures , test_refcell_empty_pressure SET refcell_pressures.refcell_vac = refcell_pressures.refcell_vac - test_refcell_empty_pressure.refcell_vac WHERE refcell_pressures.run = test_refcell_empty_pressure.run_num;

##### estimating the by-hand pressure from the epics pressure for the first and second periods #####
UPDATE refcell_pressures SET refcell_press = refcell_press*0.9919 - 1.923  WHERE run < 2275;
UPDATE refcell_pressures SET refcell_press = refcell_press*0.9857 + 0.3833 WHERE run > 2275;

##### calcing the average of the recorded by-hand pressure with the estimated by-hand pressure #####
UPDATE refcell_pressures SET taraux1 = (taraux1 + refcell_press)/2.0;
UPDATE refcell_pressures SET taraux2 = (taraux2 + refcell_press)/2.0;

##### setting the pressures to the estimated value if the recorded value is not there #####
UPDATE refcell_pressures SET taraux1 = refcell_press WHERE taraux1 is NULL;
UPDATE refcell_pressures SET taraux2 = refcell_press WHERE taraux2 is NULL;

##### defining the empty refcell as having no pressure #####
UPDATE refcell_pressures SET taraux1 = 0.0 WHERE target2 = "empty";
UPDATE refcell_pressures SET taraux2 = 0.0 WHERE target2 = "empty";

##### converting pressure to density in amagats #####
UPDATE refcell_pressures SET taraux1 = taraux1/16.31;
UPDATE refcell_pressures SET taraux2 = taraux2/16.31;

##### averaging the two recorded pressures and setting this as the target density for that run #####
UPDATE refcell_pressures , summary SET dentar = (refcell_pressures.taraux1+refcell_pressures.taraux2)/2.0 WHERE refcell_pressures.run = summary.run;

drop table if exists test_refcell_empty;
drop table if exists test_refcell_empty_pressure;
