DROP TABLE IF EXISTS run_unix_times;
DROP TABLE IF EXISTS temp;
DROP TABLE IF EXISTS temp2;
DROP TABLE IF EXISTS temp3;
DROP TABLE IF EXISTS temp4;
DROP TABLE IF EXISTS summary;

##### loading old run start/end times from run summaries #####
CREATE TABLE run_unix_times
 (
        run SMALLINT,
	start_time VARCHAR(12),
	end_time VARCHAR(12),
	INDEX (run)
 );
LOAD DATA LOCAL INFILE '../times/startendtimes.txt' INTO TABLE run_unix_times;

##### combining info from BASIC, RSPEC, BEAMPOL, BYHAND tables #####
CREATE TABLE temp 
SELECT basic.run,flag,runtype,period,nomangle AS nom_angle,cell,ebeam AS nom_ebeam,pmom AS nom_pmom,moller_a AS polbeam,target1,target2,taraux1,taraux2,raster,byhand.comments 
FROM basic,rspec,beampol,byhand
WHERE (basic.run = rspec.run) AND (rspec.run = beampol.run) AND (beampol.run = byhand.run);
# indexing run number to make queries faster
ALTER TABLE temp ADD INDEX (run);

##### combining info from previous table and SPLIT_RUNS #####
CREATE TABLE temp2
SELECT temp.run,flag,num_file,runtype,period,nom_angle,cell,nom_ebeam,nom_pmom,polbeam,target1,target2,taraux1,taraux2,raster,comments 
FROM temp,split_runs
WHERE (temp.run = split_runs.run);
#indexing run number to make queries faster
ALTER TABLE temp2 ADD INDEX (run);

##### combinig info from previous table and MSSEND #####
CREATE TABLE temp3
SELECT temp2.run,flag,num_file,runtype,period,nom_angle,cell,nom_ebeam,nom_pmom,polbeam,target1,target2,taraux1,taraux2,raster,comments
FROM temp2,mssend
WHERE (temp2.run = mssend.krun);
#indexing run number to make queries faster
ALTER TABLE temp3 ADD INDEX (run);

##### combining info from previous table and RUN_UNIX_TIMES , BEAM_HALF_PLATE #####
CREATE TABLE temp4
SELECT temp3.run,flag,num_file,runtype,start_time,end_time,period,nom_angle,cell,nom_ebeam,nom_pmom,polbeam,bhwp,target1,target2,taraux1,taraux2,raster,comments
FROM temp3,run_unix_times,beam_half_waveplate
WHERE (temp3.run = run_unix_times.run) and (temp3.run = beam_half_waveplate.run);
#indexing run number to make queries faster
ALTER TABLE temp4 ADD INDEX (run);

##### combinig previous table with info from EPICS_DATA_STREAM #####
# hac_bcm_average_mean is just used as a placeholder for a new column that has not been defined yet
CREATE TABLE summary
SELECT	temp4.run,
	temp4.run as n2_run,
	temp4.run as empty_run,
	flag,
	num_file,
	runtype,
	runtype AS sieve_slit,
	runtype AS target_collimators,
	start_time,
	end_time,
	period,
	nom_angle,
	cell,
	nom_ebeam,
	nom_ebeam AS ebeam,
	MBSY1C_energy_sigma AS ebeam_sigma,
	nom_pmom,
	HacR_D1_NMR_SIG_mean AS pmom,
	HacR_D1_NMR_SIG_sigma AS pmom_sigma,
	MSEPRIR_mean AS septum,
	MSEPRIR_sigma AS septum_sigma,
	MSEPRSETI_mean AS septum_set,
	hac_bcm_average_mean AS masstar,
	hac_bcm_average_mean AS masstar_eff,
	hac_bcm_average_mean AS nu,
	hac_bcm_average_mean AS q_2,
	hac_bcm_average_mean AS W_target,
	hac_bcm_average_mean AS W_neutron,
	hac_bcm_average_mean AS dp_ela_pos,
	hac_bcm_average_mean AS a_beam_curr,
	hac_bcm_average_sigma AS a_beam_curr_sig,
	HC_ibcm1_mean AS c_beam_curr,
	HC_ibcm1_sigma AS c_beam_curr_sig,
	IPM1H04A_XPOS_mean  AS bpm_ax,
	IPM1H04A_XPOS_sigma AS bpm_ax_sig,
	IPM1H04A_YPOS_mean  AS bpm_ay,
	IPM1H04A_YPOS_sigma AS bpm_ay_sig,
	IPM1H04B_XPOS_mean  AS bpm_bx,
	IPM1H04B_XPOS_sigma AS bpm_bx_sig,
	IPM1H04B_YPOS_mean  AS bpm_by,
	IPM1H04B_YPOS_sigma AS bpm_by_sig,
	IPM1H04B_XPOS_mean  AS bpm_tarx,
	IPM1H04B_YPOS_mean  AS bpm_tary,
	polbeam,
	bhwp,
	target1,
	target2,
	taraux1,
	taraux2,
	target2 AS tarang,
	hac_bcm_average_mean AS poltar,
	hac_bcm_average_mean AS dentar,
	raster,
	ps1 as polbeam_sign,
	ps1 as poltar_sign,
	ps1,
	ps2,
	ps3,
	ps4,
	ps5,
	ps6,
	ps7,
	ps8,
	hac_bcm_average_sigma AS bcm3_pos,
	hac_bcm_average_sigma AS bcm3_neg,
	hac_bcm_average_sigma AS bcm3_non,
	hac_bcm_average_sigma AS bcm10_pos,
	hac_bcm_average_sigma AS bcm10_neg,
	hac_bcm_average_sigma AS bcm10_non,
	hac_bcm_average_sigma AS t1_accept_pos,
	hac_bcm_average_sigma AS t1_accept_neg,
	hac_bcm_average_sigma AS t1_accept_non,
	hac_bcm_average_sigma AS t2_accept_pos,
	hac_bcm_average_sigma AS t2_accept_neg,
	hac_bcm_average_sigma AS t2_accept_non,
	hac_bcm_average_sigma AS t1_livetime_pos,
	hac_bcm_average_sigma AS t1_livetime_neg,
	hac_bcm_average_sigma AS t1_livetime_non,
	hac_bcm_average_sigma AS t2_livetime_pos,
	hac_bcm_average_sigma AS t2_livetime_neg,
	hac_bcm_average_sigma AS t2_livetime_non,
	comments,
	comments AS vdc_flag,
	comments AS pid_flag
FROM temp4 LEFT JOIN epics_data_stream
ON (temp4.run = epics_data_stream.run);
# indexing run number with the constraints that it is unique and not NULL to speed up queries
ALTER TABLE summary MODIFY run SMALLINT(6) NOT NULL;
ALTER TABLE summary ADD PRIMARY KEY (run);
# adjusting formatting of certain columns
ALTER TABLE summary MODIFY septum DOUBLE(8,3);
ALTER TABLE summary MODIFY septum_sigma DOUBLE(8,3);
ALTER TABLE summary MODIFY septum_set DOUBLE(8,3);
ALTER TABLE summary MODIFY polbeam DOUBLE(8,4);
ALTER TABLE summary MODIFY comments VARCHAR(500);
ALTER TABLE summary MODIFY vdc_flag VARCHAR(15);
ALTER TABLE summary MODIFY pid_flag VARCHAR(15);
ALTER TABLE summary MODIFY sieve_slit VARCHAR(20);
ALTER TABLE summary MODIFY target_collimators VARCHAR(20);
# dropping temporary tables used to make SUMMARY table
DROP TABLE temp;
DROP TABLE temp2;
DROP TABLE temp3;
DROP TABLE temp4;
#########below are commands that are now in the "make_tweaks" query file
#UPDATE summary,mssend SET summary.ps1 = mssend.ps1  WHERE (run = krun) and (summary.ps1 is NULL);
#UPDATE summary,mssend SET summary.ps2 = mssend.ps2  WHERE (run = krun) and (summary.ps2 is NULL);
#UPDATE summary,mssend SET summary.ps3 = mssend.ps3  WHERE (run = krun) and (summary.ps3 is NULL);
#UPDATE summary,mssend SET summary.ps4 = mssend.ps4  WHERE (run = krun) and (summary.ps4 is NULL);
#UPDATE summary,mssend SET summary.ps5 = mssend.ps5  WHERE (run = krun) and (summary.ps5 is NULL);
#UPDATE summary,mssend SET summary.ps6 = mssend.ps6  WHERE (run = krun) and (summary.ps6 is NULL);
#UPDATE summary,mssend SET summary.ps7 = mssend.ps7  WHERE (run = krun) and (summary.ps7 is NULL);
#UPDATE summary,mssend SET summary.ps8 = mssend.ps8  WHERE (run = krun) and (summary.ps8 is NULL);

#UPDATE summary,mssbeg SET summary.ps1 = mssbeg.ps1  WHERE (run = krun) and (summary.ps1 is NULL);
#UPDATE summary,mssbeg SET summary.ps2 = mssbeg.ps2  WHERE (run = krun) and (summary.ps2 is NULL);
#UPDATE summary,mssbeg SET summary.ps3 = mssbeg.ps3  WHERE (run = krun) and (summary.ps3 is NULL);
#UPDATE summary,mssbeg SET summary.ps4 = mssbeg.ps4  WHERE (run = krun) and (summary.ps4 is NULL);
#UPDATE summary,mssbeg SET summary.ps5 = mssbeg.ps5  WHERE (run = krun) and (summary.ps5 is NULL);
#UPDATE summary,mssbeg SET summary.ps6 = mssbeg.ps6  WHERE (run = krun) and (summary.ps6 is NULL);
#UPDATE summary,mssbeg SET summary.ps7 = mssbeg.ps7  WHERE (run = krun) and (summary.ps7 is NULL);
#UPDATE summary,mssbeg SET summary.ps8 = mssbeg.ps8  WHERE (run = krun) and (summary.ps8 is NULL);

#UPDATE summary SET ps1 = NULL  WHERE run = 2002;
#UPDATE summary SET ps2 = 14    WHERE run = 2002;
#UPDATE summary SET ps3 = 9999  WHERE run = 2002;
#UPDATE summary SET ps4 = 9999  WHERE run = 2002;
#UPDATE summary SET ps5 = 65535 WHERE run = 2002;
#UPDATE summary SET ps6 = 65535 WHERE run = 2002;
#UPDATE summary SET ps7 = 65535 WHERE run = 2002;
#UPDATE summary SET ps8 = 65535 WHERE run = 2002;
#UPDATE summary SET comments = concat_ws(" ; " , "fractional ps1?" , comments) where (flag > 1) and (run = 2002);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2002);

#UPDATE summary SET ps1 = NULL  WHERE run = 2003;
#UPDATE summary SET ps2 = 14    WHERE run = 2003;
#UPDATE summary SET ps3 = 9999  WHERE run = 2003;
#UPDATE summary SET ps4 = 9999  WHERE run = 2003;
#UPDATE summary SET ps5 = 65535 WHERE run = 2003;
#UPDATE summary SET ps6 = 65535 WHERE run = 2003;
#UPDATE summary SET ps7 = 65535 WHERE run = 2003;
#UPDATE summary SET ps8 = 65535 WHERE run = 2003;
#UPDATE summary SET comments = concat_ws(" ; " , "fractional ps1?" , comments) where (flag > 1) and (run = 2003);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2003);

#UPDATE summary SET ps2 = 1     WHERE run = 2727;
#UPDATE summary SET comments = concat_ws(" ; " , "no ps2?" , comments) where (flag > 1) and (run = 2727);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2727);

#UPDATE summary SET ps1 = 1     WHERE run = 2434;
#UPDATE summary SET ps2 = 1     WHERE run = 2434;
#UPDATE summary SET ps3 = 9999  WHERE run = 2434;
#UPDATE summary SET ps4 = 9999  WHERE run = 2434;
#UPDATE summary SET ps5 = 65535 WHERE run = 2434;
#UPDATE summary SET ps6 = 65535 WHERE run = 2434;
#UPDATE summary SET ps7 = 65535 WHERE run = 2434;
#UPDATE summary SET ps8 = 65535 WHERE run = 2434;
#UPDATE summary SET comments = concat_ws(" ; " , "extra spaces in prescale string?" , comments) where (flag > 1) and (run = 2434);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2434);

#UPDATE summary SET ps1 = 5     WHERE run = 2435;
#UPDATE summary SET ps2 = 1     WHERE run = 2435;
#UPDATE summary SET ps3 = 9999  WHERE run = 2435;
#UPDATE summary SET ps4 = 9999  WHERE run = 2435;
#UPDATE summary SET ps5 = 65535 WHERE run = 2435;
#UPDATE summary SET ps6 = 65535 WHERE run = 2435;
#UPDATE summary SET ps7 = 65535 WHERE run = 2435;
#UPDATE summary SET ps8 = 65535 WHERE run = 2435;
#UPDATE summary SET comments = concat_ws(" ; " , "extra spaces in prescale string?" , comments) where (flag > 1) and (run = 2435);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2435);

#UPDATE summary SET num_file = 1 where runtype = "ped";

#UPDATE summary SET pmom_sigma = pmom_sigma*(-1.6*3*pmom*pmom+2698);
#UPDATE summary SET pmom = pmom*(-1.6*pmom*pmom+2698);
#UPDATE summary SET comments = concat_ws(" ; " , "pmom_sigma is larger than 0.1 MeV" , comments) where (pmom_sigma > 0.1) and (flag > 1);
#UPDATE summary SET flag = 2 where (pmom_sigma > 0.1) and (flag = 3);
#ALTER TABLE summary MODIFY pmom DOUBLE(9,4);
#ALTER TABLE summary MODIFY pmom_sigma DOUBLE(9,4);

#UPDATE summary SET tarang = NULL;
#UPDATE summary,epics_data_stream SET tarang =   "0" WHERE (summary.run = epics_data_stream.run) AND (abs(pol3heLargeCoilCurrent_mean) < +0.5 ) AND     (pol3heSmallCoilCurrent_mean  < -6.5);
#UPDATE summary,epics_data_stream SET tarang = "180" WHERE (summary.run = epics_data_stream.run) AND (abs(pol3heLargeCoilCurrent_mean) < +0.5 ) AND     (pol3heSmallCoilCurrent_mean  > +6.5);
#UPDATE summary,epics_data_stream SET tarang = "270" WHERE (summary.run = epics_data_stream.run) AND     (pol3heLargeCoilCurrent_mean  < -6.5 ) AND (abs(pol3heSmallCoilCurrent_mean) < +0.5);

#UPDATE summary,epics_data_stream_wbpm SET       ebeam = halla_MeV_mean  WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run < 1187);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = halla_MeV_sigma WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run < 1187);
#UPDATE summary,epics_data_stream_wbpm SET       ebeam = HALLA_p_mean    WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 1735) AND (summary.run < 1924);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = HALLA_p_sigma   WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 1735) AND (summary.run < 1924);
#UPDATE summary,epics_data_stream_wbpm SET       ebeam = halla_MeV_mean  WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2188) AND (summary.run < 2260);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = halla_MeV_sigma WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2188) AND (summary.run < 2260);
#UPDATE summary,epics_data_stream_wbpm SET       ebeam = HALLA_p_mean    WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2300) AND (summary.run < 2697);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = HALLA_p_sigma   WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2300) AND (summary.run < 2697);
#UPDATE summary,epics_data_stream_wbpm SET       ebeam = HALLA_p_mean    WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2798) AND (summary.run < 3516);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = HALLA_p_sigma   WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 2798) AND (summary.run < 3516);
#UPDATE summary,epics_data_stream_wbpm SET       ebeam = halla_MeV_mean  WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 3515);
#UPDATE summary,epics_data_stream_wbpm SET ebeam_sigma = halla_MeV_sigma WHERE (summary.run = epics_data_stream_wbpm.run) AND (summary.run > 3515);
#UPDATE summary SET nom_ebeam = ROUND(nom_ebeam/1000,1);
#ALTER TABLE summary MODIFY ebeam_sigma DOUBLE(7,2);

#UPDATE summary SET comments = concat_ws(" ; " , "ebeam_sigma is larger than 0.5 MeV AND 1000 ppm" , comments) where (flag > 1) and (ebeam_sigma > 0.5) and (1000000.0*ebeam_sigma/ebeam > 1000.0);
#UPDATE summary SET flag = 2 where (flag = 3) and (ebeam_sigma > 0.5) and (1000000.0*ebeam_sigma/ebeam > 1000.0);

#UPDATE summary SET mass_neutron = NULL;
#UPDATE summary,particle_mass SET mass_neutron = mass WHERE particle = "neutron";
#UPDATE summary SET mass_target = NULL;
#UPDATE summary,particle_mass SET mass_target = mass WHERE particle = "helium3" and target1="pol3he";
#UPDATE summary,particle_mass SET mass_target = mass WHERE particle = "helium3" and target1="refcell" and target2="3he";
#UPDATE summary,particle_mass SET mass_target = mass WHERE particle = "nitrogen" and target1="refcell" and target2="n2";
#UPDATE summary,particle_mass SET mass_target = mass WHERE particle = "carbon" and target1="carbon";

#UPDATE summary SET nu = NULL;
#UPDATE summary SET nu = (ebeam - pmom)/1000;
#UPDATE summary SET q_2 = NULL;
#UPDATE summary SET q_2 = 4*ebeam/1000*pmom/1000*sin(22*nom_angle/7/180/2)*sin(22*nom_angle/7/180/2);
#UPDATE summary SET W_neutron = NULL;
#UPDATE summary SET W_neutron = sqrt(mass_neutron*mass_neutron/1000/1000 + 2*nu*mass_neutron/1000 - q_2);
#UPDATE summary SET W_target = NULL;
#UPDATE summary SET W_target = sqrt(mass_target*mass_target/1000/1000 + 2*nu*mass_target/1000 - q_2);
#UPDATE summary SET dp_ela_pos = NULL;
#UPDATE summary SET dp_ela_pos = ebeam/pmom/(1+2*ebeam/mass_target*sin(22*nom_angle/7/180/2)*sin(22*nom_angle/7/180/2))-1;
#ALTER TABLE summary MODIFY nu DOUBLE(9,5);
#ALTER TABLE summary MODIFY q_2 DOUBLE(9,5);
#ALTER TABLE summary MODIFY W_neutron DOUBLE(9,5);
#ALTER TABLE summary MODIFY W_target DOUBLE(9,5);
#ALTER TABLE summary MODIFY dp_ela_pos DOUBLE(9,5);

#UPDATE summary,epics_data_stream_wbcm SET a_beam_curr     = hac_bcm_average_mean  WHERE (summary.run = epics_data_stream_wbcm.run);
#UPDATE summary,epics_data_stream_wbcm SET a_beam_curr_sig = hac_bcm_average_sigma WHERE (summary.run = epics_data_stream_wbcm.run);
#UPDATE summary,epics_data_stream_wbcm SET c_beam_curr     = HC_ibcm1_mean         WHERE (summary.run = epics_data_stream_wbcm.run);
#UPDATE summary,epics_data_stream_wbcm SET c_beam_curr_sig = HC_ibcm1_sigma        WHERE (summary.run = epics_data_stream_wbcm.run);
#ALTER TABLE summary MODIFY a_beam_curr DOUBLE(9,4);
#ALTER TABLE summary MODIFY a_beam_curr_sig DOUBLE(9,4);
#ALTER TABLE summary MODIFY c_beam_curr DOUBLE(9,4);
#ALTER TABLE summary MODIFY c_beam_curr_sig DOUBLE(9,4);

#UPDATE summary,epics_data_stream_wbpm SET bpm_ax     = IPM1H04A_XPOS_mean  WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_ax_sig = IPM1H04A_XPOS_sigma WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_ay     = IPM1H04A_YPOS_mean  WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_ay_sig = IPM1H04A_YPOS_sigma WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_bx     = IPM1H04B_XPOS_mean  WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_bx_sig = IPM1H04B_XPOS_sigma WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_by     = IPM1H04B_YPOS_mean  WHERE (summary.run = epics_data_stream_wbpm.run);
#UPDATE summary,epics_data_stream_wbpm SET bpm_by_sig = IPM1H04B_YPOS_sigma WHERE (summary.run = epics_data_stream_wbpm.run);
#ALTER TABLE summary MODIFY bpm_ax DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_ax_sig DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_bx DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_bx_sig DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_ay DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_ay_sig DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_by DOUBLE(9,5);
#ALTER TABLE summary MODIFY bpm_by_sig DOUBLE(9,5);

#UPDATE summary SET comments = concat_ws(" ; " , "bpm_ax_sig > 0.250 mm" , comments) where (flag > 1) and (bpm_ax_sig > 0.250);
#UPDATE summary SET flag = 2 where (flag = 3) and (bpm_ax_sig > 0.250);
#UPDATE summary SET comments = concat_ws(" ; " , "bpm_ay_sig > 0.250 mm" , comments) where (flag > 1) and (bpm_ay_sig > 0.250);
#UPDATE summary SET flag = 2 where (flag = 3) and (bpm_ay_sig > 0.250);
#UPDATE summary SET comments = concat_ws(" ; " , "bpm_bx_sig > 0.250 mm" , comments) where (flag > 1) and (bpm_bx_sig > 0.250);
#UPDATE summary SET flag = 2 where (flag = 3) and (bpm_bx_sig > 0.250);
#UPDATE summary SET comments = concat_ws(" ; " , "bpm_by_sig > 0.250 mm" , comments) where (flag > 1) and (bpm_by_sig > 0.250);
#UPDATE summary SET flag = 2 where (flag = 3) and (bpm_by_sig > 0.250);

#UPDATE summary SET comments = concat_ws(" ; " , "no pressures manually recorded anywhere!" , comments) where (flag > 1) and (run = 2057);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 2057);
#UPDATE summary SET comments = concat_ws(" ; " , "no pressures manually recorded anywhere!" , comments) where (flag > 1) and (run = 3632);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 3632);
#UPDATE summary SET comments = concat_ws(" ; " , "some problems with the pressures for this run!" , comments) where (flag > 1) and (run = 3576);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 3576);
#UPDATE summary SET comments = concat_ws(" ; " , "some problems with the pressures for this run!" , comments) where (flag > 1) and (run = 3583);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 3583);
#UPDATE summary SET comments = concat_ws(" ; " , "some problems with the pressures for this run!" , comments) where (flag > 1) and (run = 3590);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 3590);

#UPDATE summary,times_eds SET summary.start_time = unix_timestamp(times_eds.start_time) WHERE summary.run = times_eds.run;
#UPDATE summary,times_eds SET summary.end_time = unix_timestamp(times_eds.end_time) WHERE summary.run = times_eds.run;

#UPDATE summary SET comments = concat_ws(" ; " , "mysterious ROC 100 errors during the scalar replay" , comments) where (flag > 1) and (run = 3382);
#UPDATE summary SET flag = 2 where (flag = 3) and (run = 3382);

#UPDATE summary SET comments = concat_ws(" ; " , "VS says ps too high, not enough events" , comments) where (flag > 1) and (run = 2754);
#UPDATE summary SET flag = 0 where (run = 2754);
